@@ -24,9 +24,11 @@
 
 ./scriptpo-update.sh
 
-find . -name "*.c" -exec indent "{}" \;
-find . -name "*.h" -exec indent "{}" \;
-find . -name "*.h.in" -exec indent "{}" \;
+# Indent C file twice to avoid weird diffs (ping-pong effect)
+find ../src/ -name "*.c" -exec indent "{}" \;
+find ../src/ -name "*.c" -exec indent "{}" \;
+find ../src/ -name "*.h" -exec indent "{}" \;
+find ../src/ -name "*.h.in" -exec indent "{}" \;
 
 ./stamp.sh auto
 
