@@ -20,9 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "cfg.h"
 #include "cfg-internal.h"
 #include "../hlp/hlp.h"
