@@ -20,10 +20,13 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "cfg.h"
 
-#define TEST_CFG "/tmp/liquidwar6-config.xml"
+#define TEST_CFG "test.xml"
 #define TEST_ARGC 3
 #define TEST_ARGV0 "abc"
 #define TEST_ARGV1 "--fullscreen"
@@ -41,21 +44,36 @@ test_load_save ()
   void *context;
   int argc = TEST_ARGC;
   char *argv[TEST_ARGC] = { TEST_ARGV0, TEST_ARGV1, TEST_ARGV2 };
+  char *user_dir = NULL;
+  char *test_cfg = NULL;
 
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   context = lw6cfg_init (argc, argv);
   if (context)
     {
-      {
-	/*
-	 * Note: we don't consider the test as invalid if the
-	 * file does not exist, after all, it's a normal behavior
-	 * of the game to be launched without any config file.
-	 */
-	lw6cfg_load (context, TEST_CFG);
-	lw6cfg_save (context, TEST_CFG);
-      }
+      user_dir = lw6sys_get_default_user_dir ();
+      if (user_dir)
+	{
+	  if (!lw6sys_dir_exists (user_dir))
+	    {
+	      lw6sys_create_dir (user_dir);
+	    }
+	  test_cfg = lw6sys_path_concat (user_dir, TEST_CFG);
+	  if (test_cfg)
+	    {
+	      /*
+	       * Note: we don't consider the test as invalid if the
+	       * file does not exist, after all, it's a normal behavior
+	       * of the game to be launched without any config file.
+	       */
+	      lw6cfg_load (context, test_cfg);
+	      lw6cfg_save (context, test_cfg);
+
+	      LW6SYS_FREE (test_cfg);
+	    }
+	  LW6SYS_FREE (user_dir);
+	}
       lw6cfg_quit (context);
     }
   else
@@ -84,7 +102,7 @@ test_unified ()
     value = lw6cfg_unified_get_value (argc, argv, TEST_UNIFIED_KEY_YES);
     if (value)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("value for \"%s\" is \"%s\""),
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("value for \"%s\" is \"%s\""),
 		    TEST_UNIFIED_KEY_YES, value);
 	LW6SYS_FREE (value);
       }
