@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,7 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
+#include <string.h>
+
 #include "cfg-internal.h"
 
 static char *
@@ -31,6 +35,11 @@ get_option (int argc, char *argv[], char *key)
   char *config_file = NULL;
   _lw6cfg_context_t *cfg_context = NULL;
 
+  if (strstr (key, "fullscr"))
+    {
+      D ("2");
+    }
+
   cfg_context = _lw6cfg_init (argc, argv);
   if (cfg_context)
     {
@@ -81,6 +90,11 @@ lw6cfg_unified_get_value (int argc, char *argv[], char *key)
 {
   char *ret = NULL;
 
+  if (strstr (key, "fullscr"))
+    {
+      D ("1");
+    }
+
   ret = lw6sys_arg_get_value_with_env (argc, argv, key);
 
   if (!ret)
