@@ -38,6 +38,16 @@
 #define LW6CFG_XML_TRUE "true"
 #define LW6CFG_XML_FALSE "false"
 
+// cfg-commandline.c
+extern int lw6cfg_parse_command_line (void *context);
+
+// cfg-env.c
+extern int lw6cfg_merge_env (void *cfg_context);
+
+// cfg-format.c
+extern char *lw6cfg_format (char *key, char *value, LW6HLP_TYPE type);
+extern char *lw6cfg_format_guess_type (char *key, char *value);
+
 /*
  * In load.c
  */
