@@ -20,7 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "cli.h"
 
 #define TEST_ARGC 1
@@ -84,12 +87,14 @@ lw6cli_test ()
       lw6cli_destroy_backend (backend);
     }
 
+#ifdef MOD_HTTP
   backend = lw6cli_create_backend (argc, argv, "http");
   if (backend)
     {
       ret = test_init (backend) && test_quit (backend) && ret;
       lw6cli_destroy_backend (backend);
     }
+#endif
 
   return ret;
 }
