@@ -20,16 +20,16 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "../cli.h"
 #include "mod-http.h"
 #include "mod-http-internal.h"
 
 static void *
-init ()
+_init ()
 {
   _http_context_t *http_context = _mod_http_init ();
 
@@ -37,7 +37,7 @@ init ()
 }
 
 static void
-quit (void *cli_context)
+_quit (void *cli_context)
 {
   _http_context_t *http_context = (_http_context_t *) cli_context;
 
@@ -48,7 +48,7 @@ quit (void *cli_context)
 }
 
 static int
-can_handle (void *cli_context, char *server_url)
+_can_handle (void *cli_context, char *server_url)
 {
   _http_context_t *http_context = (_http_context_t *) cli_context;
   int ret = 0;
@@ -62,8 +62,8 @@ can_handle (void *cli_context, char *server_url)
 }
 
 static lw6cli_connection_t *
-connect (void *cli_context, char *server_url, char *client_url,
-	 char *password)
+_connect (void *cli_context, char *server_url, char *client_url,
+	  char *password)
 {
   _http_context_t *http_context = (_http_context_t *) cli_context;
   lw6cli_connection_t *ret = NULL;
@@ -78,7 +78,7 @@ connect (void *cli_context, char *server_url, char *client_url,
 }
 
 static void
-close (void *cli_context, lw6cli_connection_t * connection)
+_close (void *cli_context, lw6cli_connection_t * connection)
 {
   _http_context_t *http_context = (_http_context_t *) cli_context;
 
@@ -89,7 +89,7 @@ close (void *cli_context, lw6cli_connection_t * connection)
 }
 
 static int
-send (void *cli_context, lw6cli_connection_t * connection, char *message)
+_send (void *cli_context, lw6cli_connection_t * connection, char *message)
 {
   _http_context_t *http_context = (_http_context_t *) cli_context;
   int ret = 0;
@@ -103,7 +103,7 @@ send (void *cli_context, lw6cli_connection_t * connection, char *message)
 }
 
 static char *
-recv (void *cli_context, lw6cli_connection_t * connection)
+_recv (void *cli_context, lw6cli_connection_t * connection)
 {
   _http_context_t *http_context = (_http_context_t *) cli_context;
   char *ret = NULL;
@@ -117,7 +117,7 @@ recv (void *cli_context, lw6cli_connection_t * connection)
 }
 
 static int
-is_alive (void *cli_context, lw6cli_connection_t * connection)
+_is_alive (void *cli_context, lw6cli_connection_t * connection)
 {
   _http_context_t *http_context = (_http_context_t *) cli_context;
   int ret = 0;
@@ -131,7 +131,7 @@ is_alive (void *cli_context, lw6cli_connection_t * connection)
 }
 
 static char *
-repr (void *cli_context, lw6cli_connection_t * connection)
+_repr (void *cli_context, lw6cli_connection_t * connection)
 {
   _http_context_t *http_context = (_http_context_t *) cli_context;
   char *ret = NULL;
@@ -145,7 +145,7 @@ repr (void *cli_context, lw6cli_connection_t * connection)
 }
 
 static char *
-error (void *cli_context, lw6cli_connection_t * connection)
+_error (void *cli_context, lw6cli_connection_t * connection)
 {
   _http_context_t *http_context = (_http_context_t *) cli_context;
   char *ret = NULL;
@@ -168,16 +168,16 @@ mod_http_create_backend ()
     {
       memset (backend, 0, sizeof (lw6cli_backend_t));
 
-      backend->init = init;
-      backend->quit = quit;
-      backend->can_handle = can_handle;
-      backend->connect = connect;
-      backend->close = close;
-      backend->send = send;
-      backend->recv = recv;
-      backend->is_alive = is_alive;
-      backend->repr = repr;
-      backend->error = error;
+      backend->init = _init;
+      backend->quit = _quit;
+      backend->can_handle = _can_handle;
+      backend->connect = _connect;
+      backend->close = _close;
+      backend->send = _send;
+      backend->recv = _recv;
+      backend->is_alive = _is_alive;
+      backend->repr = _repr;
+      backend->error = _error;
     }
 
   return backend;
