@@ -20,17 +20,23 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <readline/history.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
+#ifdef LW6_CONSOLE
+#include <readline/history.h>
+#endif
+
 #include "cns.h"
 
 void
 lw6cns_history_add_if_needed (char *line)
 {
+#ifdef LW6_CONSOLE
   if (line && line[0])
     {
       add_history (line);
     }
+#endif
 }
