@@ -20,7 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "dyn.h"
 
 #define TEST_DYN_TOP_LEVEL_LIB "gfx"
@@ -49,7 +52,7 @@ test_path ()
 				TEST_DYN_BACKEND_NAME);
     if (library_path && lw6sys_file_exists (library_path))
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG,
+	lw6sys_log (LW6SYS_LOG_NOTICE,
 		    _("found library \"%s/mod-%s\" in \"%s\""),
 		    TEST_DYN_TOP_LEVEL_LIB, TEST_DYN_BACKEND_NAME,
 		    library_path);
