@@ -20,11 +20,14 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "gfx.h"
 
 static void
-warning (char *func_name)
+_warning (char *func_name)
 {
   lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("gfx backend function \"%s\" is not defined"), func_name);
@@ -33,28 +36,36 @@ warning (char *func_name)
 void
 lw6gfx_display_background (lw6gfx_backend_t * backend, lw6gui_look_t * look)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->display_background)
     {
       backend->display_background (backend->gfx_context, look);
     }
   else
     {
-      warning ("display_background");
+      _warning ("display_background");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
 
 void
 lw6gfx_display_hud (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 		    lw6ker_game_state_t * game_state)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->display_hud)
     {
       backend->display_hud (backend->gfx_context, look, game_state);
     }
   else
     {
-      warning ("display_hud_fg");
+      _warning ("display_hud_fg");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
 
 int
@@ -62,16 +73,20 @@ lw6gfx_poll_key (lw6gfx_backend_t * backend, lw6gui_keypress_t * keypress)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->poll_key)
     {
       ret = backend->poll_key (backend->gfx_context, keypress);
     }
   else
     {
-      warning ("poll_key");
+      _warning ("poll_key");
     }
 
   return ret;
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
 
 int
@@ -79,15 +94,19 @@ lw6gfx_is_key_esc (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->is_key_esc)
     {
       ret = backend->is_key_esc (backend->gfx_context, keysym);
     }
   else
     {
-      warning ("is_key_esc");
+      _warning ("is_key_esc");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -96,15 +115,19 @@ lw6gfx_is_key_enter (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->is_key_enter)
     {
       ret = backend->is_key_enter (backend->gfx_context, keysym);
     }
   else
     {
-      warning ("is_key_enter");
+      _warning ("is_key_enter");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -113,15 +136,19 @@ lw6gfx_is_key_up (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->is_key_up)
     {
       ret = backend->is_key_up (backend->gfx_context, keysym);
     }
   else
     {
-      warning ("is_key_up");
+      _warning ("is_key_up");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -130,15 +157,19 @@ lw6gfx_is_key_down (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->is_key_down)
     {
       ret = backend->is_key_down (backend->gfx_context, keysym);
     }
   else
     {
-      warning ("is_key_down");
+      _warning ("is_key_down");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -147,15 +178,19 @@ lw6gfx_is_key_left (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->is_key_left)
     {
       ret = backend->is_key_left (backend->gfx_context, keysym);
     }
   else
     {
-      warning ("is_key_left");
+      _warning ("is_key_left");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -164,15 +199,19 @@ lw6gfx_is_key_right (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->is_key_right)
     {
       ret = backend->is_key_right (backend->gfx_context, keysym);
     }
   else
     {
-      warning ("is_key_right");
+      _warning ("is_key_right");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -181,29 +220,37 @@ lw6gfx_poll_quit (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->poll_quit)
     {
       ret = backend->poll_quit (backend->gfx_context);
     }
   else
     {
-      warning ("poll_quit");
+      _warning ("poll_quit");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
 void
 lw6gfx_send_quit (lw6gfx_backend_t * backend)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->send_quit)
     {
       backend->send_quit (backend->gfx_context);
     }
   else
     {
-      warning ("send_quit");
+      _warning ("send_quit");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
 
 int
@@ -211,15 +258,19 @@ lw6gfx_get_key_state (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->get_key_state)
     {
       ret = backend->get_key_state (backend->gfx_context, keysym);
     }
   else
     {
-      warning ("get_key_state");
+      _warning ("get_key_state");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -228,15 +279,19 @@ lw6gfx_poll_mouse_move (lw6gfx_backend_t * backend, int *x, int *y)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->poll_mouse_move)
     {
       ret = backend->poll_mouse_move (backend->gfx_context, x, y);
     }
   else
     {
-      warning ("poll_mouse_move");
+      _warning ("poll_mouse_move");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -245,15 +300,19 @@ lw6gfx_poll_mouse_button_left (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->poll_mouse_button_left)
     {
       ret = backend->poll_mouse_button_left (backend->gfx_context);
     }
   else
     {
-      warning ("poll_mouse_button_left");
+      _warning ("poll_mouse_button_left");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -262,15 +321,19 @@ lw6gfx_poll_mouse_button_right (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->poll_mouse_button_right)
     {
       ret = backend->poll_mouse_button_right (backend->gfx_context);
     }
   else
     {
-      warning ("poll_mouse_button_right");
+      _warning ("poll_mouse_button_right");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -279,15 +342,19 @@ lw6gfx_poll_mouse_wheel_up (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->poll_mouse_wheel_up)
     {
       ret = backend->poll_mouse_wheel_up (backend->gfx_context);
     }
   else
     {
-      warning ("poll_mouse_wheel_up");
+      _warning ("poll_mouse_wheel_up");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -296,15 +363,19 @@ lw6gfx_poll_mouse_wheel_down (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->poll_mouse_wheel_down)
     {
       ret = backend->poll_mouse_wheel_down (backend->gfx_context);
     }
   else
     {
-      warning ("poll_mouse_wheel_down");
+      _warning ("poll_mouse_wheel_down");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -312,6 +383,8 @@ void
 lw6gfx_get_mouse_state (lw6gfx_backend_t * backend, int *x, int *y,
 			int *button_left, int *button_right)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->get_mouse_state)
     {
       backend->get_mouse_state (backend->gfx_context, x, y, button_left,
@@ -319,8 +392,10 @@ lw6gfx_get_mouse_state (lw6gfx_backend_t * backend, int *x, int *y,
     }
   else
     {
-      warning ("get_mouse_state");
+      _warning ("get_mouse_state");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
 
 int
@@ -328,15 +403,19 @@ lw6gfx_poll_joystick_up (lw6gfx_backend_t * backend, int i)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->poll_joystick_up)
     {
       ret = backend->poll_joystick_up (backend->gfx_context, i);
     }
   else
     {
-      warning ("poll_joystick_up");
+      _warning ("poll_joystick_up");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -345,15 +424,19 @@ lw6gfx_poll_joystick_down (lw6gfx_backend_t * backend, int i)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->poll_joystick_down)
     {
       ret = backend->poll_joystick_down (backend->gfx_context, i);
     }
   else
     {
-      warning ("poll_joystick_down");
+      _warning ("poll_joystick_down");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -362,15 +445,19 @@ lw6gfx_poll_joystick_left (lw6gfx_backend_t * backend, int i)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->poll_joystick_left)
     {
       ret = backend->poll_joystick_left (backend->gfx_context, i);
     }
   else
     {
-      warning ("poll_joystick_left");
+      _warning ("poll_joystick_left");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -379,124 +466,138 @@ lw6gfx_poll_joystick_right (lw6gfx_backend_t * backend, int i)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->poll_joystick_right)
     {
       ret = backend->poll_joystick_right (backend->gfx_context, i);
     }
   else
     {
-      warning ("poll_joystick_right");
+      _warning ("poll_joystick_right");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
 int
-lw6gfx_poll_joystick_button_a (lw6gfx_backend_t * backend, int i)
+lw6gfx_poll_joystick_button (lw6gfx_backend_t * backend, int i, int b)
 {
   int ret = 0;
 
-  if (backend->poll_joystick_button_a)
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
+  if (backend->poll_joystick_button)
     {
-      ret = backend->poll_joystick_button_a (backend->gfx_context, i);
+      ret = backend->poll_joystick_button (backend->gfx_context, i, b);
     }
   else
     {
-      warning ("poll_joystick_button_a");
+      _warning ("poll_joystick_button");
     }
 
-  return ret;
-}
-
-int
-lw6gfx_poll_joystick_button_b (lw6gfx_backend_t * backend, int i)
-{
-  int ret = 0;
-
-  if (backend->poll_joystick_button_b)
-    {
-      ret = backend->poll_joystick_button_b (backend->gfx_context, i);
-    }
-  else
-    {
-      warning ("poll_joystick_button_b");
-    }
+  LW6SYS_BACKEND_FUNCION_END;
 
   return ret;
 }
 
 void
 lw6gfx_get_joystick_state (lw6gfx_backend_t * backend, int *x, int *y,
-			   int *button_a, int *button_b, int i)
+			   int *button, int i, int b)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->get_joystick_state)
     {
-      backend->get_joystick_state (backend->gfx_context, x, y, button_a,
-				   button_b, i);
+      backend->get_joystick_state (backend->gfx_context, x, y, button, i, b);
     }
   else
     {
-      warning ("get_joystick_state");
+      _warning ("get_joystick_state");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
 
 void
 lw6gfx_display_log (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 		    char **log_list)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->display_log)
     {
       backend->display_log (backend->gfx_context, look, log_list);
     }
   else
     {
-      warning ("display_log");
+      _warning ("display_log");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
+
 void
 lw6gfx_display_fps (lw6gfx_backend_t * backend, lw6gui_look_t * look, int fps)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->display_fps)
     {
       backend->display_fps (backend->gfx_context, look, fps);
     }
   else
     {
-      warning ("display_fps");
+      _warning ("display_fps");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
+
 void
 lw6gfx_display_map_preview (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 			    lw6map_level_t * level)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->display_map_preview)
     {
       backend->display_map_preview (backend->gfx_context, look, level);
     }
   else
     {
-      warning ("display_map_preview");
+      _warning ("display_map_preview");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
 
 void
 lw6gfx_display_map_zones (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 			  lw6ker_game_struct_t * game_struct)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->display_map_zones)
     {
       backend->display_map_zones (backend->gfx_context, look, game_struct);
     }
   else
     {
-      warning ("display_map_zones");
+      _warning ("display_map_zones");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
 
 void
 lw6gfx_display_map_gradient (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 			     lw6ker_game_state_t * game_state, int team_id)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->display_map_gradient)
     {
       backend->display_map_gradient (backend->gfx_context, look, game_state,
@@ -504,22 +605,28 @@ lw6gfx_display_map_gradient (lw6gfx_backend_t * backend, lw6gui_look_t * look,
     }
   else
     {
-      warning ("display_map_gradient");
+      _warning ("display_map_gradient");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
 
 void
 lw6gfx_display_game (lw6gfx_backend_t * backend,
 		     lw6gui_look_t * look, lw6ker_game_state_t * game_state)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->display_game)
     {
       backend->display_game (backend->gfx_context, look, game_state);
     }
   else
     {
-      warning ("display_game");
+      _warning ("display_game");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
 
 void
@@ -528,6 +635,8 @@ lw6gfx_pick_map_coord (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 		       lw6ker_game_state_t * game_state, int screen_x,
 		       int screen_y)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->pick_map_coord)
     {
       backend->pick_map_coord (backend->gfx_context, look, map_x, map_y,
@@ -535,22 +644,28 @@ lw6gfx_pick_map_coord (lw6gfx_backend_t * backend, lw6gui_look_t * look,
     }
   else
     {
-      warning ("pick_map_coord");
+      _warning ("pick_map_coord");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
 
 void
 lw6gfx_display_menu (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 		     lw6gui_menu_t * menu)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->display_menu)
     {
       backend->display_menu (backend->gfx_context, look, menu);
     }
   else
     {
-      warning ("display_menu");
+      _warning ("display_menu");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
 
 void
@@ -558,6 +673,8 @@ lw6gfx_pick_menuitem (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 		      int *position, int *scroll, lw6gui_menu_t * menu,
 		      int screen_x, int screen_y)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->pick_menuitem)
     {
       backend->pick_menuitem (backend->gfx_context, look, position, scroll,
@@ -565,8 +682,10 @@ lw6gfx_pick_menuitem (lw6gfx_backend_t * backend, lw6gui_look_t * look,
     }
   else
     {
-      warning ("pick_menuitem");
+      _warning ("pick_menuitem");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
 
 int
@@ -576,6 +695,8 @@ lw6gfx_warp_mouse_on_menuitem (lw6gfx_backend_t * backend,
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->warp_mouse_on_menuitem)
     {
       ret = backend->warp_mouse_on_menuitem (backend->gfx_context, look, menu,
@@ -583,42 +704,56 @@ lw6gfx_warp_mouse_on_menuitem (lw6gfx_backend_t * backend,
     }
   else
     {
-      warning ("warp_mouse_on_menuitem");
+      _warning ("warp_mouse_on_menuitem");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
 void
 lw6gfx_prepare_buffer (lw6gfx_backend_t * backend, lw6gui_look_t * look)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->prepare_buffer)
     {
       backend->prepare_buffer (backend->gfx_context, look);
     }
   else
     {
-      warning ("prepare_buffer");
+      _warning ("prepare_buffer");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
+
 void
 lw6gfx_swap_buffers (lw6gfx_backend_t * backend)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->swap_buffers)
     {
       backend->swap_buffers (backend->gfx_context);
     }
   else
     {
-      warning ("swap_buffers");
+      _warning ("swap_buffers");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
+
 int
 lw6gfx_init (lw6gfx_backend_t * backend, int width,
 	     int height, int fullscreen,
 	     void (*resize_callback) (int width, int height, int fullscreen),
 	     int ticks)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->init)
     {
       backend->gfx_context =
@@ -627,12 +762,68 @@ lw6gfx_init (lw6gfx_backend_t * backend, int width,
     }
   else
     {
-      warning ("init");
+      _warning ("init");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return backend->gfx_context ? 1 : 0;
 }
 
+void
+lw6gfx_get_low_resolution (lw6gfx_backend_t * backend, int *width,
+			   int *height)
+{
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
+  if (backend->get_low_resolution)
+    {
+      backend->get_low_resolution (backend->gfx_context, width, height);
+    }
+  else
+    {
+      _warning ("get_low_resolution");
+    }
+
+  LW6SYS_BACKEND_FUNCION_END;
+}
+
+void
+lw6gfx_get_standard_resolution (lw6gfx_backend_t * backend, int *width,
+				int *height)
+{
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
+  if (backend->get_standard_resolution)
+    {
+      backend->get_standard_resolution (backend->gfx_context, width, height);
+    }
+  else
+    {
+      _warning ("get_standard_resolution");
+    }
+
+  LW6SYS_BACKEND_FUNCION_END;
+}
+
+void
+lw6gfx_get_high_resolution (lw6gfx_backend_t * backend, int *width,
+			    int *height)
+{
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
+  if (backend->get_high_resolution)
+    {
+      backend->get_high_resolution (backend->gfx_context, width, height);
+    }
+  else
+    {
+      _warning ("get_high_resolution");
+    }
+
+  LW6SYS_BACKEND_FUNCION_END;
+}
+
 int
 lw6gfx_set_video_mode (lw6gfx_backend_t * backend, int width, int height,
 		       int fullscreen, void (*resize_callback) (int width,
@@ -642,6 +833,8 @@ lw6gfx_set_video_mode (lw6gfx_backend_t * backend, int width, int height,
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->set_video_mode)
     {
       ret =
@@ -650,9 +843,11 @@ lw6gfx_set_video_mode (lw6gfx_backend_t * backend, int width, int height,
     }
   else
     {
-      warning ("set_video_mode");
+      _warning ("set_video_mode");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
@@ -662,6 +857,8 @@ lw6gfx_get_video_mode (lw6gfx_backend_t * backend, int *width, int *height,
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->get_video_mode)
     {
       ret =
@@ -670,15 +867,19 @@ lw6gfx_get_video_mode (lw6gfx_backend_t * backend, int *width, int *height,
     }
   else
     {
-      warning ("get_video_mode");
+      _warning ("get_video_mode");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
 
 void
 lw6gfx_quit (lw6gfx_backend_t * backend)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->quit)
     {
       backend->quit (backend->gfx_context);
@@ -686,34 +887,46 @@ lw6gfx_quit (lw6gfx_backend_t * backend)
     }
   else
     {
-      warning ("quit");
+      _warning ("quit");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
+
 void
 lw6gfx_delay (lw6gfx_backend_t * backend, int ms)
 {
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->delay)
     {
       backend->delay (backend->gfx_context, ms);
     }
   else
     {
-      warning ("delay");
+      _warning ("delay");
     }
+
+  LW6SYS_BACKEND_FUNCION_END;
 }
+
 int
 lw6gfx_get_ticks (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
+  LW6SYS_BACKEND_FUNCION_BEGIN;
+
   if (backend->get_ticks)
     {
       ret = backend->get_ticks (backend->gfx_context);
     }
   else
     {
-      warning ("get_ticks");
+      _warning ("get_ticks");
     }
 
+  LW6SYS_BACKEND_FUNCION_END;
+
   return ret;
 }
