@@ -23,10 +23,6 @@
 #ifndef LIQUIDWAR6GFX_MOD_GL_BACKGROUND_BUBBLES_INTERNAL_H
 #define LIQUIDWAR6GFX_MOD_GL_BACKGROUND_BUBBLES_INTERNAL_H
 
-#include <GL/gl.h>
-#include <SDL/SDL.h>
-#include <SDL/SDL_ttf.h>
-
 #include "gl-bubbles.h"
 
 #define _MOD_GL_BACKGROUND_BUBBLES_MAX_BUBBLES 64
@@ -61,6 +57,14 @@ typedef struct _mod_gl_background_bubbles_texture_data_s
 }
 _mod_gl_background_bubbles_texture_data_t;
 
+typedef struct _mod_gl_background_bubbles_lastest_colors_s
+{
+  int colorize;
+  lw6map_color_couple_t base;
+  lw6map_color_couple_t alternate;
+}
+_mod_gl_background_bubbles_latest_colors_t;
+
 typedef struct _mod_gl_background_bubbles_const_data_s
 {
   int nb_bubbles;
@@ -68,12 +72,6 @@ typedef struct _mod_gl_background_bubbles_const_data_s
   float bubble_yspeed;
   float bubble_size_min;
   float bubble_size_max;
-  lw6sys_color_f_t menu_fg;
-  lw6sys_color_f_t menu_bg;
-  lw6sys_color_f_t menu_fg_disabled;
-  lw6sys_color_f_t menu_bg_disabled;
-  lw6sys_color_f_t menu_fg_selected;
-  lw6sys_color_f_t menu_bg_selected;
 }
 _mod_gl_background_bubbles_const_data_t;
 
@@ -82,10 +80,24 @@ typedef struct _mod_gl_background_bubbles_context_s
   _mod_gl_background_bubbles_state_t state;
   _mod_gl_background_bubbles_image_data_t image_data;
   _mod_gl_background_bubbles_texture_data_t texture_data;
+  _mod_gl_background_bubbles_latest_colors_t latest_colors;
   _mod_gl_background_bubbles_const_data_t const_data;
 }
 _mod_gl_background_bubbles_context_t;
 
+// gl-bubbles-colorize.c
+extern int
+_mod_gl_background_bubbles_colorize_if_needed (mod_gl_utils_context_t *
+					       utils_context,
+					       _mod_gl_background_bubbles_context_t
+					       * bubbles_context,
+					       lw6gui_look_t * look);
+extern int _mod_gl_background_bubbles_colorize (mod_gl_utils_context_t *
+						utils_context,
+						_mod_gl_background_bubbles_context_t
+						* bubbles_context,
+						lw6gui_look_t * look);
+
 /*
  * In display.c
  */
