@@ -23,10 +23,6 @@
 #ifndef LIQUIDWAR6GFX_MOD_GL_HUD_FLOATING_INTERNAL_H
 #define LIQUIDWAR6GFX_MOD_GL_HUD_FLOATING_INTERNAL_H
 
-#include <GL/gl.h>
-#include <SDL/SDL.h>
-#include <SDL/SDL_ttf.h>
-
 #include "gl-floating.h"
 
 typedef struct _mod_gl_hud_floating_const_data_s
