@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,12 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
-#include <GL/glu.h>
-#include <SDL/SDL_image.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "../../../gfx.h"
 #include "../../../../cfg/cfg.h"
 #include "gl-tactical.h"
@@ -73,8 +70,8 @@ load_consts (mod_gl_utils_context_t * utils_context,
 
       ret =
 	lw6cfg_read_key_value_xml_file (const_file, read_callback,
-					(void *) &(tactical_context->
-						   const_data));
+					(void *)
+					&(tactical_context->const_data));
 
       LW6SYS_FREE (const_file);
     }
