@@ -23,10 +23,6 @@
 #ifndef LIQUIDWAR6GFX_MOD_GL_HUD_TACTICAL_INTERNAL_H
 #define LIQUIDWAR6GFX_MOD_GL_HUD_TACTICAL_INTERNAL_H
 
-#include <GL/gl.h>
-#include <SDL/SDL.h>
-#include <SDL/SDL_ttf.h>
-
 #include "gl-tactical.h"
 
 typedef struct _mod_gl_hud_tactical_image_data_s
