@@ -20,11 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <math.h>
-#include <GL/glu.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
+#include <math.h>
+
 #include "../../mod-gl.h"
 #include "gl-cylinder-internal.h"
 
@@ -124,7 +125,6 @@ get_bg_color (lw6gui_look_t * look, lw6gui_menuitem_t * menuitem)
   return color;
 }
 
-
 /*
  * Draw a basic text menu item (button).
  */
@@ -222,7 +222,7 @@ draw_button (mod_gl_utils_context_t * utils_context,
 						       MOD_GL_UTILS_MENU_TEXTURE_H,
 						       menuitem->label,
 						       lw6gui_menuitem_checksum
-						       (menuitem));
+						       (menuitem, look));
       if (text_texture)
 	{
 	  glEnable (GL_TEXTURE_2D);
