@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,11 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <math.h>
-#include <GL/glu.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
+#include <math.h>
+
 #include "../../mod-gl.h"
 #include "gl-cylinder-internal.h"
 
