@@ -20,9 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "../../gfx.h"
 #include "gl-utils.h"
 #include "gl-utils-internal.h"
@@ -143,6 +144,24 @@ check_joystick_index (int i)
   return ret;
 }
 
+static int
+check_joystick_button_index (int b)
+{
+  int ret = 0;
+
+  if (b >= 0 && b < MOD_GL_NB_JOYSTICK_BUTTONS)
+    {
+      ret = 1;
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("joystick button index %d out of range"), b);
+    }
+
+  return ret;
+}
+
 void
 update_joystick_axis (mod_gl_utils_context_t * utils_context, int which,
 		      int axis, int value)
@@ -231,50 +250,152 @@ update_joystick_axis (mod_gl_utils_context_t * utils_context, int which,
 
 void
 joystick_button_down (mod_gl_utils_joysticks_state_t * joysticks_state,
-		      int which, int button)
+		      int i, int b)
 {
   mod_gl_utils_joystick_state_t *joystick_state;
 
-  if (check_joystick_index (which))
+  if (check_joystick_index (i))
     {
-      joystick_state = &(joysticks_state->joystick_state[which]);
+      joystick_state = &(joysticks_state->joystick_state[i]);
 
-      switch (button)
+      if (check_joystick_button_index (b))
 	{
-	case 0:
-	  joystick_state->button_a.pressed = 1;
-	  joystick_state->button_a.queue++;
-	  break;
-	case 1:
-	  joystick_state->button_b.pressed = 1;
-	  joystick_state->button_b.queue++;
-	  break;
+	  joystick_state->buttons[b].pressed = 1;
+	  joystick_state->buttons[b].queue++;
 	}
     }
 }
 
 void
 joystick_button_up (mod_gl_utils_joysticks_state_t * joysticks_state,
-		    int which, int button)
+		    int i, int b)
 {
   mod_gl_utils_joystick_state_t *joystick_state;
 
-  if (check_joystick_index (which))
+  if (check_joystick_index (i))
     {
-      joystick_state = &(joysticks_state->joystick_state[which]);
+      joystick_state = &(joysticks_state->joystick_state[i]);
 
-      switch (button)
+      if (check_joystick_button_index (b))
 	{
-	case 0:
-	  joystick_state->button_a.pressed = 0;
-	  break;
-	case 1:
-	  joystick_state->button_b.pressed = 0;
-	  break;
+	  joystick_state->buttons[b].pressed = 0;
 	}
     }
 }
 
+static void
+log_event (SDL_Event * event)
+{
+  switch (event->type)
+    {
+    case SDL_ACTIVEEVENT:
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _("SDL event type=SDL_ACTIVEEVENT gain=%d state=%d"),
+		  (int) event->active.gain, (int) event->active.state);
+      break;
+    case SDL_KEYDOWN:
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _
+		  ("SDL event type=SDL_KEYDOWN state=%d scancode=%d sym=%d unicode=%d"),
+		  (int) event->key.state,
+		  (int) event->key.keysym.scancode,
+		  (int) event->key.keysym.sym,
+		  (int) event->key.keysym.mod,
+		  (int) event->key.keysym.unicode);
+      break;
+    case SDL_KEYUP:
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _
+		  ("SDL event type=SDL_KEYUP state=%d scancode=%d sym=%d unicode=%d"),
+		  (int) event->key.state,
+		  (int) event->key.keysym.scancode,
+		  (int) event->key.keysym.sym,
+		  (int) event->key.keysym.mod,
+		  (int) event->key.keysym.unicode);
+      break;
+    case SDL_MOUSEMOTION:
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _
+		  ("SDL event type=SDL_MOUSEMOTION state=%d x=%d y=%d xrel=%d yrel=%d"),
+		  (int) event->motion.state, (int) event->motion.x,
+		  (int) event->motion.y, (int) event->motion.xrel,
+		  (int) event->motion.yrel);
+      break;
+    case SDL_MOUSEBUTTONDOWN:
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _
+		  ("SDL event type=SDL_MOUSEBUTTONDOWN button=%d state=%d x=%d y=%d"),
+		  (int) event->button.button, (int) event->button.state,
+		  (int) event->motion.x, (int) event->motion.y);
+      break;
+    case SDL_MOUSEBUTTONUP:
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _
+		  ("SDL event type=SDL_MOUSEBUTTONUP button=%d state=%d x=%d y=%d"),
+		  (int) event->button.button, (int) event->button.state,
+		  (int) event->motion.x, (int) event->motion.y);
+      break;
+    case SDL_JOYAXISMOTION:
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _
+		  ("SDL event type=SDL_JOYAXISMOTION which=%d axis=%d value=%d"),
+		  (int) event->jaxis.which, event->jaxis.axis,
+		  (int) event->jaxis.value);
+      break;
+    case SDL_JOYBALLMOTION:
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _
+		  ("SDL event type=SDL_JOYBALLMOTION which=%d ball=%d xrel=%d yrel=%d"),
+		  (int) event->jball.which, (int) event->jball.ball,
+		  (int) event->jball.xrel, (int) event->jball.yrel);
+      break;
+    case SDL_JOYHATMOTION:
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _
+		  ("SDL event type=SDL_JOYHATMOTION which=%d hat=%d value=%d"),
+		  (int) event->jhat.which, (int) event->jhat.hat,
+		  (int) event->jhat.value);
+      break;
+    case SDL_JOYBUTTONDOWN:
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _
+		  ("SDL event type=SDL_JOYBUTTONDOWN which=%d button=%d state=%d"),
+		  (int) event->jbutton.which, (int) event->jbutton.button,
+		  (int) event->jbutton.state);
+      break;
+    case SDL_JOYBUTTONUP:
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _
+		  ("SDL event type=SDL_JOYBUTTONUP which=%d button=%d state=%d"),
+		  (int) event->jbutton.which, (int) event->jbutton.button,
+		  (int) event->jbutton.state);
+      break;
+    case SDL_QUIT:
+      lw6sys_log (LW6SYS_LOG_DEBUG, _("SDL event type=SDL_QUIT"));
+      break;
+    case SDL_SYSWMEVENT:
+      lw6sys_log (LW6SYS_LOG_DEBUG, _("SDL event type=SDL_SYSWMEVENT"));
+      break;
+    case SDL_VIDEORESIZE:
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _("SDL event type=SDL_VIDEORESIZE w=%d h=%d"),
+		  (int) event->resize.w, (int) event->resize.h);
+      break;
+    case SDL_VIDEOEXPOSE:
+      lw6sys_log (LW6SYS_LOG_DEBUG, _("SDL event type=SDL_VIDEOEXPOSE"));
+      break;
+    case SDL_USEREVENT:
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _("SDL event type=SDL_USEREVENT code=%d"),
+		  (int) event->user.code);
+      break;
+    default:
+// should never get there, unless API changes...
+      lw6sys_log (LW6SYS_LOG_WARNING, _("SDL event with unknown type=%d"),
+		  event->type);
+    }
+}
+
 /*
  * Internal poll function.
  */
@@ -294,6 +415,7 @@ poll (mod_gl_utils_context_t * utils_context)
 
   if (ret)
     {
+      log_event (&event);
       switch (event.type)
 	{
 	case SDL_KEYDOWN:
@@ -336,6 +458,9 @@ poll (mod_gl_utils_context_t * utils_context)
 	  mod_gl_utils_resize_video_mode (utils_context, event.resize.w,
 					  event.resize.h);
 	  break;
+	case SDL_VIDEOEXPOSE:
+	  mod_gl_utils_sync_mode (utils_context);
+	  break;
 	}
     }
 
@@ -532,8 +657,9 @@ mod_gl_utils_poll_mouse_wheel_down (mod_gl_utils_context_t * utils_context)
 }
 
 void
-mod_gl_utils_get_mouse_state (mod_gl_utils_context_t * utils_context, int *x,
-			      int *y, int *button_left, int *button_right)
+mod_gl_utils_get_mouse_state (mod_gl_utils_context_t * utils_context,
+			      int *x, int *y, int *button_left,
+			      int *button_right)
 {
   mod_gl_utils_mouse_state_t *mouse_state = &utils_context->mouse_state;
 
@@ -645,43 +771,21 @@ mod_gl_utils_poll_joystick_right (mod_gl_utils_context_t * utils_context,
 }
 
 int
-mod_gl_utils_poll_joystick_button_a (mod_gl_utils_context_t *
-				     utils_context, int i)
+mod_gl_utils_poll_joystick_button (mod_gl_utils_context_t *
+				   utils_context, int i, int b)
 {
   int ret = 0;
 
   if (utils_context->joysticks_state.supported)
     {
-      if (check_joystick_index (i))
+      if (check_joystick_index (i) && check_joystick_button_index (b))
 	{
 	  poll (utils_context);
 
 	  ret =
 	    poll_button (&
 			 (utils_context->joysticks_state.joystick_state[i].
-			  button_a));
-	}
-    }
-
-  return ret;
-}
-
-int
-mod_gl_utils_poll_joystick_button_b (mod_gl_utils_context_t *
-				     utils_context, int i)
-{
-  int ret = 0;
-
-  if (utils_context->joysticks_state.supported)
-    {
-      if (check_joystick_index (i))
-	{
-	  poll (utils_context);
-
-	  ret =
-	    poll_button (&
-			 (utils_context->joysticks_state.joystick_state[i].
-			  button_b));
+			  buttons[b]));
 	}
     }
 
@@ -691,7 +795,7 @@ mod_gl_utils_poll_joystick_button_b (mod_gl_utils_context_t *
 void
 mod_gl_utils_get_joystick_state (mod_gl_utils_context_t *
 				 utils_context, int *x, int *y,
-				 int *button_a, int *button_b, int i)
+				 int *button, int i, int b)
 {
   SDL_Joystick *joystick = NULL;
   int num_axes;
@@ -700,8 +804,7 @@ mod_gl_utils_get_joystick_state (mod_gl_utils_context_t *
 
   (*x) = 0;
   (*y) = 0;
-  (*button_a) = 0;
-  (*button_b) = 0;
+  (*button) = 0;
 
   if (utils_context->joysticks_state.supported)
     {
@@ -752,30 +855,21 @@ mod_gl_utils_get_joystick_state (mod_gl_utils_context_t *
 			  num_axes, i);
 	    }
 
-	  num_buttons = SDL_JoystickNumButtons (joystick);
+	  if (check_joystick_button_index (b))
+	    {
+	      num_buttons = SDL_JoystickNumButtons (joystick);
 
-	  if (num_buttons >= 1)
-	    {
-	      (*button_a) = SDL_JoystickGetButton (joystick, 0);
-	    }
-	  else
-	    {
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _
-			  ("only %d buttons for joystick %d, button a can't be fetched"),
-			  num_buttons, i);
-	    }
-
-	  if (num_buttons >= 1)
-	    {
-	      (*button_b) = SDL_JoystickGetButton (joystick, 1);
-	    }
-	  else
-	    {
-	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _
-			  ("only %d buttons for joystick %d, button b can't be fetched"),
-			  num_buttons, i);
+	      if (num_buttons >= b)
+		{
+		  (*button) = SDL_JoystickGetButton (joystick, b);
+		}
+	      else
+		{
+		  lw6sys_log (LW6SYS_LOG_INFO,
+			      _
+			      ("only %d buttons for joystick %d, button %d can't be fetched"),
+			      num_buttons, i, b);
+		}
 	    }
 	}
     }
