@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,12 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
-#include <GL/glu.h>
-#include <SDL/SDL_image.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
+#include <string.h>
+
 #include "../../gfx.h"
 #include "gl-utils.h"
 #include "gl-utils-internal.h"
@@ -52,7 +51,14 @@ mod_gl_utils_set_video_mode (mod_gl_utils_context_t * utils_context,
   /* Let's get some video information. */
   info = SDL_GetVideoInfo ();
 
-  if (!info)
+  if (info)
+    {
+      lw6sys_log (LW6SYS_LOG_INFO,
+		  _
+		  ("SDL VideoInfo hw_available=%d wm_available=%d video_mem=%dkb"),
+		  info->hw_available, info->wm_available, info->video_mem);
+    }
+  else
     {
       /* This should probably never happen. */
       lw6sys_log (LW6SYS_LOG_ERROR,
@@ -87,6 +93,17 @@ mod_gl_utils_set_video_mode (mod_gl_utils_context_t * utils_context,
 
   flags = SDL_OPENGL | (fullscreen ? SDL_FULLSCREEN : SDL_RESIZABLE);
 
+  if (width <= 0 || height <= 0)
+    {
+      mod_gl_utils_get_standard_resolution (utils_context, &width, &height);
+    }
+
+  if (fullscreen)
+    {
+      mod_gl_utils_find_closest_resolution (utils_context, &width, &height,
+					    width, height);
+    }
+
   /*
    * Set the video mode
    */
@@ -98,20 +115,20 @@ mod_gl_utils_set_video_mode (mod_gl_utils_context_t * utils_context,
        * resolution not being available, etc.
        */
       lw6sys_log (LW6SYS_LOG_ERROR,
-		  _("SDL SetVideoMode %dx%d failed: \"%s\""), width,
-		  height, SDL_GetError ());
+		  _("SDL SetVideoMode %dx%d fullscreen=%d failed: \"%s\""),
+		  width, height, fullscreen, SDL_GetError ());
       fflush (stderr);
       return 0;
     }
   else
     {
-      glViewport (0, 0, width, height);	// required by some drivers
-      lw6sys_log (LW6SYS_LOG_INFO, _("SDL SetVideoMode %dx%d"),
-		  width, height);
+      lw6sys_log (LW6SYS_LOG_INFO, _("SDL SetVideoMode %dx%d fullscreen=%d"),
+		  width, height, fullscreen);
       utils_context->screen.width = width;
       utils_context->screen.height = height;
       utils_context->screen.bpp = bpp;
       utils_context->screen.fullscreen = fullscreen;
+      mod_gl_utils_sync_viewport (utils_context);
 
       glGetIntegerv (GL_MAX_TEXTURE_SIZE,
 		     &(utils_context->caps.max_texture_size));
@@ -168,34 +185,32 @@ mod_gl_utils_resize_video_mode (mod_gl_utils_context_t * utils_context,
 				int width, int height)
 {
   int ret = 0;
+  int fullscreen = 0;
 
+  fullscreen = utils_context->screen.fullscreen;
   if (width != utils_context->screen.width
       || height != utils_context->screen.height)
     {
       int flags = 0;
 
-      flags =
-	SDL_OPENGL | (utils_context->screen.
-		      fullscreen ? SDL_FULLSCREEN : SDL_RESIZABLE);
+      flags = SDL_OPENGL | (fullscreen ? SDL_FULLSCREEN : SDL_RESIZABLE);
 
       if (SDL_SetVideoMode (width, height, utils_context->screen.bpp, flags)
 	  == 0)
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("unable to resize screen %dx%d"), width, height);
+		      _("unable to resize screen %dx%d fullscreen=%d"), width,
+		      height, fullscreen);
 	}
       else
 	{
-	  glViewport (0, 0, width, height);
 	  utils_context->screen.width = width;
 	  utils_context->screen.height = height;
+	  mod_gl_utils_sync_viewport (utils_context);
 
 	  if (utils_context->resize_callback)
 	    {
-	      utils_context->resize_callback (width,
-					      height,
-					      utils_context->screen.
-					      fullscreen);
+	      utils_context->resize_callback (width, height, fullscreen);
 	    }
 
 	  lw6sys_log (LW6SYS_LOG_INFO,
@@ -229,3 +244,47 @@ mod_gl_utils_get_video_mode (mod_gl_utils_context_t * utils_context,
 
   return ret;
 }
+
+/*
+ * Update viewport
+ */
+int
+mod_gl_utils_sync_viewport (mod_gl_utils_context_t * utils_context)
+{
+  int ret = 1;
+
+  glViewport (0, 0, utils_context->screen.width,
+	      utils_context->screen.height);
+
+  return ret;
+}
+
+/*
+ * Force mode.
+ */
+int
+mod_gl_utils_sync_mode (mod_gl_utils_context_t * utils_context)
+{
+  int ret = 0;
+  int width;
+  int height;
+  int fullscreen;
+  int flags;
+
+  mod_gl_utils_get_video_mode (utils_context, &width, &height, &fullscreen);
+  flags = SDL_OPENGL | (fullscreen ? SDL_FULLSCREEN : SDL_RESIZABLE);
+
+  if (SDL_SetVideoMode (width, height, utils_context->screen.bpp, flags) == 0)
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable to sync screen %dx%d fullscreen=%d"), width,
+		  height, fullscreen);
+    }
+  else
+    {
+      mod_gl_utils_sync_viewport (utils_context);
+      ret = 1;
+    }
+
+  return ret;
+}
