@@ -20,11 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
-#include <GL/glu.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "../../gfx.h"
 #include "gl-utils.h"
 #include "gl-utils-internal.h"
