@@ -23,11 +23,16 @@
 #ifndef LIQUIDWAR6GFX_MOD_GL_UTILS_H
 #define LIQUIDWAR6GFX_MOD_GL_UTILS_H
 
-#include <GL/gl.h>
+#include "../../gfx.h"
+
 #include <SDL/SDL.h>
+#include <SDL/SDL_opengl.h>
+#include <SDL/SDL_image.h>
 #include <SDL/SDL_ttf.h>
 
-#include "../../gfx.h"
+#ifndef GL_CLAMP_TO_EDGE
+#define GL_CLAMP_TO_EDGE GL_CLAMP
+#endif
 
 #define MOD_GL_UTILS_MENU_TEXTURE_W 512
 #define MOD_GL_UTILS_MENU_TEXTURE_H 128
@@ -76,7 +81,8 @@
  */
 #define MOD_GL_SHADES_FOR_FIGHTERS_SCALE 64
 
-#define MOD_GL_NB_JOYSTICKS 2
+#define MOD_GL_NB_JOYSTICKS 4
+#define MOD_GL_NB_JOYSTICK_BUTTONS 6
 
 typedef struct mod_gl_utils_path_s
 {
@@ -177,8 +183,7 @@ typedef struct mod_gl_utils_joystick_state_s
   mod_gl_utils_button_state_t down;
   mod_gl_utils_button_state_t left;
   mod_gl_utils_button_state_t right;
-  mod_gl_utils_button_state_t button_a;
-  mod_gl_utils_button_state_t button_b;
+  mod_gl_utils_button_state_t buttons[MOD_GL_NB_JOYSTICK_BUTTONS];
   SDL_Joystick *sdl_joystick;
 }
 mod_gl_utils_joystick_state_t;
@@ -353,11 +358,18 @@ mod_gl_utils_get_shaded_color_for_fighter (mod_gl_utils_context_t *
 					   utils_context, int team_id,
 					   int health)
 {
-  return utils_context->team_color_map.
-    team_colors[team_id][(health * MOD_GL_SHADES_FOR_FIGHTERS_SCALE) /
-			 LW6MAP_MAX_FIGHTER_HEALTH];
+  return utils_context->team_color_map.team_colors[team_id][(health *
+							     MOD_GL_SHADES_FOR_FIGHTERS_SCALE)
+							    /
+							    LW6MAP_MAX_FIGHTER_HEALTH];
 }
 
+// gl-utils-colorize.c
+extern SDL_Surface *mod_gl_utils_colorize_image (mod_gl_utils_context_t *
+						 utils_context,
+						 SDL_Surface * image,
+						 lw6map_color_couple_t *
+						 color);
 
 /*
  * In data.c
@@ -423,14 +435,11 @@ extern int mod_gl_utils_poll_joystick_left (mod_gl_utils_context_t *
 					    utils_context, int i);
 extern int mod_gl_utils_poll_joystick_right (mod_gl_utils_context_t *
 					     utils_context, int i);
-extern int mod_gl_utils_poll_joystick_button_a (mod_gl_utils_context_t *
-						utils_context, int i);
-extern int mod_gl_utils_poll_joystick_button_b (mod_gl_utils_context_t *
-						utils_context, int i);
+extern int mod_gl_utils_poll_joystick_button (mod_gl_utils_context_t *
+					      utils_context, int i, int b);
 extern void mod_gl_utils_get_joystick_state (mod_gl_utils_context_t *
 					     utils_context, int *x, int *y,
-					     int *button_a,
-					     int *button_b, int i);
+					     int *button, int i, int b);
 
 /*
  * In font.c
@@ -532,6 +541,9 @@ extern int mod_gl_utils_resize_video_mode (mod_gl_utils_context_t *
 extern int mod_gl_utils_get_video_mode (mod_gl_utils_context_t *
 					utils_context, int *width,
 					int *height, int *fullscreen);
+extern int mod_gl_utils_sync_viewport (mod_gl_utils_context_t *
+				       utils_context);
+extern int mod_gl_utils_sync_mode (mod_gl_utils_context_t * utils_context);
 
 /*
  * In menucache.c
@@ -597,6 +609,25 @@ extern void mod_gl_utils_set_render_mode_3d_pick (mod_gl_utils_context_t *
 extern void mod_gl_utils_set_render_mode_3d_warp (mod_gl_utils_context_t *
 						  utils_context);
 
+/*
+ * In resolution.c
+ */
+extern void mod_gl_utils_get_low_resolution (mod_gl_utils_context_t *
+					     utils_context, int *width,
+					     int *height);
+extern void mod_gl_utils_get_standard_resolution (mod_gl_utils_context_t *
+						  utils_context, int *width,
+						  int *height);
+extern void mod_gl_utils_get_high_resolution (mod_gl_utils_context_t *
+					      utils_context, int *width,
+					      int *height);
+extern void mod_gl_utils_find_closest_resolution (mod_gl_utils_context_t *
+						  utils_context,
+						  int *closest_width,
+						  int *closest_height,
+						  int wished_width,
+						  int wished_height);
+
 /*
  * In setup.c
  */
@@ -669,6 +700,7 @@ mod_gl_utils_set_surface_array_surface (mod_gl_utils_surface_array_t *
 {
   surface_array->surfaces[n_y * surface_array->layout.n_w + n_x] = surface;
 }
+
 static inline SDL_Surface *
 mod_gl_utils_get_surface_array_surface (mod_gl_utils_surface_array_t *
 					surface_array, int n_x, int n_y)
@@ -757,6 +789,7 @@ mod_gl_utils_set_texture_array_texture (mod_gl_utils_texture_array_t *
 {
   texture_array->textures[n_y * texture_array->layout.n_w + n_x] = texture;
 }
+
 static inline GLuint
 mod_gl_utils_get_texture_array_texture (mod_gl_utils_texture_array_t *
 					texture_array, int n_x, int n_y)
