@@ -20,9 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <GL/glu.h>
 
-#include "config.h"
 #include "../../../gfx.h"
 #include "gl-flat.h"
 #include "gl-flat-internal.h"
@@ -416,9 +419,8 @@ _mod_gl_view_flat_display_game (mod_gl_utils_context_t * utils_context,
 
       _mod_gl_view_flat_game_context_update (utils_context,
 					     flat_context,
-					     &flat_context->
-					     game_context, look, level,
-					     game_state);
+					     &flat_context->game_context,
+					     look, level, game_state);
 
       mod_gl_utils_set_render_mode_2d_blend (utils_context);
 
