@@ -23,10 +23,6 @@
 #ifndef LIQUIDWAR6GFX_MOD_GL_VIEW_FLAT_INTERNAL_H
 #define LIQUIDWAR6GFX_MOD_GL_VIEW_FLAT_INTERNAL_H
 
-#include <GL/gl.h>
-#include <SDL/SDL.h>
-#include <SDL/SDL_ttf.h>
-
 #include "gl-flat.h"
 
 typedef struct _mod_gl_view_flat_game_context_map_s
