@@ -20,17 +20,17 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "../gfx.h"
 #include "mod-gl.h"
 #include "mod-gl-internal.h"
 
 
 static void
-display_background (void *gfx_context, lw6gui_look_t * look)
+_display_background (void *gfx_context, lw6gui_look_t * look)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -44,8 +44,8 @@ display_background (void *gfx_context, lw6gui_look_t * look)
 }
 
 static void
-display_hud (void *gfx_context, lw6gui_look_t * look,
-	     lw6ker_game_state_t * game_state)
+_display_hud (void *gfx_context, lw6gui_look_t * look,
+	      lw6ker_game_state_t * game_state)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -59,7 +59,7 @@ display_hud (void *gfx_context, lw6gui_look_t * look,
 }
 
 static int
-poll_key (void *gfx_context, lw6gui_keypress_t * keypress)
+_poll_key (void *gfx_context, lw6gui_keypress_t * keypress)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -74,7 +74,7 @@ poll_key (void *gfx_context, lw6gui_keypress_t * keypress)
 }
 
 static int
-is_key_esc (void *gfx_context, int keysym)
+_is_key_esc (void *gfx_context, int keysym)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -89,7 +89,7 @@ is_key_esc (void *gfx_context, int keysym)
 }
 
 static int
-is_key_enter (void *gfx_context, int keysym)
+_is_key_enter (void *gfx_context, int keysym)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -104,7 +104,7 @@ is_key_enter (void *gfx_context, int keysym)
 }
 
 static int
-is_key_up (void *gfx_context, int keysym)
+_is_key_up (void *gfx_context, int keysym)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -118,7 +118,7 @@ is_key_up (void *gfx_context, int keysym)
 }
 
 static int
-is_key_down (void *gfx_context, int keysym)
+_is_key_down (void *gfx_context, int keysym)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -133,7 +133,7 @@ is_key_down (void *gfx_context, int keysym)
 }
 
 static int
-is_key_left (void *gfx_context, int keysym)
+_is_key_left (void *gfx_context, int keysym)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -148,7 +148,7 @@ is_key_left (void *gfx_context, int keysym)
 }
 
 static int
-is_key_right (void *gfx_context, int keysym)
+_is_key_right (void *gfx_context, int keysym)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -163,7 +163,7 @@ is_key_right (void *gfx_context, int keysym)
 }
 
 static int
-poll_quit (void *gfx_context)
+_poll_quit (void *gfx_context)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -177,7 +177,7 @@ poll_quit (void *gfx_context)
 }
 
 static void
-send_quit (void *gfx_context)
+_send_quit (void *gfx_context)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -188,7 +188,7 @@ send_quit (void *gfx_context)
 }
 
 static int
-get_key_state (void *gfx_context, int keysym)
+_get_key_state (void *gfx_context, int keysym)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -203,7 +203,7 @@ get_key_state (void *gfx_context, int keysym)
 }
 
 static int
-poll_mouse_move (void *gfx_context, int *x, int *y)
+_poll_mouse_move (void *gfx_context, int *x, int *y)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -218,7 +218,7 @@ poll_mouse_move (void *gfx_context, int *x, int *y)
 }
 
 static int
-poll_mouse_button_left (void *gfx_context)
+_poll_mouse_button_left (void *gfx_context)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -234,7 +234,7 @@ poll_mouse_button_left (void *gfx_context)
 }
 
 static int
-poll_mouse_button_right (void *gfx_context)
+_poll_mouse_button_right (void *gfx_context)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -251,7 +251,7 @@ poll_mouse_button_right (void *gfx_context)
 }
 
 static int
-poll_mouse_wheel_up (void *gfx_context)
+_poll_mouse_wheel_up (void *gfx_context)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -266,7 +266,7 @@ poll_mouse_wheel_up (void *gfx_context)
 }
 
 static int
-poll_mouse_wheel_down (void *gfx_context)
+_poll_mouse_wheel_down (void *gfx_context)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -281,8 +281,8 @@ poll_mouse_wheel_down (void *gfx_context)
 }
 
 static void
-get_mouse_state (void *gfx_context, int *x, int *y, int *button_left,
-		 int *button_right)
+_get_mouse_state (void *gfx_context, int *x, int *y, int *button_left,
+		  int *button_right)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -294,7 +294,7 @@ get_mouse_state (void *gfx_context, int *x, int *y, int *button_left,
 }
 
 static int
-poll_joystick_up (void *gfx_context, int i)
+_poll_joystick_up (void *gfx_context, int i)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -309,7 +309,7 @@ poll_joystick_up (void *gfx_context, int i)
 }
 
 static int
-poll_joystick_down (void *gfx_context, int i)
+_poll_joystick_down (void *gfx_context, int i)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -324,7 +324,7 @@ poll_joystick_down (void *gfx_context, int i)
 }
 
 static int
-poll_joystick_left (void *gfx_context, int i)
+_poll_joystick_left (void *gfx_context, int i)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -339,7 +339,7 @@ poll_joystick_left (void *gfx_context, int i)
 }
 
 static int
-poll_joystick_right (void *gfx_context, int i)
+_poll_joystick_right (void *gfx_context, int i)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -355,7 +355,7 @@ poll_joystick_right (void *gfx_context, int i)
 }
 
 static int
-poll_joystick_button_a (void *gfx_context, int i)
+_poll_joystick_button (void *gfx_context, int i, int b)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -363,46 +363,29 @@ poll_joystick_button_a (void *gfx_context, int i)
   if (mod_gl_context)
     {
       ret =
-	mod_gl_utils_poll_joystick_button_a (&
-					     (mod_gl_context->
-					      utils_context), i);
-    }
-
-  return ret;
-}
-
-static int
-poll_joystick_button_b (void *gfx_context, int i)
-{
-  int ret = 0;
-  _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
-
-  if (mod_gl_context)
-    {
-      ret =
-	mod_gl_utils_poll_joystick_button_b (&
-					     (mod_gl_context->
-					      utils_context), i);
+	mod_gl_utils_poll_joystick_button (&
+					   (mod_gl_context->utils_context), i,
+					   b);
     }
 
   return ret;
 }
 
 static void
-get_joystick_state (void *gfx_context, int *x, int *y, int *button_a,
-		    int *button_b, int i)
+_get_joystick_state (void *gfx_context, int *x, int *y, int *button,
+		     int i, int b)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
   if (mod_gl_context)
     {
       mod_gl_utils_get_joystick_state (&(mod_gl_context->utils_context), x, y,
-				       button_a, button_b, i);
+				       button, i, b);
     }
 }
 
 static void
-display_log (void *gfx_context, lw6gui_look_t * look, char **log_list)
+_display_log (void *gfx_context, lw6gui_look_t * look, char **log_list)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -414,7 +397,7 @@ display_log (void *gfx_context, lw6gui_look_t * look, char **log_list)
 }
 
 static void
-display_fps (void *gfx_context, lw6gui_look_t * look, int fps)
+_display_fps (void *gfx_context, lw6gui_look_t * look, int fps)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -425,8 +408,8 @@ display_fps (void *gfx_context, lw6gui_look_t * look, int fps)
 }
 
 static void
-display_map_preview (void *gfx_context, lw6gui_look_t * look,
-		     lw6map_level_t * level)
+_display_map_preview (void *gfx_context, lw6gui_look_t * look,
+		      lw6map_level_t * level)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -440,8 +423,8 @@ display_map_preview (void *gfx_context, lw6gui_look_t * look,
 }
 
 static void
-display_map_zones (void *gfx_context, lw6gui_look_t * look,
-		   lw6ker_game_struct_t * game_struct)
+_display_map_zones (void *gfx_context, lw6gui_look_t * look,
+		    lw6ker_game_struct_t * game_struct)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -457,8 +440,8 @@ display_map_zones (void *gfx_context, lw6gui_look_t * look,
 }
 
 static void
-display_map_gradient (void *gfx_context, lw6gui_look_t * look,
-		      lw6ker_game_state_t * game_state, int team_id)
+_display_map_gradient (void *gfx_context, lw6gui_look_t * look,
+		       lw6ker_game_state_t * game_state, int team_id)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -474,8 +457,8 @@ display_map_gradient (void *gfx_context, lw6gui_look_t * look,
 }
 
 static void
-display_game (void *gfx_context, lw6gui_look_t * look,
-	      lw6ker_game_state_t * game_state)
+_display_game (void *gfx_context, lw6gui_look_t * look,
+	       lw6ker_game_state_t * game_state)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -490,9 +473,9 @@ display_game (void *gfx_context, lw6gui_look_t * look,
 }
 
 static void
-pick_map_coord (void *gfx_context, lw6gui_look_t * look, int *map_x,
-		int *map_y, lw6ker_game_state_t * game_state, int screen_x,
-		int screen_y)
+_pick_map_coord (void *gfx_context, lw6gui_look_t * look, int *map_x,
+		 int *map_y, lw6ker_game_state_t * game_state, int screen_x,
+		 int screen_y)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -507,7 +490,7 @@ pick_map_coord (void *gfx_context, lw6gui_look_t * look, int *map_x,
 }
 
 static void
-display_menu (void *gfx_context, lw6gui_look_t * look, lw6gui_menu_t * menu)
+_display_menu (void *gfx_context, lw6gui_look_t * look, lw6gui_menu_t * menu)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -521,8 +504,8 @@ display_menu (void *gfx_context, lw6gui_look_t * look, lw6gui_menu_t * menu)
 }
 
 static void
-pick_menuitem (void *gfx_context, lw6gui_look_t * look, int *position,
-	       int *scroll, lw6gui_menu_t * menu, int x, int y)
+_pick_menuitem (void *gfx_context, lw6gui_look_t * look, int *position,
+		int *scroll, lw6gui_menu_t * menu, int x, int y)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -537,8 +520,8 @@ pick_menuitem (void *gfx_context, lw6gui_look_t * look, int *position,
 }
 
 static int
-warp_mouse_on_menuitem (void *gfx_context, lw6gui_look_t * look,
-			lw6gui_menu_t * menu, int position)
+_warp_mouse_on_menuitem (void *gfx_context, lw6gui_look_t * look,
+			 lw6gui_menu_t * menu, int position)
 {
   int ret = 0;
 
@@ -558,7 +541,7 @@ warp_mouse_on_menuitem (void *gfx_context, lw6gui_look_t * look,
 }
 
 static void
-prepare_buffer (void *gfx_context, lw6gui_look_t * look)
+_prepare_buffer (void *gfx_context, lw6gui_look_t * look)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -569,7 +552,7 @@ prepare_buffer (void *gfx_context, lw6gui_look_t * look)
 }
 
 static void
-swap_buffers (void *gfx_context)
+_swap_buffers (void *gfx_context)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -580,9 +563,9 @@ swap_buffers (void *gfx_context)
 }
 
 static void *
-init (int argc, char *argv[], int width, int height, int fullscreen,
-      void (*resize_callback) (int width, int height, int fullscreen),
-      int ticks)
+_init (int argc, char *argv[], int width, int height, int fullscreen,
+       void (*resize_callback) (int width, int height, int fullscreen),
+       int ticks)
 {
   _mod_gl_context_t *mod_gl_context =
     _mod_gl_init (argc, argv, width, height, fullscreen, resize_callback,
@@ -591,11 +574,47 @@ init (int argc, char *argv[], int width, int height, int fullscreen,
   return (void *) mod_gl_context;
 }
 
+static void
+_get_low_resolution (void *gfx_context, int *width, int *height)
+{
+  _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
+
+  if (mod_gl_context)
+    {
+      mod_gl_utils_get_low_resolution (&(mod_gl_context->utils_context),
+				       width, height);
+    }
+}
+
+static void
+_get_standard_resolution (void *gfx_context, int *width, int *height)
+{
+  _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
+
+  if (mod_gl_context)
+    {
+      mod_gl_utils_get_standard_resolution (&(mod_gl_context->utils_context),
+					    width, height);
+    }
+}
+
+static void
+_get_high_resolution (void *gfx_context, int *width, int *height)
+{
+  _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
+
+  if (mod_gl_context)
+    {
+      mod_gl_utils_get_high_resolution (&(mod_gl_context->utils_context),
+					width, height);
+    }
+}
+
 static int
-set_video_mode (void *gfx_context, int width, int height,
-		int fullscreen,
-		void (*resize_callback) (int width,
-					 int height, int fullscreen))
+_set_video_mode (void *gfx_context, int width, int height,
+		 int fullscreen,
+		 void (*resize_callback) (int width,
+					  int height, int fullscreen))
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -611,7 +630,7 @@ set_video_mode (void *gfx_context, int width, int height,
 }
 
 static int
-get_video_mode (void *gfx_context, int *width, int *height, int *fullscreen)
+_get_video_mode (void *gfx_context, int *width, int *height, int *fullscreen)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -627,7 +646,7 @@ get_video_mode (void *gfx_context, int *width, int *height, int *fullscreen)
 }
 
 static void
-quit (void *gfx_context)
+_quit (void *gfx_context)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -638,7 +657,7 @@ quit (void *gfx_context)
 }
 
 static void
-delay (void *gfx_context, int ms)
+_delay (void *gfx_context, int ms)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -649,7 +668,7 @@ delay (void *gfx_context, int ms)
 }
 
 static int
-get_ticks (void *gfx_context)
+_get_ticks (void *gfx_context)
 {
   int ret = 0;
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
@@ -670,49 +689,51 @@ mod_gl_create_backend ()
   backend = LW6SYS_CALLOC (sizeof (lw6gfx_backend_t));
   if (backend)
     {
-      backend->display_background = display_background;
-      backend->display_hud = display_hud;
-      backend->poll_key = poll_key;
-      backend->is_key_esc = is_key_esc;
-      backend->is_key_enter = is_key_enter;
-      backend->is_key_up = is_key_up;
-      backend->is_key_down = is_key_down;
-      backend->is_key_left = is_key_left;
-      backend->is_key_right = is_key_right;
-      backend->poll_quit = poll_quit;
-      backend->send_quit = send_quit;
-      backend->get_key_state = get_key_state;
-      backend->poll_mouse_move = poll_mouse_move;
-      backend->poll_mouse_button_left = poll_mouse_button_left;
-      backend->poll_mouse_button_right = poll_mouse_button_right;
-      backend->poll_mouse_wheel_up = poll_mouse_wheel_up;
-      backend->poll_mouse_wheel_down = poll_mouse_wheel_down;
-      backend->get_mouse_state = get_mouse_state;
-      backend->poll_joystick_up = poll_joystick_up;
-      backend->poll_joystick_down = poll_joystick_down;
-      backend->poll_joystick_left = poll_joystick_left;
-      backend->poll_joystick_right = poll_joystick_right;
-      backend->poll_joystick_button_a = poll_joystick_button_a;
-      backend->poll_joystick_button_b = poll_joystick_button_b;
-      backend->get_joystick_state = get_joystick_state;
-      backend->display_log = display_log;
-      backend->display_fps = display_fps;
-      backend->display_map_preview = display_map_preview;
-      backend->display_map_zones = display_map_zones;
-      backend->display_map_gradient = display_map_gradient;
-      backend->display_game = display_game;
-      backend->pick_map_coord = pick_map_coord;
-      backend->display_menu = display_menu;
-      backend->pick_menuitem = pick_menuitem;
-      backend->warp_mouse_on_menuitem = warp_mouse_on_menuitem;
-      backend->prepare_buffer = prepare_buffer;
-      backend->swap_buffers = swap_buffers;
-      backend->init = init;
-      backend->set_video_mode = set_video_mode;
-      backend->get_video_mode = get_video_mode;
-      backend->quit = quit;
-      backend->delay = delay;
-      backend->get_ticks = get_ticks;
+      backend->display_background = _display_background;
+      backend->display_hud = _display_hud;
+      backend->poll_key = _poll_key;
+      backend->is_key_esc = _is_key_esc;
+      backend->is_key_enter = _is_key_enter;
+      backend->is_key_up = _is_key_up;
+      backend->is_key_down = _is_key_down;
+      backend->is_key_left = _is_key_left;
+      backend->is_key_right = _is_key_right;
+      backend->poll_quit = _poll_quit;
+      backend->send_quit = _send_quit;
+      backend->get_key_state = _get_key_state;
+      backend->poll_mouse_move = _poll_mouse_move;
+      backend->poll_mouse_button_left = _poll_mouse_button_left;
+      backend->poll_mouse_button_right = _poll_mouse_button_right;
+      backend->poll_mouse_wheel_up = _poll_mouse_wheel_up;
+      backend->poll_mouse_wheel_down = _poll_mouse_wheel_down;
+      backend->get_mouse_state = _get_mouse_state;
+      backend->poll_joystick_up = _poll_joystick_up;
+      backend->poll_joystick_down = _poll_joystick_down;
+      backend->poll_joystick_left = _poll_joystick_left;
+      backend->poll_joystick_right = _poll_joystick_right;
+      backend->poll_joystick_button = _poll_joystick_button;
+      backend->get_joystick_state = _get_joystick_state;
+      backend->display_log = _display_log;
+      backend->display_fps = _display_fps;
+      backend->display_map_preview = _display_map_preview;
+      backend->display_map_zones = _display_map_zones;
+      backend->display_map_gradient = _display_map_gradient;
+      backend->display_game = _display_game;
+      backend->pick_map_coord = _pick_map_coord;
+      backend->display_menu = _display_menu;
+      backend->pick_menuitem = _pick_menuitem;
+      backend->warp_mouse_on_menuitem = _warp_mouse_on_menuitem;
+      backend->prepare_buffer = _prepare_buffer;
+      backend->swap_buffers = _swap_buffers;
+      backend->init = _init;
+      backend->get_low_resolution = _get_low_resolution;
+      backend->get_standard_resolution = _get_standard_resolution;
+      backend->get_high_resolution = _get_high_resolution;
+      backend->set_video_mode = _set_video_mode;
+      backend->get_video_mode = _get_video_mode;
+      backend->quit = _quit;
+      backend->delay = _delay;
+      backend->get_ticks = _get_ticks;
     }
 
   return backend;
