@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,12 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
-#include <time.h>
-#include <string.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
+#include <time.h>
+
 #include "../gfx.h"
 #include "mod-gl-internal.h"
 
@@ -283,8 +282,6 @@ _mod_gl_init (int argc, char *argv[], int width, int height, int fullscreen,
 			  _("SDL_ttf init error: \"%s\""), TTF_GetError ());
 	    }
 
-	  srandom (time (NULL));
-
 	  if (sdl_ok && ttf_ok)
 	    {
 	      if (mod_gl_utils_set_video_mode
@@ -419,8 +416,7 @@ _mod_gl_quit (_mod_gl_context_t * gfx_context)
       lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("possible memory leak, %d calls to SDL_CreateSurface, IMG_Load or TTF_RenderUTF8, and %d calls to SDL_FreeSurface"),
-		  gfx_context->utils_context.surface_counter.
-		  new_counter,
+		  gfx_context->utils_context.surface_counter.new_counter,
 		  gfx_context->utils_context.surface_counter.delete_counter);
     }
 
@@ -430,8 +426,7 @@ _mod_gl_quit (_mod_gl_context_t * gfx_context)
       lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("possible memory leak, %d calls to glGenTexture and %d calls to glDeleteTextures"),
-		  gfx_context->utils_context.texture_counter.
-		  new_counter,
+		  gfx_context->utils_context.texture_counter.new_counter,
 		  gfx_context->utils_context.texture_counter.delete_counter);
     }
 
