@@ -20,9 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
 
-#include "config.h"
 #include "gui.h"
 
 /*
@@ -625,7 +628,7 @@ lw6gui_menu_append_for_id_use (lw6gui_menu_t * menu, char *label, int value,
 static int
 get_position_using_id (lw6gui_menu_t * menu, int id)
 {
-  int ret = 0;
+  int ret = -1;
   int i;
 
   for (i = 0; i < menu->nb_items; ++i)
@@ -637,12 +640,11 @@ get_position_using_id (lw6gui_menu_t * menu, int id)
 	}
     }
 
-  if (!ret)
+  if (ret < 0)
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("error, no menuitem with id %d in menu %d \"%s\""), id,
 		  menu->id, menu->title);
-      ret = -1;
     }
 
   return ret;
