@@ -80,6 +80,7 @@ extern void lw6gui_look_free (lw6gui_look_t * look);
 extern int lw6gui_look_memory_footprint (lw6gui_look_t * look);
 extern char *lw6gui_look_repr (lw6gui_look_t * look);
 extern int lw6gui_look_set (lw6gui_look_t * look, char *key, char *value);
+extern char *lw6gui_look_get (lw6gui_look_t * look, char *key);
 
 /* gui-menuitem.c */
 extern lw6gui_menuitem_t *lw6gui_menuitem_new (char *label, int value,
@@ -94,7 +95,8 @@ extern void lw6gui_menuitem_set_value (lw6gui_menuitem_t * menuitem,
 				       int value, int now);
 extern void lw6gui_menuitem_select (lw6gui_menuitem_t * menuitem, int now);
 extern void lw6gui_menuitem_unselect (lw6gui_menuitem_t * menuitem, int now);
-extern int lw6gui_menuitem_checksum (lw6gui_menuitem_t * menuitem);
+extern u_int32_t lw6gui_menuitem_checksum (lw6gui_menuitem_t * menuitem,
+					   lw6gui_look_t * look);
 
 /* gui-menu.c */
 extern lw6gui_menu_t *lw6gui_menu_new (char *title);
@@ -128,6 +130,11 @@ extern void lw6gui_menu_sync_using_id (lw6gui_menu_t * menu, int menuitem_id,
 				       char *label, int value, int enabled,
 				       int selected, int colored, int now);
 
+/* gui-resolution.c */
+extern int lw6gui_resolution_find_closest (lw6sys_wh_t * closest,
+					   lw6sys_wh_t * wished,
+					   lw6sys_list_t * available);
+
 /* gui-test.c */
 extern int lw6gui_test ();
 
