@@ -20,9 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
 
-#include "config.h"
 #include "hlp.h"
 
 /**
@@ -92,10 +95,13 @@ update_quick (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, "version");
   lw6sys_list_push_back (list, "test");
   lw6sys_list_push_back (list, "pedigree");
+  lw6sys_list_push_back (list, "audit");
+  lw6sys_list_push_back (list, "modules");
   lw6sys_list_push_back (list, "reset");
   lw6sys_list_push_back (list, "defaults");
   lw6sys_list_push_back (list, "list");
   lw6sys_list_push_back (list, "about");
+  lw6sys_list_push_back (list, "debug");
 
   return ((*list) != NULL);
 }
@@ -166,6 +172,7 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, "show-build-copyright");
   lw6sys_list_push_back (list, "show-build-license");
   lw6sys_list_push_back (list, "show-build-configure-args");
+  lw6sys_list_push_back (list, "show-build-gcc-version");
   lw6sys_list_push_back (list, "show-build-cflags");
   lw6sys_list_push_back (list, "show-build-ldflags");
   lw6sys_list_push_back (list, "show-build-hostname");
@@ -173,6 +180,7 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, "show-build-time");
   lw6sys_list_push_back (list, "show-build-target-cpu");
   lw6sys_list_push_back (list, "show-build-target-os");
+  lw6sys_list_push_back (list, "show-build-ms-windows");
   lw6sys_list_push_back (list, "show-build-top-srcdir");
   lw6sys_list_push_back (list, "show-build-prefix");
   lw6sys_list_push_back (list, "show-build-datadir");
@@ -180,6 +188,15 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, "show-build-includedir");
   lw6sys_list_push_back (list, "show-build-localedir");
   lw6sys_list_push_back (list, "show-build-docdir");
+  lw6sys_list_push_back (list, "show-build-enable-console");
+  lw6sys_list_push_back (list, "show-build-enable-mod-gl");
+  lw6sys_list_push_back (list, "show-build-enable-mod-csound");
+  lw6sys_list_push_back (list, "show-build-enable-mod-ogg");
+  lw6sys_list_push_back (list, "show-build-enable-mod-http");
+  lw6sys_list_push_back (list, "show-build-enable-allinone");
+  lw6sys_list_push_back (list, "show-build-enable-fullstatic");
+  lw6sys_list_push_back (list, "show-build-enable-gprof");
+  lw6sys_list_push_back (list, "show-build-enable-valgrind");
   lw6sys_list_push_back (list, "show-default-user-dir");
   lw6sys_list_push_back (list, "show-default-config-file");
   lw6sys_list_push_back (list, "show-default-log-file");
@@ -189,6 +206,8 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, "show-default-map-dir");
   lw6sys_list_push_back (list, "show-default-map-path");
   lw6sys_list_push_back (list, "show-default-script-file");
+  lw6sys_list_push_back (list, "show-cwd");
+  lw6sys_list_push_back (list, "show-run-dir");
   lw6sys_list_push_back (list, "show-user-dir");
   lw6sys_list_push_back (list, "show-config-file");
   lw6sys_list_push_back (list, "show-log-file");
@@ -219,6 +238,7 @@ lw6hlp_list_show ()
 static int
 update_path (lw6sys_list_t ** list)
 {
+  lw6sys_list_push_back (list, "run-dir");
   lw6sys_list_push_back (list, "user-dir");
   lw6sys_list_push_back (list, "config-file");
   lw6sys_list_push_back (list, "log-file");
@@ -363,6 +383,15 @@ static int
 update_map (lw6sys_list_t ** list)
 {
   lw6sys_list_push_back (list, "chosen-map");
+  lw6sys_list_push_back (list, "use-map-options");
+  lw6sys_list_push_back (list, "use-map-style");
+  lw6sys_list_push_back (list, "force-time");
+  lw6sys_list_push_back (list, "force-size");
+  lw6sys_list_push_back (list, "force-background");
+  lw6sys_list_push_back (list, "force-hud");
+  lw6sys_list_push_back (list, "force-menu");
+  lw6sys_list_push_back (list, "force-view");
+  lw6sys_list_push_back (list, "force-team-colors");
 
   return ((*list) != NULL);
 }
@@ -447,6 +476,7 @@ update_map_style (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, "view-style");
   lw6sys_list_push_back (list, "background-density");
   lw6sys_list_push_back (list, "background-speed");
+  lw6sys_list_push_back (list, "colorize-background");
   lw6sys_list_push_back (list, "background-color-auto");
   lw6sys_list_push_back (list, "hud-color-auto");
   lw6sys_list_push_back (list, "menu-color-auto");
@@ -543,6 +573,7 @@ lw6hlp_list_hooks ()
 static int
 update_tuning (lw6sys_list_t ** list)
 {
+  lw6sys_list_push_back (list, "log-level");
   lw6sys_list_push_back (list, "max-frames-per-sec");
   lw6sys_list_push_back (list, "max-logic-per-sec");
   lw6sys_list_push_back (list, "max-io-per-sec");
