@@ -20,9 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
 
-#include "config.h"
 #include "ker.h"
 #include "ker-internal.h"
 
@@ -472,8 +475,7 @@ lw6ker_game_state_do_round (lw6ker_game_state_t * game_state)
 				    spreads_per_round);
 
   lw6ker_map_state_move_fighters (&(game_state->map_state),
-				  lw6sys_checksum_int32 (game_state->
-							 rounds) %
+				  lw6sys_checksum_int32 (game_state->rounds) %
 				  LW6KER_NB_PARITIES,
 				  &(game_state->game_struct->options),
 				  game_state->game_struct->options.
