@@ -20,10 +20,13 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
 #include <math.h>
 
-#include "config.h"
 #include "ker.h"
 #include "ker-internal.h"
 
