@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,9 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <libpng12/png.h>
 
-#include "config.h"
 #include "ldr.h"
 #include "ldr-internal.h"
 
@@ -123,11 +125,9 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, char *png_file)
 			  for (row = 0; row < height; ++row)
 			    {
 			      buf[row] =
-				(unsigned char *) LW6SYS_MALLOC (info_ptr->
-								 rowbytes *
-								 sizeof
-								 (unsigned
-								  char));
+				(unsigned char *)
+				LW6SYS_MALLOC (info_ptr->rowbytes *
+					       sizeof (unsigned char));
 			      if (!buf[row])
 				{
 				  memory_ok = 0;
