@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,33 +20,35 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <dirent.h>
-#include <string.h>
-#include <stdio.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
+#include <dirent.h>
+
 #include "ldr.h"
 #include "ldr-internal.h"
 
 static lw6ldr_entry_t *
-new_entry (char *absolute_path, char *relative_path, char *d_name)
+new_entry (char *absolute_path, char *relative_path, char *entry_path)
 {
   lw6ldr_entry_t *entry = NULL;
   char *map_filename = NULL;
 
-  if (d_name[0] != '.')
+  if (entry_path[0] != '.')
     {
       entry = (lw6ldr_entry_t *) LW6SYS_CALLOC (sizeof (lw6ldr_entry_t));
       if (entry)
 	{
-	  entry->absolute_path = lw6sys_path_concat (absolute_path, d_name);
+	  entry->absolute_path =
+	    lw6sys_path_concat (absolute_path, entry_path);
 	  if (entry->absolute_path)
 	    {
 	      if (lw6sys_dir_exists (entry->absolute_path))
 		{
-		  entry->title = lw6sys_str_copy (d_name);
+		  entry->title = lw6sys_str_copy (entry_path);
 		  entry->relative_path =
-		    lw6sys_path_concat (relative_path, d_name);
+		    lw6sys_path_concat (relative_path, entry_path);
 		  map_filename =
 		    lw6sys_path_concat (entry->absolute_path,
 					_LW6LDR_FILE_MAP_PNG);
@@ -80,6 +81,19 @@ new_entry (char *absolute_path, char *relative_path, char *d_name)
       entry = NULL;
     }
 
+  if (entry)
+    {
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _("name \"%s\" in \"%s\" is a valid entry"), entry_path,
+		  absolute_path);
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_DEBUG,
+		  _("name \"%s\" in \"%s\" is not a valid entry"), entry_path,
+		  absolute_path);
+    }
+
   return entry;
 }
 
@@ -98,73 +112,132 @@ lw6ldr_free_entry (lw6ldr_entry_t * entry)
       if (entry->title)
 	{
 	  LW6SYS_FREE (entry->title);
+	  entry->title = NULL;
 	}
       if (entry->absolute_path)
 	{
 	  LW6SYS_FREE (entry->absolute_path);
+	  entry->absolute_path = NULL;
 	}
       if (entry->relative_path)
 	{
 	  LW6SYS_FREE (entry->relative_path);
+	  entry->relative_path = NULL;
 	}
     }
   LW6SYS_FREE (entry);
 }
 
+static void
+add_entry (lw6sys_list_t ** entries, lw6sys_assoc_t ** entries_index,
+	   char *absolute_path, char *relative_path, char *entry_path, int *n)
+{
+  lw6ldr_entry_t *entry = NULL;
+
+  entry = new_entry (absolute_path, relative_path, entry_path);
+  if (entry)
+    {
+      if (!lw6sys_assoc_has_key (*entries_index, entry->relative_path))
+	{
+	  lw6sys_lifo_push (entries, (void *) entry);
+	  lw6sys_assoc_set (entries_index, entry->relative_path, NULL);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO,
+		      _
+		      ("duplicate map \"%s\", it is present in at least two places, last found (and ignored) in \"%s\""),
+		      entry->relative_path, entry->absolute_path);
+	  lw6ldr_free_entry (entry);
+	  entry = NULL;
+	}
+      (*n)++;
+    }
+}
+
 static void
 add_subdirs (lw6sys_list_t ** entries, lw6sys_assoc_t ** entries_index,
 	     char *absolute_path, char *relative_path)
 {
-  struct dirent **namelist = NULL;
-  int n;
+#ifdef LW6_MS_WINDOWS
+  WIN32_FIND_DATA dir_entry;
+  HANDLE dir_handle = INVALID_HANDLE_VALUE;
+  char *dir_wildcard = NULL;
+#else
+  struct dirent *dir_entry = NULL;
+  struct dirent *dir_entry_result = NULL;
+  int dir_entry_size = 0;
+  DIR *dir_handle = NULL;
+#endif
+  int n = 0;
+  int eod = 0;
 
-  n = scandir (absolute_path, &namelist, NULL, alphasort);
-  if (n < 0)
+#ifdef LW6_MS_WINDOWS
+  memset (&dir_entry, 0, sizeof (WIN32_FIND_DATA));
+  if (strlen (absolute_path) + 2 < MAX_PATH)
+    {
+      dir_wildcard = lw6sys_path_concat (absolute_path, "*");
+      if (dir_wildcard)
+	{
+	  dir_handle = FindFirstFile (dir_wildcard, &dir_entry);
+	  LW6SYS_FREE (dir_wildcard);
+	}
+    }
+  if (dir_handle != INVALID_HANDLE_VALUE)
+    {
+      while (!eod)
+	{
+	  add_entry (entries, entries_index, absolute_path, relative_path,
+		     dir_entry.cFileName, &n);
+	  memset (&dir_entry, 0, sizeof (WIN32_FIND_DATA));
+	  if (!FindNextFile (dir_handle, &dir_entry))
+	    {
+	      eod = 1;
+	    }
+	}
+      FindClose (dir_handle);
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, "", _("no files in dir \"%s\""),
+		  absolute_path);
+    }
+#else
+  dir_handle = opendir (absolute_path);
+  if (dir_handle)
+    {
+      while (!eod)
+	{
+	  dir_entry_size = sizeof (struct dirent) + NAME_MAX + 1;
+	  dir_entry = (struct dirent *) LW6SYS_CALLOC (dir_entry_size);
+	  if (dir_entry)
+	    {
+	      readdir_r (dir_handle, dir_entry, &dir_entry_result);
+	      if (dir_entry_result && (dir_entry_result == dir_entry))
+		{
+		  add_entry (entries, entries_index, absolute_path,
+			     relative_path, dir_entry->d_name, &n);
+		}
+	      else
+		{
+		  eod = 1;
+		}
+	      LW6SYS_FREE (dir_entry);
+	    }
+	}
+      if (n == 0)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO,
+		      _("no maps in dir \"%s\""), absolute_path);
+	}
+      closedir (dir_handle);
+    }
+  else
     {
       lw6sys_log (LW6SYS_LOG_WARNING, "", _("couldn't read map dir \"%s\""),
 		  absolute_path);
     }
-  else
-    {
-      if (n > 0)
-	{
-	  while (n--)
-	    {
-	      if (1)
-		{
-		  lw6ldr_entry_t *entry =
-		    new_entry (absolute_path, relative_path,
-			       namelist[n]->d_name);
-		  if (entry)
-		    {
-		      if (!lw6sys_assoc_has_key
-			  (*entries_index, entry->relative_path))
-			{
-			  lw6sys_lifo_push (entries, (void *) entry);
-			}
-		      else
-			{
-			  lw6sys_log (LW6SYS_LOG_INFO,
-				      _
-				      ("duplicate map \"%s\", it is present in at least two places, last found (and ignored) in \"%s\""),
-				      entry->relative_path,
-				      entry->absolute_path);
-			  lw6ldr_free_entry (entry);
-			}
-		      lw6sys_assoc_set (entries_index, entry->relative_path,
-					NULL);
-		    }
-		}
-	      free (namelist[n]);	// use of free instead of LW6SYS_FREE is "normal" here       
-	    }
-	}
-      else
-	{
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("no maps in dir \"%s\""), absolute_path);
-	}
-      free (namelist);		// use of free instead of LW6SYS_FREE is "normal" here
-    }
+#endif
 }
 
 /*
