@@ -24,10 +24,13 @@
 #define LIQUIDWAR6LDR_INTERNAL_H
 
 #define _LW6LDR_FILE_README "README"
+#define _LW6LDR_FILE_README_TXT "README.txt"
 #define _LW6LDR_FILE_MAP_PNG "map.png"
 #define _LW6LDR_FILE_TEXTURE_PNG "texture.png"
 #define _LW6LDR_FILE_TEXTURE_JPEG "texture.jpeg"
+#define _LW6LDR_FILE_TEXTURE_JPG "texture.jpg"
 #define _LW6LDR_FILE_TEXTURE_ALPHA_JPEG "texture-alpha.jpeg"
+#define _LW6LDR_FILE_TEXTURE_ALPHA_JPG "texture-alpha.jpg"
 
 #define _LW6LDR_FILE_OPTIONS_XML "options.xml"
 #define _LW6LDR_FILE_STYLE_XML "style.xml"
@@ -58,6 +61,7 @@ extern void _lw6ldr_bw_clear (_lw6ldr_image_bw_t * image);
  * In color.c
  */
 extern int _lw6ldr_guess_colors (lw6map_level_t * level);
+extern void _lw6ldr_auto_background (lw6map_level_t * level);
 
 /*
  * In rgba.c
