@@ -20,10 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <string.h>
-#include <stdio.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "ldr.h"
 #include "ldr-internal.h"
 
@@ -80,6 +80,17 @@ read_readme (char *dirname)
       LW6SYS_FREE (buf);
     }
 
+  if (!readme)
+    {
+      buf = lw6sys_path_concat (dirname, _LW6LDR_FILE_README_TXT);
+      if (buf)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO, _("reading README \"%s\""), buf);
+	  readme = lw6sys_read_file_content (buf);
+	  LW6SYS_FREE (buf);
+	}
+    }
+
   if (!readme)
     {
       readme = lw6sys_str_copy (_("no README for this map"));
