@@ -19,9 +19,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <libpng12/png.h>
 
-#include "config.h"
 #include "ldr.h"
 #include "ldr-internal.h"
 
@@ -76,6 +79,7 @@ lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
 			      display_shape, ratio,
 			      level->param.style.fighter_scale);
       _lw6ldr_guess_colors (level);
+      _lw6ldr_auto_background (level);
       lw6map_auto_colors (&level->param.style);
     }
 
