@@ -20,6 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "liquidwar6.h"
 
 /*
