@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -20,11 +19,47 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <libguile.h>
 
 #include "liquidwar6.h"
 
+#ifdef LW6_MS_WINDOWS
+#define GUILE_LOAD_PATH_KEY "GUILE_LOAD_PATH"
+#define GUILE_LOAD_PATH_SUFFIX "guile"
+
+static void
+fix_guile_load_path (int argc, char *argv[])
+{
+  char *run_dir = NULL;
+  char *guile_dir = NULL;
+
+  run_dir = lw6sys_get_run_dir (argc, argv);
+  if (run_dir)
+    {
+      guile_dir = lw6sys_path_concat (run_dir, GUILE_LOAD_PATH_SUFFIX);
+      if (guile_dir)
+	{
+	  if (lw6sys_dir_exists (guile_dir))
+	    {
+	      lw6sys_setenv (GUILE_LOAD_PATH_KEY, guile_dir);
+	    }
+	  else
+	    {
+	      lw6sys_log (LW6SYS_LOG_NOTICE,
+			  _("Guile library directory \"%s\" does not exist"),
+			  guile_dir);
+	    }
+	  LW6SYS_FREE (guile_dir);
+	}
+      LW6SYS_FREE (run_dir);
+    }
+}
+#endif
+
 static void *
 guile_main (void *data)
 {
@@ -80,12 +115,30 @@ int
 lw6_main (int argc, char *argv[])
 {
   int ret = 0;
+  char *debug_str = NULL;
+  int debug = 0;
+  char *log_level_str = NULL;
+  int log_level = 0;
   char *log_file = NULL;
   int run_game = 1;
 
   ret = lw6_process_non_run_options (argc, argv, &run_game);
   if (run_game)
     {
+      debug_str = lw6sys_arg_get_value_with_env (argc, argv, "debug");
+      if (debug_str)
+	{
+	  debug = lw6sys_atob (debug_str);
+	  lw6sys_debug_set (debug);
+	  LW6SYS_FREE (debug_str);
+	}
+      log_level_str = lw6cfg_unified_get_value (argc, argv, "log-level");
+      if (log_level_str)
+	{
+	  log_level = lw6sys_atoi (log_level_str);
+	  lw6sys_log_set_level (log_level);
+	  LW6SYS_FREE (log_level_str);
+	}
       log_file = lw6cfg_unified_get_log_file (argc, argv);
       if (log_file)
 	{
@@ -94,12 +147,15 @@ lw6_main (int argc, char *argv[])
 	}
       else
 	{
-	  lw6sys_log_sos (_("can't determine log file"));
+	  lw6sys_log_critical (_("can't determine log file"));
 	}
 
       lw6_print_hello (argc, argv);
       if (lw6_init_global (argc, argv))
 	{
+#ifdef LW6_MS_WINDOWS
+	  fix_guile_load_path (argc, argv);
+#endif
 	  scm_with_guile (guile_main, NULL);
 	}
 
