@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,8 +20,9 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "liquidwar6.h"
 
@@ -76,8 +76,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
        */
       if (!check_arg (argv[i]))
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("unknown option \"%s\""),
-		      argv[i]);
+	  lw6sys_log (LW6SYS_LOG_ERROR, _("unknown option \"%s\""), argv[i]);
 	  (*run_game) = 0;
 	}
       else if (lw6sys_arg_match ("help", argv[i]) ||
@@ -130,6 +129,16 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  lw6_print_pedigree ();
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match ("audit", argv[i]))
+	{
+	  lw6_print_audit (argc, argv);
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match ("modules", argv[i]))
+	{
+	  lw6_print_modules ();
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match ("list", argv[i]))
 	{
 	  lw6_print_list ();
@@ -291,6 +300,11 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%s\n", lw6sys_build_get_configure_args ());
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match ("show-build-gcc-version", argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_gcc_version ());
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match ("show-build-cflags", argv[i]))
 	{
 	  printf ("%s\n", lw6sys_build_get_cflags ());
@@ -326,6 +340,11 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%s\n", lw6sys_build_get_target_os ());
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match ("show-build-ms-windows", argv[i]))
+	{
+	  printf ("%d\n", lw6sys_build_is_ms_windows ());
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match ("show-build-top-srcdir", argv[i]))
 	{
 	  printf ("%s\n", lw6sys_build_get_top_srcdir ());
@@ -361,6 +380,51 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%s\n", lw6sys_build_get_docdir ());
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match ("show-build-enable-console", argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_console ());
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match ("show-build-enable-mod-gl", argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_mod_gl ());
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match ("show-build-enable-mod-csound", argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_mod_csound ());
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match ("show-build-enable-mod-ogg", argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_mod_ogg ());
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match ("show-build-enable-mod-http", argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_mod_http ());
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match ("show-build-enable-allinone", argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_allinone ());
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match ("show-build-enable-fullstatic", argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_fullstatic ());
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match ("show-build-enable-gprof", argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_gprof ());
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match ("show-build-enable-valgrind", argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_valgrind ());
+	  (*run_game) = 0;
+	}
       /*
        * Show any interesting default path
        */
@@ -370,6 +434,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -380,6 +445,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -390,6 +456,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -400,6 +467,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -410,6 +478,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -420,6 +489,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -430,6 +500,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -440,6 +511,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -450,6 +522,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -457,12 +530,35 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
       /*
        * Show any interesting path
        */
+      else if (lw6sys_arg_match ("show-cwd", argv[i]))
+	{
+	  path = lw6sys_get_cwd (argc, argv);
+	  if (path)
+	    {
+	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
+	      path = NULL;
+	    }
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match ("show-run-dir", argv[i]))
+	{
+	  path = lw6sys_get_run_dir (argc, argv);
+	  if (path)
+	    {
+	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
+	      path = NULL;
+	    }
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match ("show-user-dir", argv[i]))
 	{
 	  path = lw6cfg_unified_get_user_dir (argc, argv);
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -473,6 +569,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -483,6 +580,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -493,6 +591,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -503,6 +602,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -513,6 +613,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -523,6 +624,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -533,6 +635,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
@@ -543,6 +646,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  if (path)
 	    {
 	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
 	      path = NULL;
 	    }
 	  (*run_game) = 0;
