@@ -20,8 +20,9 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <string.h>
-#include <stdio.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "liquidwar6.h"
 
