@@ -20,9 +20,23 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
+#include <string.h>
+
 #include "map.h"
 
+/**
+ * lw6map_color_invert
+ *
+ * @color: the color to invert
+ *
+ * Inverts a color couple, that is, replace fg by bg and vice-versa.
+ *
+ * Return value: none.
+ */
 void
 lw6map_color_invert (lw6map_color_couple_t * color)
 {
@@ -33,6 +47,19 @@ lw6map_color_invert (lw6map_color_couple_t * color)
   color->bg = tmp;
 }
 
+/**
+ * lw6map_auto_colors
+ *
+ * @style: the style structure to process.
+ *
+ * Deduces all colors from background color, if needed. The function
+ * will check color_auto parameters and replace all other colors
+ * by base and alternate colors if needed. Note that the background
+ * color itself is not changed by this function. Background can only
+ * be guessed from texture.
+ *
+ * Return value: none.
+ */
 void
 lw6map_auto_colors (lw6map_style_t * style)
 {
@@ -61,3 +88,20 @@ lw6map_auto_colors (lw6map_style_t * style)
       style->system_color = style->background_color_alternate;
     }
 }
+
+/**
+ * lw6map_color_is_same
+ *
+ * @color1: 1st color to compare
+ * @color2: 2nd color to compare
+ *
+ * Compares two colors. 
+ *
+ * Return value: 1 if equal, 0 if not.
+ */
+int
+lw6map_color_is_same (lw6map_color_couple_t * color1,
+		      lw6map_color_couple_t * color2)
+{
+  return memcmp (color1, color2, sizeof (lw6map_color_couple_t)) ? 0 : 1;
+}
