@@ -20,7 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "map.h"
 
 static int
@@ -141,6 +144,9 @@ push_param (lw6sys_hexa_serializer_t * hexa_serializer,
   ret = ret
     && lw6sys_hexa_serializer_push_float (hexa_serializer,
 					  param->style.background_speed);
+  ret = ret
+    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
+					  param->style.colorize_background);
   ret = ret
     && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
 					  param->style.background_color_auto);
@@ -436,6 +442,9 @@ pop_param (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_param_t * param)
   ret = ret
     && lw6sys_hexa_serializer_pop_float (hexa_serializer,
 					 &(param->style.background_speed));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
+					 &(param->style.colorize_background));
   ret = ret
     && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
 					 &(param->style.
