@@ -20,9 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
 
-#include "config.h"
 #include "map.h"
 
 void
@@ -41,6 +44,7 @@ lw6map_style_defaults (lw6map_style_t * style)
   style->view_style = lw6sys_str_copy (LW6MAP_STYLE_DEFAULT_VIEW_STYLE);
   style->background_density = LW6MAP_STYLE_DEFAULT_BACKGROUND_DENSITY;
   style->background_speed = LW6MAP_STYLE_DEFAULT_BACKGROUND_SPEED;
+  style->colorize_background = LW6MAP_STYLE_DEFAULT_COLORIZE_BACKGROUND;
   style->background_color_auto = LW6MAP_STYLE_DEFAULT_BACKGROUND_COLOR_AUTO;
   style->hud_color_auto = LW6MAP_STYLE_DEFAULT_HUD_COLOR_AUTO;
   style->menu_color_auto = LW6MAP_STYLE_DEFAULT_MENU_COLOR_AUTO;
@@ -232,6 +236,10 @@ lw6map_style_set (lw6map_style_t * style, char *key, char *value)
     {
       style->background_speed = lw6sys_atof (value);
     }
+  else if (lw6sys_arg_match ("colorize-background", key))
+    {
+      style->colorize_background = lw6sys_atob (value);
+    }
   else if (lw6sys_arg_match ("background-color-auto", key))
     {
       style->background_color_auto = lw6sys_atob (value);
@@ -388,3 +396,230 @@ lw6map_style_set (lw6map_style_t * style, char *key, char *value)
 
   return ret;
 }
+
+char *
+lw6map_style_get (lw6map_style_t * style, char *key)
+{
+  char *ret = NULL;
+
+  if (lw6sys_arg_match ("keep-ratio", key))
+    {
+      ret = lw6sys_btoa (style->keep_ratio);
+    }
+  else if (lw6sys_arg_match ("zoom", key))
+    {
+      ret = lw6sys_ftoa (style->zoom);
+    }
+  else if (lw6sys_arg_match ("fighter-scale", key))
+    {
+      ret = lw6sys_ftoa (style->fighter_scale);
+    }
+  else if (lw6sys_arg_match ("use-texture", key))
+    {
+      ret = lw6sys_btoa (style->use_texture);
+    }
+  else if (lw6sys_arg_match ("background-style", key))
+    {
+      ret = lw6sys_str_copy (style->background_style);
+    }
+  else if (lw6sys_arg_match ("hud-style", key))
+    {
+      ret = lw6sys_str_copy (style->hud_style);
+    }
+  else if (lw6sys_arg_match ("menu-style", key))
+    {
+      ret = lw6sys_str_copy (style->menu_style);
+    }
+  else if (lw6sys_arg_match ("view-style", key))
+    {
+      ret = lw6sys_str_copy (style->view_style);
+    }
+  else if (lw6sys_arg_match ("background-density", key))
+    {
+      ret = lw6sys_ftoa (style->background_density);
+    }
+  else if (lw6sys_arg_match ("background-speed", key))
+    {
+      ret = lw6sys_ftoa (style->background_speed);
+    }
+  else if (lw6sys_arg_match ("colorize-background", key))
+    {
+      ret = lw6sys_btoa (style->colorize_background);
+    }
+  else if (lw6sys_arg_match ("background-color-auto", key))
+    {
+      ret = lw6sys_btoa (style->background_color_auto);
+    }
+  else if (lw6sys_arg_match ("hud-color-auto", key))
+    {
+      ret = lw6sys_btoa (style->hud_color_auto);
+    }
+  else if (lw6sys_arg_match ("menu-color-auto", key))
+    {
+      ret = lw6sys_btoa (style->menu_color_auto);
+    }
+  else if (lw6sys_arg_match ("view-color-auto", key))
+    {
+      ret = lw6sys_btoa (style->view_color_auto);
+    }
+  else if (lw6sys_arg_match ("system-color-auto", key))
+    {
+      ret = lw6sys_btoa (style->system_color_auto);
+    }
+  else if (lw6sys_arg_match ("background-color-base-bg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->background_color_base.bg);
+    }
+  else if (lw6sys_arg_match ("background-color-base-fg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->background_color_base.fg);
+    }
+  else if (lw6sys_arg_match ("background-color-alternate-bg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->background_color_alternate.bg);
+    }
+  else if (lw6sys_arg_match ("background-color-alternate-fg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->background_color_alternate.fg);
+    }
+  else if (lw6sys_arg_match ("hud-color-frame-bg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->hud_color_frame.bg);
+    }
+  else if (lw6sys_arg_match ("hud-color-frame-fg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->hud_color_frame.fg);
+    }
+  else if (lw6sys_arg_match ("hud-color-text-bg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->background_color_base.bg);
+    }
+  else if (lw6sys_arg_match ("hud-color-text-fg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->background_color_base.fg);
+    }
+  else if (lw6sys_arg_match ("menu-color-default-bg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->menu_color_default.bg);
+    }
+  else if (lw6sys_arg_match ("menu-color-default-fg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->menu_color_default.fg);
+    }
+  else if (lw6sys_arg_match ("menu-color-selected-bg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->menu_color_selected.bg);
+    }
+  else if (lw6sys_arg_match ("menu-color-selected-fg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->menu_color_selected.fg);
+    }
+  else if (lw6sys_arg_match ("menu-color-disabled-bg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->menu_color_disabled.bg);
+    }
+  else if (lw6sys_arg_match ("menu-color-disabled-fg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->menu_color_disabled.fg);
+    }
+  else if (lw6sys_arg_match ("view-color-cursor-bg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->view_color_cursor.bg);
+    }
+  else if (lw6sys_arg_match ("view-color-cursor-fg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->view_color_cursor.fg);
+    }
+  else if (lw6sys_arg_match ("view-color-map-bg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->view_color_map.bg);
+    }
+  else if (lw6sys_arg_match ("view-color-map-fg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->view_color_map.fg);
+    }
+  else if (lw6sys_arg_match ("system-color-bg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->system_color.bg);
+    }
+  else if (lw6sys_arg_match ("system-color-fg", key))
+    {
+      ret = lw6sys_color_8_to_a (style->system_color.fg);
+    }
+  else if (lw6sys_arg_match ("team-color-red", key))
+    {
+      ret = lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_RED]);
+    }
+  else if (lw6sys_arg_match ("team-color-green", key))
+    {
+      ret = lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_GREEN]);
+    }
+  else if (lw6sys_arg_match ("team-color-blue", key))
+    {
+      ret = lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_BLUE]);
+    }
+  else if (lw6sys_arg_match ("team-color-yellow", key))
+    {
+      ret =
+	lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_YELLOW]);
+    }
+  else if (lw6sys_arg_match ("team-color-cyan", key))
+    {
+      ret = lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_CYAN]);
+    }
+  else if (lw6sys_arg_match ("team-color-magenta", key))
+    {
+      ret =
+	lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_MAGENTA]);
+    }
+  else if (lw6sys_arg_match ("team-color-orange", key))
+    {
+      ret =
+	lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_ORANGE]);
+    }
+  else if (lw6sys_arg_match ("team-color-lightblue", key))
+    {
+      ret =
+	lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_LIGHTBLUE]);
+    }
+  else if (lw6sys_arg_match ("team-color-purple", key))
+    {
+      ret =
+	lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_PURPLE]);
+    }
+  else if (lw6sys_arg_match ("team-color-pink", key))
+    {
+      ret = lw6sys_color_8_to_a (style->team_colors[LW6MAP_TEAM_COLOR_PINK]);
+    }
+  else
+    {
+      ret = NULL;		// no entry matches
+    }
+
+  return ret;
+}
+
+char *
+lw6map_style_get_default (char *key)
+{
+  lw6map_style_t *style;
+  char *ret = NULL;
+
+  style = (lw6map_style_t *) LW6SYS_CALLOC (sizeof (lw6map_style_t));
+  if (style)
+    {
+      lw6map_style_defaults (style);
+      ret = lw6map_style_get (style, key);
+      lw6map_style_clear (style);
+      LW6SYS_FREE (style);
+    }
+
+  if (!ret)
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable to get default value for style parameter \"%s\""),
+		  key);
+    }
+
+  return ret;
+}
