@@ -222,6 +222,7 @@ extern char *LW6MAP_OPTIONS_LIST[];
 #define LW6MAP_STYLE_DEFAULT_VIEW_STYLE "flat"
 #define LW6MAP_STYLE_DEFAULT_BACKGROUND_DENSITY 1.0f
 #define LW6MAP_STYLE_DEFAULT_BACKGROUND_SPEED 1.0f
+#define LW6MAP_STYLE_DEFAULT_COLORIZE_BACKGROUND 1
 #define LW6MAP_STYLE_DEFAULT_BACKGROUND_COLOR_AUTO 1
 #define LW6MAP_STYLE_DEFAULT_HUD_COLOR_AUTO 1
 #define LW6MAP_STYLE_DEFAULT_MENU_COLOR_AUTO 1
@@ -322,6 +323,7 @@ typedef struct lw6map_style_s
   char *view_style;
   float background_density;
   float background_speed;
+  int colorize_background;
   int background_color_auto;
   int hud_color_auto;
   int menu_color_auto;
@@ -379,28 +381,31 @@ lw6map_depth_set (lw6map_depth_t * depth, int x, int y, unsigned char value)
 {
   depth->data[y * depth->shape.w + x] = value;
 }
+
 static inline unsigned char
 lw6map_depth_get (lw6map_depth_t * depth, int x, int y)
 {
   return depth->data[y * depth->shape.w + x];
 }
+
 static inline void
 lw6map_texture_set (lw6map_texture_t * texture, int x, int y,
 		    lw6sys_color_8_t value)
 {
   texture->data[y * texture->shape.w + x] = value;
 }
+
 static inline lw6sys_color_8_t
 lw6map_texture_get (lw6map_texture_t * texture, int x, int y)
 {
   return texture->data[y * texture->shape.w + x];
 }
 
-/*
- * In color.c
- */
+// map-color.c
 extern void lw6map_color_invert (lw6map_color_couple_t * color);
 extern void lw6map_auto_colors (lw6map_style_t * style);
+extern int lw6map_color_is_same (lw6map_color_couple_t * color1,
+				 lw6map_color_couple_t * color2);
 
 /*
  * In depth.c
@@ -457,20 +462,11 @@ extern int lw6map_options_set_bool (lw6map_options_t * static_options,
 				    char *key, int value);
 extern void lw6map_options_clear (lw6map_options_t * param);
 
-/*
- * In param.c
- */
+// map-param.c
 extern void lw6map_param_defaults (lw6map_param_t * param);
 extern void lw6map_param_clear (lw6map_param_t * param);
 extern void lw6map_param_copy (lw6map_param_t * dst, lw6map_param_t * src);
-extern void lw6map_param_set_int (lw6map_param_t * param, char *key,
-				  int value);
-extern void lw6map_param_set_bool (lw6map_param_t * param, char *key,
-				   int value);
-extern void lw6map_param_set_float (lw6map_param_t * param, char *key,
-				    float value);
-extern void lw6map_param_set_string (lw6map_param_t * param, char *key,
-				     char *value);
+extern int lw6map_param_set (lw6map_param_t * param, char *key, char *value);
 
 /*
  * In resampler.c
@@ -494,6 +490,8 @@ extern void lw6map_style_defaults (lw6map_style_t * style);
 extern void lw6map_style_clear (lw6map_style_t * style);
 extern void lw6map_style_copy (lw6map_style_t * dst, lw6map_style_t * src);
 extern int lw6map_style_set (lw6map_style_t * style, char *key, char *value);
+extern char *lw6map_style_get (lw6map_style_t * style, char *key);
+extern char *lw6map_style_get_default (char *key);
 
 /*
  * In test.c
