@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,10 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "../cfg/cfg.h"
 #include "net-internal.h"
 
@@ -75,8 +74,9 @@ _lw6net_const_init (int argc, char *argv[])
 	  ret =
 	    lw6cfg_read_key_value_xml_file (const_file, read_callback,
 					    (void *)
-					    &(_lw6net_global_context->
-					      const_data));
+					    &
+					    (_lw6net_global_context->
+					     const_data));
 
 	  LW6SYS_FREE (const_file);
 	}
