@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,6 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <signal.h>
 
 #include "net.h"
@@ -48,6 +51,26 @@ lw6net_init (int argc, char *argv[])
     (_lw6net_context_t *) LW6SYS_CALLOC (sizeof (_lw6net_context_t));
   if (_lw6net_global_context)
     {
+#ifdef LW6_MS_WINDOWS
+      WORD version_requested;
+      WSADATA wsa_data;
+      int err = 0;
+
+      version_requested = MAKEWORD (2, 2);
+      memset (&wsa_data, 0, sizeof (WSADATA));
+      err = WSAStartup (version_requested, &wsa_data);
+      if (err == 0)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO, _("WSAStartup() OK, returned 0"));
+	  ok = 1;
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("WSAStartup() failed with code %d \"%s\""), err,
+		      _lw6net_wsa_str (err));
+	}
+#else
       /*
        * Well, it seems that SIGPIPE is sent to the application when
        * there's a brutal socket close or things like that, so we
@@ -62,6 +85,7 @@ lw6net_init (int argc, char *argv[])
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING, _("signal() failed"));
 	}
+#endif
 
       ok = _lw6net_const_init (argc, argv)
 	&& _lw6net_socket_init () && _lw6net_thread_init () && ok;
@@ -92,6 +116,10 @@ lw6net_quit ()
 {
   lw6sys_log (LW6SYS_LOG_INFO, _("net quit"));
 
+#ifdef LW6_MS_WINDOWS
+  WSACleanup ();
+#endif
+
   if (_lw6net_global_context)
     {
       _lw6net_thread_quit ();
