@@ -20,16 +20,16 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "../snd.h"
 #include "mod-csound.h"
 #include "mod-csound-internal.h"
 
 static int
-play_sound (void *snd_context, int sound_id)
+_play_sound (void *snd_context, int sound_id)
 {
   int ret = 0;
 
@@ -45,7 +45,7 @@ play_sound (void *snd_context, int sound_id)
 }
 
 static int
-play_music (void *snd_context, char *music_name)
+_play_music (void *snd_context, char *music_name)
 {
   int ret = 0;
 
@@ -61,7 +61,7 @@ play_music (void *snd_context, char *music_name)
 }
 
 static void *
-init (int argc, char *argv[], float sound_volume, float music_volume)
+_init (int argc, char *argv[], float sound_volume, float music_volume)
 {
   _mod_csound_context_t *csound_context =
     _mod_csound_init (argc, argv, sound_volume, music_volume);
@@ -70,7 +70,7 @@ init (int argc, char *argv[], float sound_volume, float music_volume)
 }
 
 static void
-set_sound_volume (void *snd_context, float volume)
+_set_sound_volume (void *snd_context, float volume)
 {
   _mod_csound_context_t *csound_context =
     (_mod_csound_context_t *) snd_context;
@@ -82,7 +82,7 @@ set_sound_volume (void *snd_context, float volume)
 }
 
 static void
-set_music_volume (void *snd_context, float volume)
+_set_music_volume (void *snd_context, float volume)
 {
   _mod_csound_context_t *csound_context =
     (_mod_csound_context_t *) snd_context;
@@ -94,7 +94,7 @@ set_music_volume (void *snd_context, float volume)
 }
 
 static void
-quit (void *snd_context)
+_quit (void *snd_context)
 {
   _mod_csound_context_t *csound_context =
     (_mod_csound_context_t *) snd_context;
@@ -115,12 +115,12 @@ mod_csound_create_backend ()
     {
       memset (backend, 0, sizeof (lw6snd_backend_t));
 
-      backend->play_sound = play_sound;
-      backend->play_music = play_music;
-      backend->init = init;
-      backend->set_sound_volume = set_sound_volume;
-      backend->set_music_volume = set_music_volume;
-      backend->quit = quit;
+      backend->play_sound = _play_sound;
+      backend->play_music = _play_music;
+      backend->init = _init;
+      backend->set_sound_volume = _set_sound_volume;
+      backend->set_music_volume = _set_music_volume;
+      backend->quit = _quit;
     }
 
   return backend;
