@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,7 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "../snd.h"
 #include "mod-ogg-internal.h"
 
@@ -30,7 +32,7 @@ _mod_ogg_set_sound_volume (_mod_ogg_context_t * ogg_context, float volume)
 {
   ogg_context->volume.sound = volume;
 
-  // todo...
+  Mix_Volume (-1, volume * MIX_MAX_VOLUME);
 }
 
 extern void
@@ -38,5 +40,5 @@ _mod_ogg_set_music_volume (_mod_ogg_context_t * ogg_context, float volume)
 {
   ogg_context->volume.music = volume;
 
-  // todo...
+  Mix_VolumeMusic (volume * MIX_MAX_VOLUME);
 }
