@@ -20,16 +20,16 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "../srv.h"
 #include "mod-udpd.h"
 #include "mod-udpd-internal.h"
 
 static void *
-init ()
+_init ()
 {
   _udpd_context_t *udpd_context = _mod_udpd_init ();
 
@@ -37,7 +37,7 @@ init ()
 }
 
 static void
-quit (void *srv_context)
+_quit (void *srv_context)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
 
@@ -48,7 +48,7 @@ quit (void *srv_context)
 }
 
 static int
-can_handle_tcp (void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter)
+_can_handle_tcp (void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   int ret = 0;
@@ -62,7 +62,7 @@ can_handle_tcp (void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter)
 }
 
 static int
-can_handle_udp (void *srv_context, lw6srv_udp_buffer_t * udp_buffer)
+_can_handle_udp (void *srv_context, lw6srv_udp_buffer_t * udp_buffer)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   int ret = 0;
@@ -76,8 +76,8 @@ can_handle_udp (void *srv_context, lw6srv_udp_buffer_t * udp_buffer)
 }
 
 static lw6srv_connection_t *
-accept_tcp (void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter,
-	    char *password)
+_accept_tcp (void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter,
+	     char *password)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   lw6srv_connection_t *ret = NULL;
@@ -91,7 +91,7 @@ accept_tcp (void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter,
 }
 
 static lw6srv_connection_t *
-new_udp (void *srv_context, lw6srv_udp_buffer_t * udp_buffer, char *password)
+_new_udp (void *srv_context, lw6srv_udp_buffer_t * udp_buffer, char *password)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   lw6srv_connection_t *ret = NULL;
@@ -105,8 +105,8 @@ new_udp (void *srv_context, lw6srv_udp_buffer_t * udp_buffer, char *password)
 }
 
 static int
-is_associated_with_udp (void *srv_context, lw6srv_connection_t * connection,
-			lw6srv_udp_buffer_t * udp_buffer)
+_is_associated_with_udp (void *srv_context, lw6srv_connection_t * connection,
+			 lw6srv_udp_buffer_t * udp_buffer)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   int ret = 0;
@@ -122,8 +122,8 @@ is_associated_with_udp (void *srv_context, lw6srv_connection_t * connection,
 }
 
 static int
-update_with_udp (void *srv_context, lw6srv_connection_t * connection,
-		 lw6srv_udp_buffer_t * udp_buffer)
+_update_with_udp (void *srv_context, lw6srv_connection_t * connection,
+		  lw6srv_udp_buffer_t * udp_buffer)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   int ret = 0;
@@ -137,7 +137,7 @@ update_with_udp (void *srv_context, lw6srv_connection_t * connection,
 }
 
 static void
-close (void *srv_context, lw6srv_connection_t * connection)
+_close (void *srv_context, lw6srv_connection_t * connection)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
 
@@ -148,7 +148,7 @@ close (void *srv_context, lw6srv_connection_t * connection)
 }
 
 static int
-send (void *srv_context, lw6srv_connection_t * connection, char *message)
+_send (void *srv_context, lw6srv_connection_t * connection, char *message)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   int ret = 0;
@@ -162,7 +162,7 @@ send (void *srv_context, lw6srv_connection_t * connection, char *message)
 }
 
 static char *
-recv (void *srv_context, lw6srv_connection_t * connection)
+_recv (void *srv_context, lw6srv_connection_t * connection)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   char *ret = NULL;
@@ -176,7 +176,7 @@ recv (void *srv_context, lw6srv_connection_t * connection)
 }
 
 static int
-is_alive (void *srv_context, lw6srv_connection_t * connection)
+_is_alive (void *srv_context, lw6srv_connection_t * connection)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   int ret = 0;
@@ -190,7 +190,7 @@ is_alive (void *srv_context, lw6srv_connection_t * connection)
 }
 
 static char *
-repr (void *srv_context, lw6srv_connection_t * connection)
+_repr (void *srv_context, lw6srv_connection_t * connection)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   char *ret = NULL;
@@ -204,7 +204,7 @@ repr (void *srv_context, lw6srv_connection_t * connection)
 }
 
 static char *
-error (void *srv_context, lw6srv_connection_t * connection)
+_error (void *srv_context, lw6srv_connection_t * connection)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   char *ret = NULL;
@@ -227,20 +227,20 @@ mod_udpd_create_backend ()
     {
       memset (backend, 0, sizeof (lw6srv_backend_t));
 
-      backend->init = init;
-      backend->quit = quit;
-      backend->can_handle_tcp = can_handle_tcp;
-      backend->can_handle_udp = can_handle_udp;
-      backend->accept_tcp = accept_tcp;
-      backend->new_udp = new_udp;
-      backend->is_associated_with_udp = is_associated_with_udp;
-      backend->update_with_udp = update_with_udp;
-      backend->close = close;
-      backend->send = send;
-      backend->recv = recv;
-      backend->is_alive = is_alive;
-      backend->repr = repr;
-      backend->error = error;
+      backend->init = _init;
+      backend->quit = _quit;
+      backend->can_handle_tcp = _can_handle_tcp;
+      backend->can_handle_udp = _can_handle_udp;
+      backend->accept_tcp = _accept_tcp;
+      backend->new_udp = _new_udp;
+      backend->is_associated_with_udp = _is_associated_with_udp;
+      backend->update_with_udp = _update_with_udp;
+      backend->close = _close;
+      backend->send = _send;
+      backend->recv = _recv;
+      backend->is_alive = _is_alive;
+      backend->repr = _repr;
+      backend->error = _error;
     }
 
   return backend;
