@@ -20,9 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
 
-#include "config.h"
 #include "sys.h"
 
 #define MATCH_EXACT_FORMAT_SIZE 4
@@ -159,16 +162,9 @@ lw6sys_arg_get_value (int argc, char *argv[], char *keyword)
   int len = 0;
 
   len = strlen (keyword);
-  for (i = 1; i < argc; ++i)
+  for (i = 1; i < argc && !ret; ++i)
     {
-      if (((strncmp (argv[i], "--", 2) == 0)
-	   && (strncasecmp (argv[i] + 2, keyword, len) == 0)
-	   && (argv[i][2 + len] == '='))
-	  || ((argv[i][0] == '-' || argv[i][0] == '/')
-	      && (strncasecmp (argv[i] + 1, keyword, len) == 0)
-	      && (argv[i][1 + len] == '='))
-	  || ((strncasecmp (argv[i], keyword, len) == 0)
-	      && (argv[i][len] == '=')))
+      if (!ret && lw6sys_arg_match (keyword, argv[i]))
 	{
 	  equal = strchr (argv[i], '=');
 	  if (equal)
@@ -177,9 +173,7 @@ lw6sys_arg_get_value (int argc, char *argv[], char *keyword)
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _
-			  ("error parsing command-line option, can't find '='"));
+	      ret = lw6sys_str_copy ("");
 	    }
 	}
     }
@@ -218,5 +212,4 @@ lw6sys_arg_get_value_with_env (int argc, char *argv[], char *keyword)
     }
 
   return ret;
-
 }
