@@ -20,9 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
 
-#include "config.h"
 #include "sys.h"
 #include "sys-build.h"
 
@@ -210,6 +213,24 @@ lw6sys_build_get_configure_args ()
   return LW6_CONFIGURE_ARGS;
 }
 
+/**
+ * lw6sys_build_get_gcc_version:
+ *
+ * Returns __VERSION__ GCC preprocessor value, that is, the human readable
+ * version of the compiler.
+ *
+ * Return value: a non-NULL string, must not be freed.
+ */
+char *
+lw6sys_build_get_gcc_version ()
+{
+#ifdef __GNUC__
+  return __VERSION__;
+#else
+  return "?";
+#endif
+}
+
 /**
  * lw6sys_build_get_cflags:
  *
@@ -318,6 +339,23 @@ lw6sys_build_get_target_os ()
   return LW6_TARGET_OS;
 }
 
+/**
+ * lw6sys_build_is_ms_windows:
+ *
+ * Tells wether the program was compiled for Microsoft Windows, or not.
+ *
+ * Return value: 1 if compiled on windows 32-bit, 0 if not
+ */
+int
+lw6sys_build_is_ms_windows ()
+{
+#ifdef LW6_MS_WINDOWS
+  return 1;
+#else
+  return 0;
+#endif
+}
+
 /**
  * lw6sys_build_get_top_srcdir:
  *
@@ -467,6 +505,159 @@ lw6sys_build_get_docdir ()
   return LW6_DOCDIR;
 }
 
+/**
+ * lw6sys_build_get_enable_console
+ *
+ * Tells wether console is enabled or not.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_console ()
+{
+#ifdef LW6_CONSOLE
+  return "yes";			// do not translate this, could be interpreted by a script
+#else
+  return "no";			// do not translate this, could be interpreted by a script
+#endif
+}
+
+/**
+ * lw6sys_build_get_enable_mod_gl
+ *
+ * Tells wether the graphical mod-gl backend was compiled.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_mod_gl ()
+{
+#ifdef MOD_GL
+  return "yes";			// do not translate this, could be interpreted by a script
+#else
+  return "no";			// do not translate this, could be interpreted by a script
+#endif
+}
+
+/**
+ * lw6sys_build_get_enable_mod_csound
+ *
+ * Tells wether the audio mod-csound backend was compiled.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_mod_csound ()
+{
+#ifdef MOD_CSOUND
+  return "yes";			// do not translate this, could be interpreted by a script
+#else
+  return "no";			// do not translate this, could be interpreted by a script
+#endif
+}
+
+/**
+ * lw6sys_build_get_enable_mod_ogg
+ *
+ * Tells wether the audio mod-ogg backend was compiled.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_mod_ogg ()
+{
+#ifdef MOD_OGG
+  return "yes";			// do not translate this, could be interpreted by a script
+#else
+  return "no";			// do not translate this, could be interpreted by a script
+#endif
+}
+
+/**
+ * lw6sys_build_get_enable_mod_http
+ *
+ * Tells wether the network mod-http backend was compiled.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_mod_http ()
+{
+#ifdef MOD_HTTP
+  return "yes";			// do not translate this, could be interpreted by a script
+#else
+  return "no";			// do not translate this, could be interpreted by a script
+#endif
+}
+
+/**
+ * lw6sys_build_get_enable_allinone
+ *
+ * Tells wether the game was compiled in allinone mode.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_allinone ()
+{
+#ifdef LW6_ALLINONE
+  return "yes";			// do not translate this, could be interpreted by a script
+#else
+  return "no";			// do not translate this, could be interpreted by a script
+#endif
+}
+
+/**
+ * lw6sys_build_get_enable_fullstatic
+ *
+ * Tells wether the game was compiled in fullstatic mode.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_fullstatic ()
+{
+#ifdef LW6_FULLSTATIC
+  return "yes";			// do not translate this, could be interpreted by a script
+#else
+  return "no";			// do not translate this, could be interpreted by a script
+#endif
+}
+
+/**
+ * lw6sys_build_get_enable_gprof
+ *
+ * Tells wether the game was compiled with suitable informations for gprof.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_gprof ()
+{
+#ifdef LW6_GPROF
+  return "yes";			// do not translate this, could be interpreted by a script
+#else
+  return "no";			// do not translate this, could be interpreted by a script
+#endif
+}
+
+/**
+ * lw6sys_build_get_enable_valgrind
+ *
+ * Tells wether the game was compiled for later use with valgrind.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_valgrind ()
+{
+#ifdef LW6_VALGRIND
+  return "yes";			// do not translate this, could be interpreted by a script
+#else
+  return "no";			// do not translate this, could be interpreted by a script
+#endif
+}
+
 /**
  * lw6sys_build_log_pedigree
  *
@@ -498,8 +689,8 @@ lw6sys_build_log_pedigree ()
 	      lw6sys_build_get_license ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build configure args is \"%s\""),
 	      lw6sys_build_get_configure_args ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build md5sum is \"%s\""),
-	      lw6sys_build_get_md5sum ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build gcc_version is \"%s\""),
+	      lw6sys_build_get_gcc_version ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build cflags is \"%s\""),
 	      lw6sys_build_get_cflags ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build ldflags is \"%s\""),
@@ -512,6 +703,8 @@ lw6sys_build_log_pedigree ()
 	      lw6sys_build_get_target_cpu ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build target os is \"%s\""),
 	      lw6sys_build_get_target_os ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build ms windows is \"%d\""),
+	      lw6sys_build_is_ms_windows ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build top_srcdir is \"%s\""),
 	      lw6sys_build_get_top_srcdir ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build prefix is \"%s\""),
@@ -526,4 +719,22 @@ lw6sys_build_log_pedigree ()
 	      lw6sys_build_get_localedir ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build docdir is \"%s\""),
 	      lw6sys_build_get_docdir ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable console is \"%s\""),
+	      lw6sys_build_get_enable_console ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable mod-gl is \"%s\""),
+	      lw6sys_build_get_enable_mod_gl ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable mod-csound is \"%s\""),
+	      lw6sys_build_get_enable_mod_csound ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable mod-ogg is \"%s\""),
+	      lw6sys_build_get_enable_mod_ogg ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable mod-http is \"%s\""),
+	      lw6sys_build_get_enable_mod_http ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable allinone is \"%s\""),
+	      lw6sys_build_get_enable_allinone ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable fullstatic is \"%s\""),
+	      lw6sys_build_get_enable_fullstatic ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable gprof is \"%s\""),
+	      lw6sys_build_get_enable_gprof ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable valgrind is \"%s\""),
+	      lw6sys_build_get_enable_valgrind ());
 }
