@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,26 +20,49 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <string.h>
-#include <iconv.h>
-#include <langinfo.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
+#include <iconv.h>
+#ifndef LW6_MS_WINDOWS
+#include <langinfo.h>
+#endif
+
 #include "sys.h"
 
-/*
- * Used to force strings into UTF8 mode, this is basically
+/**
+ * lw6sys_locale_to_utf8
+ *
+ * @string: the string to convert
+ *
+ * Used to force strings into UTF-8 mode, this is basically
  * to match the TTF font settings used when displaying stuff
- * on OpenGL. String must be freed.
+ * on OpenGL. Indeed, in this case, the standard _ gettext
+ * function won't work, we need to force UTF-8 mode. If the
+ * locale is UTF-8, then function does nothing, but at least
+ * it's transparent usage won't hurt.
+ *
+ * Returned value: a newly allocated string, always in UTF-8
+ *   no matter what the locale is.
  */
 char *
 lw6sys_locale_to_utf8 (char *string)
 {
-  char *codeset;
-  iconv_t cd;
   char *utf8 = NULL;
 
+  char *codeset = NULL;
+  iconv_t cd;
+
+#ifndef LW6_MS_WINDOWS
+  /*
+   * No support for ns_langinfo on mingw32. However it seems assuming
+   * we're in ISO-8859-1" (latin1) works. At least it works for French
+   * translations on my computer. There is certainly a way to get this
+   * using GetLocaleInfo. Not implemented yet.
+   */
   codeset = nl_langinfo (CODESET);
+#endif
   if (!codeset)
     {
       codeset = "ISO-8859-1";
