@@ -24,6 +24,11 @@
 #define LIQUIDWAR6SYS_INTERNAL_H
 
 #include <pthread.h>
+#include <stdarg.h>
+
+#include "sys.h"
+
+#define _LW6SYS_EXIT_CRITICAL 1
 
 #define _LW6SYS_BAZOOKA_DEFAULT_SIZE 10000
 #define _LW6SYS_BAZOOKA_FILE_SIZE 50
@@ -32,6 +37,9 @@
 #define _LW6SYS_LOG_CTIME_BUF_SIZE 30	// more than 26 is enough
 #define _LW6SYS_LOG_CTIME_ZERO 24
 
+#define _LW6SYS_DEBUG_DEFAULT 0
+#define _LW6SYS_LOG_DEFAULT_ID LW6SYS_LOG_INFO_ID
+
 typedef struct _lw6sys_bazooka_s
 {
   void *ptr;
@@ -58,6 +66,14 @@ typedef struct _lw6sys_thread_handler_s
   int flag;
 } _lw6sys_thread_handler_t;
 
+typedef struct _lw6sys_global_s
+{
+  int debug;
+  int log_level;
+} _lw6sys_global_t;
+
+extern _lw6sys_global_t _lw6sys_global;
+
 extern void _lw6sys_bazooka_register_malloc (char *ptr, int size, char *file,
 					     int line);
 extern void _lw6sys_bazooka_register_calloc (char *ptr, int size, char *file,
@@ -68,5 +84,6 @@ extern void _lw6sys_bazooka_register_realloc_2 (char *ptr, char *ptr2,
 						int size, char *file,
 						int line);
 extern void _lw6sys_bazooka_register_free (char *ptr);
+extern char *_lw6sys_new_vsnprintf (int n, char *fmt, va_list ap);
 
 #endif
