@@ -20,17 +20,22 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <stdarg.h>
-#include <syslog.h>
-#include <time.h>
-#include <string.h>
-#include <errno.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "sys.h"
 #include "sys-internal.h"
 
+#ifdef HAVE_SYSLOG_H
+#include <syslog.h>
+#endif
+#include <time.h>
+#include <errno.h>
+
+#define MSGBOX_LENGTH 4096
+#define MSGBOX_WIDTH 128
+
 #define STATIC_LOG_FILENAME_SIZE 65536
 static char static_log_filename[STATIC_LOG_FILENAME_SIZE + 1] = { 0 };
 
@@ -50,7 +55,7 @@ get_log_file ()
 
   if (!log_file)
     {
-      lw6sys_log_sos (_("log_file is NULL"));
+      lw6sys_log_critical (_("log_file is NULL"));
     }
 
   return log_file;
@@ -496,7 +501,7 @@ lw6sys_log_clear (char *filename)
   lw6sys_clear_file (filename);
   if (!lw6sys_file_exists (filename))
     {
-      lw6sys_log_sos (_("can't open log file \"%s\""), filename);
+      lw6sys_log_critical (_("can't open log file \"%s\""), filename);
     }
 }
 
@@ -554,15 +559,69 @@ log_to_console (FILE * f, char *level_str, char *fmt, va_list ap)
   fflush (f);
 }
 
+static void
+msgbox_alert (char *fmt, va_list ap)
+{
+#ifdef LW6_MS_WINDOWS
+  {
+    char *message_raw = NULL;
+    char *message_formatted = NULL;
+
+    message_raw = _lw6sys_new_vsnprintf (MSGBOX_LENGTH, fmt, ap);
+    if (!message_raw)
+      {
+	message_raw = lw6sys_str_copy (_("Error (message too long...)"));
+      }
+    if (message_raw)
+      {
+	message_formatted =
+	  lw6sys_str_reformat (message_raw, "", MSGBOX_WIDTH);
+	if (message_formatted)
+	  {
+	    MessageBox (NULL,
+			message_formatted,
+			lw6sys_build_get_package_name (),
+			MB_OK | MB_ICONERROR | MB_APPLMODAL);
+	    LW6SYS_FREE (message_formatted);
+	  }
+	LW6SYS_FREE (message_raw);
+      }
+  }
+#else
+/*
+ * Not implemented yet, below sample code, which would require to
+ * link against gtk2, with:
+ * CFLAGS=`pkg-config --cflags gtk+-2.0`
+ * LDFLAGS=`pkg-config --libs gtk+-2.0`
+ */
+#if 0
+  {
+    GtkWidget *dlg = NULL;
+    gtk_init (&argc, &argv);
+    dlg = gtk_message_dialog_new (NULL,
+				  GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
+				  GTK_BUTTONS_NONE, "Il y a un bleme");
+    if (dlg)
+      {
+	gtk_dialog_add_button (GTK_DIALOG (dlg), GTK_STOCK_OK,
+			       GTK_RESPONSE_OK);
+	gtk_dialog_run (GTK_DIALOG (dlg));
+	gtk_widget_destroy (dlg);
+      }
+  }
+#endif
+#endif
+}
+
 /**
  * lw6sys_log:
  *
  * @level_id: the log level to use. Possible values are, by order, 
- *   LW6SYS_LOG_DEBUG_ID (-1), 
- *   LW6SYS_LOG_INFO_ID (0), 
- *   LW6SYS_LOG_NOTICE_ID (1), 
- *   LW6SYS_LOG_WARNING_ID (2) and 
- *   LW6SYS_LOG_ERROR_ID (3).
+ *   LW6SYS_LOG_ERROR_ID (0), 
+ *   LW6SYS_LOG_WARNING_ID (1), 
+ *   LW6SYS_LOG_NOTICE_ID (2), 
+ *   LW6SYS_LOG_INFO_ID (3) and 
+ *   LW6SYS_LOG_DEBUG_ID (4).
  * @file: the name of the source file where the function is called,
  *   one can use __FILE__
  * @line: the line in the source file where the function is called,
@@ -585,113 +644,139 @@ log_to_console (FILE * f, char *level_str, char *fmt, va_list ap)
 void
 lw6sys_log (int level_id, char *file, int line, char *fmt, ...)
 {
-  char *level_str = NULL;
-  int syslog_priority = 0;
-  FILE *f;
-  int errno_int;
-  va_list ap;
-  va_list ap2;
-
-  errno_int = errno;
-
-  va_start (ap, fmt);
-
-  switch (level_id)
+  if (level_id <= lw6sys_log_get_level () || lw6sys_debug_get ())
     {
-    case LW6SYS_LOG_INFO_ID:
-      level_str = lw6sys_str_copy ("");
-      syslog_priority = LOG_INFO;
-      break;
-    case LW6SYS_LOG_NOTICE_ID:
-      level_str = lw6sys_str_copy ("");
-      syslog_priority = LOG_NOTICE;
-      break;
-    case LW6SYS_LOG_WARNING_ID:
-      if (errno_int)
+      char *level_str = NULL;
+#ifdef HAVE_SYSLOG_H
+      int syslog_priority = 0;
+#endif
+      FILE *f;
+      int errno_int;
+      va_list ap;
+      va_list ap2;
+
+      errno_int = errno;
+
+      va_start (ap, fmt);
+
+      switch (level_id)
 	{
-	  level_str =
-	    lw6sys_new_sprintf (_("WARNING! (errno=%d:%s) "), errno_int,
-				errno_str (errno_int));
+	case LW6SYS_LOG_ERROR_ID:
+	  if (errno_int)
+	    {
+	      level_str =
+		lw6sys_new_sprintf (_("ERROR! (errno=%d:%s) "), errno_int,
+				    errno_str (errno_int));
+	    }
+	  else
+	    {
+	      level_str = lw6sys_str_copy (_("ERROR! "));
+	    }
+#ifdef HAVE_SYSLOG_H
+	  syslog_priority = LOG_ERR;
+#endif
+	  break;
+	case LW6SYS_LOG_WARNING_ID:
+	  if (errno_int)
+	    {
+	      level_str =
+		lw6sys_new_sprintf (_("WARNING! (errno=%d:%s) "), errno_int,
+				    errno_str (errno_int));
+	    }
+	  else
+	    {
+	      level_str = lw6sys_str_copy (_("WARNING! "));
+	    }
+#ifdef HAVE_SYSLOG_H
+	  syslog_priority = LOG_WARNING;
+#endif
+	  break;
+	case LW6SYS_LOG_NOTICE_ID:
+	  level_str = lw6sys_str_copy ("");
+#ifdef HAVE_SYSLOG_H
+	  syslog_priority = LOG_NOTICE;
+#endif
+	  break;
+	case LW6SYS_LOG_INFO_ID:
+	  level_str = lw6sys_str_copy ("");
+#ifdef HAVE_SYSLOG_H
+	  syslog_priority = LOG_INFO;
+#endif
+	  break;
+	default:		// LW6SYS_LOG_DEBUG_ID
+	  level_str = lw6sys_str_copy (_("[debug] "));
+#ifdef HAVE_SYSLOG_H
+	  syslog_priority = LOG_DEBUG;
+#endif
+	  break;
 	}
-      else
+
+      if (fmt != NULL)
 	{
-	  level_str = lw6sys_str_copy (_("WARNING! "));
+	  // exclude INFO & DEBUG from console in non-debug mode
+	  if (level_id <= LW6SYS_LOG_NOTICE_ID || lw6sys_debug_get ())
+	    {
+	      va_copy (ap2, ap);
+	      log_to_console (stderr, level_str, fmt, ap2);
+	      va_end (ap2);
+	    }
+#ifdef HAVE_SYSLOG_H
+	  // exclude INFO & DEBUG from syslog
+	  if (level_id <= LW6SYS_LOG_NOTICE_ID)
+	    {
+	      va_copy (ap2, ap);
+	      vsyslog (syslog_priority, fmt, ap2);
+	      va_end (ap2);
+	    }
+#endif
+	  f = open_log_file ();
+	  if (f)
+	    {
+	      va_copy (ap2, ap);
+	      log_to_file (f, level_id, level_str, file, line, fmt, ap2);
+	      va_end (ap2);
+	      fclose (f);
+	    }
+	  if (level_id <= LW6SYS_LOG_ERROR_ID)
+	    {
+	      va_copy (ap2, ap);
+	      msgbox_alert (fmt, ap2);
+	      va_end (ap2);
+	    }
 	}
-      syslog_priority = LOG_WARNING;
-      break;
-    case LW6SYS_LOG_ERROR_ID:
-      if (errno_int)
+
+      va_end (ap);
+
+      if (level_str)
 	{
-	  level_str =
-	    lw6sys_new_sprintf (_("ERROR! (errno=%d:%s) "), errno_int,
-				errno_str (errno_int));
+	  LW6SYS_FREE (level_str);
 	}
-      else
-	{
-	  level_str = lw6sys_str_copy (_("ERROR! "));
-	}
-      syslog_priority = LOG_ERR;
-      break;
-    default:			// LW6SYS_LOG_DEBUG_ID
-      level_str = lw6sys_str_copy (_("[debug] "));
-      syslog_priority = LOG_DEBUG;
-      break;
+
+      /*
+       * We reset errno to avoid getting pointless errno in logs,
+       * the idea is to print errno when needed...
+       */
+      errno = 0;
     }
-
-  if (fmt != NULL)
-    {
-      if (level_id != LW6SYS_LOG_INFO_ID)
-	{
-	  va_copy (ap2, ap);
-	  log_to_console (stderr, level_str, fmt, ap2);
-	  va_end (ap2);
-	}
-      if (level_id >= LW6SYS_LOG_NOTICE_ID)
-	{
-	  va_copy (ap2, ap);
-	  vsyslog (syslog_priority, fmt, ap2);
-	  va_end (ap2);
-	}
-      f = open_log_file ();
-      if (f)
-	{
-	  va_copy (ap2, ap);
-	  log_to_file (f, level_id, level_str, file, line, fmt, ap2);
-	  va_end (ap2);
-	  fclose (f);
-	}
-    }
-
-  va_end (ap);
-
-  if (level_str)
-    {
-      LW6SYS_FREE (level_str);
-    }
-
-  /*
-   * We reset errno to avoid getting pointless errno in logs,
-   * the idea is to print errno when needed...
-   */
-  errno = 0;
 }
 
 /**
- * lw6sys_log_sos:
+ * lw6sys_log_critical:
  *
  * @fmt: a printf-like format string
  * @...: printf-like arguments, corresponding to @fmt.
  *
  * This function is a special log function which will dump informations
  * on the console only, without opening any log file whatsoever. The idea
- * is that it's a "never fail" function. In some cases, for instance reporting
- * that log file can't be opened, it's not wise to use the standard log
- * function.
+ * is that it's a "never fail" function. Additionnally, it will never
+ * return but quit the program. This can be used as an ultimate emergency
+ * function, use it when the program won't run for sure, and displaying
+ * an immediate error message is the only issue.
  *
  * @Return value: void
  */
 void
-lw6sys_log_sos (char *fmt, ...)
+lw6sys_log_critical (char *fmt, ...)
 {
   va_list ap;
   va_list ap2;
@@ -699,8 +784,41 @@ lw6sys_log_sos (char *fmt, ...)
   va_start (ap, fmt);
 
   va_copy (ap2, ap);
-  log_to_console (stderr, _("SOS! "), fmt, ap2);
+  log_to_console (stderr, _("CRITICAL! "), fmt, ap2);
   va_end (ap2);
 
+  va_copy (ap2, ap);
+  msgbox_alert (fmt, ap2);
+  va_end (ap2);
+
+  exit (_LW6SYS_EXIT_CRITICAL);
+
   va_end (ap);
 }
+
+/**
+ * lw6sys_log_get_level
+ *
+ * @Return value: the log level, integer between 0 & 4. 4 is very verbose
+ * (debug), 0 displays errors only.
+ */
+int
+lw6sys_log_get_level ()
+{
+  return _lw6sys_global.log_level;
+}
+
+/**
+ * lw6sys_log_set_level
+ *
+ * @level: the log level, integer between 0 & 4. 4 is very verbose (debug),
+ * 0 displays errors only.
+ */
+void
+lw6sys_log_set_level (int level)
+{
+  level = lw6sys_min (level, LW6SYS_LOG_DEBUG_ID);
+  level = lw6sys_max (level, LW6SYS_LOG_ERROR_ID);
+
+  _lw6sys_global.log_level = level;
+}
