@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,9 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <errno.h>
 
-#include "config.h"
 #include "sys.h"
 #include "sys-internal.h"
 
@@ -32,6 +34,13 @@
 static int mutex_lock_counter = 0;
 static int mutex_unlock_counter = 0;
 
+/**
+ * lw6sys_mutex_create
+ *
+ * Creates a mutex object.
+ *
+ * Return value: newly allocated pointer.
+ */
 void *
 lw6sys_mutex_create ()
 {
@@ -60,6 +69,15 @@ lw6sys_mutex_create ()
   return (void *) mutex;
 }
 
+/**
+ * lw6sys_mutex_destroy
+ *
+ * @mutex: the mutex to destroy.
+ *
+ * Destroys a mutex object.
+ *
+ * Return value: none.
+ */
 void
 lw6sys_mutex_destroy (void *mutex)
 {
@@ -67,6 +85,17 @@ lw6sys_mutex_destroy (void *mutex)
   LW6SYS_FREE (mutex);
 }
 
+/**
+ * lw6sys_mutex_lock
+ *
+ * @mutex: the mutex to use
+ *
+ * Locks the mutex. Note that this should never fail unless
+ * there's a serious initialization problem, instead, function
+ * will wait forever until mutex is released.
+ *
+ * Return value: 1 if success, 0 if failure.
+ */
 int
 lw6sys_mutex_lock (void *mutex)
 {
@@ -88,6 +117,19 @@ lw6sys_mutex_lock (void *mutex)
   return ret;
 }
 
+/**
+ * lw6sys_mutex_trylock
+ *
+ * @mutex: the mutex to use
+ *
+ * Tries to locks the mutex. That is, tells wether mutex
+ * can be locked immediately or not. Note that this does
+ * not mean there's 100% chance next call to lock will
+ * terminated immediately, since lock can still be acquired
+ * by another thread.
+ *
+ * Return value: 1 if mutex unlocked, 0 if locked or error.
+ */
 int
 lw6sys_mutex_trylock (void *mutex)
 {
@@ -117,6 +159,15 @@ lw6sys_mutex_trylock (void *mutex)
   return ret;
 }
 
+/**
+ * lw6sys_mutex_unlock
+ *
+ * @mutex: the mutex to use
+ *
+ * Unlocks a mutex.
+ *
+ * Return value: 1 if sucess, 0 if error.
+ */
 int
 lw6sys_mutex_unlock (void *mutex)
 {
@@ -138,18 +189,42 @@ lw6sys_mutex_unlock (void *mutex)
   return ret;
 }
 
+/**
+ * lw6sys_get_mutex_lock_count
+ *
+ * Returns how many mutexes have been locked since program start.
+ * Usefull for sanity checking when debugging.
+ *
+ * Return value: number of calls to lock
+ */
 int
 lw6sys_get_mutex_lock_count ()
 {
   return mutex_lock_counter;
 }
 
+/**
+ * lw6sys_get_mutex_unlock_count
+ *
+ * Returns how many mutexes have been unlocked since program start.
+ * Usefull for sanity checking when debugging.
+ *
+ * Return value: number of calls to unlock
+ */
 int
 lw6sys_get_mutex_unlock_count ()
 {
   return mutex_unlock_counter;
 }
 
+/**
+ * lw6sys_check_mutex_count
+ *
+ * Checks wether unlock has been called as many times as lock.
+ * Usefull for sanity checking when debugging.
+ *
+ * Return value: 1 if OK, 0 if inconsistency.
+ */
 int
 lw6sys_check_mutex_count ()
 {
