@@ -20,11 +20,18 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
 
-#include "config.h"
 #include "sys.h"
 
+#ifndef LW6_MS_WINDOWS
+#include <unistd.h>
+#endif
+
 #define CONFIG_FILE "config.xml"
 #define LOG_FILE "log.csv"
 #define MOD_LIBDIR_MASK "%s/%s-%s"
@@ -34,28 +41,41 @@
 #define DATA_DIR "data"
 #define MAP_DIR "map"
 #define SCRIPT_FILE "script/liquidwar6.scm"
-#ifdef WIN32
+#ifdef LW6_MS_WINDOWS
 #define README_FILE "README.txt"
 #else
 #define README_FILE "README"
 #endif
+#define CWD_SIZE 2048
 
+/**
+ * lw6sys_get_default_user_dir
+ *
+ * Returns the default user directory. Note that this value
+ * is not static, it can depend, for instance, of the environment
+ * variable @HOME.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_default_user_dir ()
 {
   char *home_dir = NULL;
   char *user_dir = NULL;
-  char *dot_tarname = NULL;
+  char *relative = NULL;
 
   home_dir = lw6sys_get_home ();
   if (home_dir)
     {
-      dot_tarname =
-	lw6sys_str_concat (".", lw6sys_build_get_package_tarname ());
-      if (dot_tarname)
+#ifdef LW6_MS_WINDOWS
+      relative = lw6sys_str_copy (lw6sys_build_get_package_name ());
+#else
+      relative = lw6sys_str_concat (".", lw6sys_build_get_package_tarname ());
+#endif
+      if (relative)
 	{
-	  user_dir = lw6sys_path_concat (home_dir, dot_tarname);
-	  LW6SYS_FREE (dot_tarname);
+	  user_dir = lw6sys_path_concat (home_dir, relative);
+	  LW6SYS_FREE (relative);
 	}
       LW6SYS_FREE (home_dir);
     }
@@ -73,6 +93,15 @@ get_config_file_with_user_dir (char *user_dir)
   return config_file;
 }
 
+/**
+ * lw6sys_get_default_config_file
+ *
+ * Returns the default config file. Note that this value
+ * is not static, it can depend, for instance, of the environment
+ * variable @HOME.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_default_config_file ()
 {
@@ -99,6 +128,15 @@ get_log_file_with_user_dir (char *user_dir)
   return log_file;
 }
 
+/**
+ * lw6sys_get_default_log_file
+ *
+ * Returns the default log file. Note that this value
+ * is not static, it can depend, for instance, of the environment
+ * variable @HOME.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_default_log_file ()
 {
@@ -115,6 +153,13 @@ lw6sys_get_default_log_file ()
   return log_file;
 }
 
+/**
+ * lw6sys_get_default_prefix
+ *
+ * Returns the default prefix, could be /usr/local for instance.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_default_prefix ()
 {
@@ -126,7 +171,8 @@ lw6sys_get_default_prefix ()
 }
 
 static char *
-get_dir (char *mask1, char *prefix1, char *mask2, char *prefix2, char *sub)
+get_dir_common (char *mask1, char *prefix1, char *mask2, char *prefix2,
+		char *sub)
 {
   char *system_dir = NULL;
   char *top_srcdir = NULL;
@@ -191,6 +237,16 @@ get_dir (char *mask1, char *prefix1, char *mask2, char *prefix2, char *sub)
 	}
     }
 
+  return dir;
+}
+
+static char *
+get_dir (char *mask1, char *prefix1, char *mask2, char *prefix2, char *sub)
+{
+  char *dir = NULL;
+
+  dir = get_dir_common (mask1, prefix1, mask2, prefix2, sub);
+
   if (dir == NULL)
     {
       // if not installed, if no source, then search in local directory
@@ -201,7 +257,45 @@ get_dir (char *mask1, char *prefix1, char *mask2, char *prefix2, char *sub)
 }
 
 static char *
-get_file (char *mask1, char *prefix1, char *mask2, char *prefix2, char *sub)
+get_dir_argc_argv (int argc, char *argv[], char *mask1, char *prefix1,
+		   char *mask2, char *prefix2, char *sub)
+{
+  char *dir = NULL;
+  char *run_dir = NULL;
+
+  dir = get_dir_common (mask1, prefix1, mask2, prefix2, sub);
+
+  if (dir == NULL && strlen (sub) > 0)
+    {
+      run_dir = lw6sys_get_run_dir (argc, argv);
+      if (run_dir)
+	{
+	  dir = lw6sys_path_concat (run_dir, sub);
+	  if (dir)
+	    {
+	      if (!lw6sys_dir_exists (dir))
+		{
+		  // directory doesn't exist, we ignore it
+		  LW6SYS_FREE (dir);
+		  dir = NULL;
+		}
+	    }
+	  LW6SYS_FREE (run_dir);
+	}
+    }
+
+  if (dir == NULL)
+    {
+      // if not installed, if no source, then search in local directory
+      dir = lw6sys_path_concat (".", sub);
+    }
+
+  return dir;
+}
+
+static char *
+get_file_common (char *mask1, char *prefix1, char *mask2, char *prefix2,
+		 char *sub)
 {
   char *system_dir = NULL;
   char *top_srcdir = NULL;
@@ -266,6 +360,53 @@ get_file (char *mask1, char *prefix1, char *mask2, char *prefix2, char *sub)
 	}
     }
 
+  return file;
+}
+
+static char *
+get_file (char *mask1, char *prefix1, char *mask2, char *prefix2, char *sub)
+{
+  char *file = NULL;
+
+  file = get_file_common (mask1, prefix1, mask2, prefix2, sub);
+
+  if (file == NULL)
+    {
+      // if not installed, if no source, then search in local directory
+      file = lw6sys_path_concat (".", sub);
+    }
+
+  return file;
+}
+
+static char *
+get_file_argc_argv (int argc, char *argv[], char *mask1, char *prefix1,
+		    char *mask2, char *prefix2, char *sub)
+{
+  char *file = NULL;
+  char *run_dir = NULL;
+
+  file = get_file_common (mask1, prefix1, mask2, prefix2, sub);
+
+  if (file == NULL && strlen (sub) > 0)
+    {
+      run_dir = lw6sys_get_run_dir (argc, argv);
+      if (run_dir)
+	{
+	  file = lw6sys_path_concat (run_dir, sub);
+	  if (file)
+	    {
+	      if (!lw6sys_file_exists (file))
+		{
+		  // file doesn't exist, we ignore it
+		  LW6SYS_FREE (file);
+		  file = NULL;
+		}
+	    }
+	  LW6SYS_FREE (run_dir);
+	}
+    }
+
   if (file == NULL)
     {
       // if not installed, if no source, then search in local directory
@@ -287,6 +428,27 @@ get_mod_dir_with_prefix (char *prefix)
   return mod_dir;
 }
 
+static char *
+get_mod_dir_with_prefix_argc_argc (int argc, char *argv[], char *prefix)
+{
+  char *mod_dir = NULL;
+  char *libdir = NULL;
+
+  libdir = lw6sys_build_get_libdir ();
+  mod_dir =
+    get_dir_argc_argv (argc, argv, MOD_PREFIX_MASK, prefix, MOD_LIBDIR_MASK,
+		       libdir, "");
+
+  return mod_dir;
+}
+
+/**
+ * lw6sys_get_default_mod_dir
+ *
+ * Returns the default module directory (dynamically loaded libraries).
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_default_mod_dir ()
 {
@@ -316,6 +478,28 @@ get_share_dir_with_prefix (char *prefix, char *sub)
   return share_dir;
 }
 
+static char *
+get_share_dir_with_prefix_argc_argv (int argc, char *argv[], char *prefix,
+				     char *sub)
+{
+  char *share_dir = NULL;
+  char *datadir = NULL;
+
+  datadir = lw6sys_build_get_datadir ();
+  share_dir =
+    get_dir_argc_argv (argc, argv, SHARE_PREFIX_MASK, prefix,
+		       SHARE_DATADIR_MASK, datadir, sub);
+
+  return share_dir;
+}
+
+/**
+ * lw6sys_get_default_data_dir
+ *
+ * Returns the default data directory.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_default_data_dir ()
 {
@@ -332,6 +516,13 @@ lw6sys_get_default_data_dir ()
   return data_dir;
 }
 
+/**
+ * lw6sys_get_default_map_dir
+ *
+ * Returns the default map directory.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_default_map_dir ()
 {
@@ -393,6 +584,13 @@ get_path_with_dir_and_user_dir (char *dir, char *user_dir, char *sub,
   return path;
 }
 
+/**
+ * lw6sys_get_default_map_path
+ *
+ * Returns the default map path, which can be composed of several directories.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_default_map_path ()
 {
@@ -430,6 +628,28 @@ get_share_file_with_prefix (char *prefix, char *sub)
   return share_file;
 }
 
+static char *
+get_share_file_with_prefix_argc_argv (int argc, char *argv[], char *prefix,
+				      char *sub)
+{
+  char *share_file = NULL;
+  char *datadir;
+
+  datadir = lw6sys_build_get_datadir ();
+  share_file =
+    get_file_argc_argv (argc, argv, SHARE_PREFIX_MASK, prefix,
+			SHARE_DATADIR_MASK, datadir, sub);
+
+  return share_file;
+}
+
+/**
+ * lw6sys_get_default_script_file
+ *
+ * Returns the default script file.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_default_script_file ()
 {
@@ -446,6 +666,12 @@ lw6sys_get_default_script_file ()
   return script_file;
 }
 
+/**
+ * lw6sys_options_log_defaults
+ *
+ * Logs all default values to log file. Usefull for debugging, to
+ * know where the program is searching for its informations.
+ */
 void
 lw6sys_options_log_defaults ()
 {
@@ -523,6 +749,88 @@ get_command_arg_with_env (int argc, char *argv[], char *keyword)
   return ret;
 }
 
+/**
+ * lw6sys_get_cwd
+ *
+ * Returns the current working directory (absolute path).
+ *
+ * Return value: a newly allocated string.
+ */
+char *
+lw6sys_get_cwd ()
+{
+  char *cwd = NULL;
+  char *cwd_tmp = NULL;
+
+  cwd_tmp = (char *) LW6SYS_CALLOC (CWD_SIZE + 1);
+
+  if (cwd_tmp)
+    {
+#ifdef LW6_MS_WINDOWS
+      if (!GetCurrentDirectoryA (CWD_SIZE, cwd_tmp))
+#else
+      if (!getcwd (cwd_tmp, CWD_SIZE))
+#endif
+	{
+	  LW6SYS_FREE (cwd_tmp);
+	  cwd_tmp = NULL;
+	}
+    }
+
+  if (cwd_tmp)
+    {
+      cwd = lw6sys_path_strip_slash (cwd_tmp);
+      LW6SYS_FREE (cwd_tmp);
+    }
+  else
+    {
+      cwd = lw6sys_str_copy (".");
+    }
+
+  return cwd;
+}
+
+/**
+ * lw6sys_get_run_dir
+ *
+ * @argc: argc, number of arguments, as given to @main
+ * @argv: argv, pointer to arguments, as given to @main
+ *
+ * Returns the binary directory, that is, the directory the binary
+ * is stored in. This is calculated dynamically, by interpreting
+ * command-line arguments.
+ *
+ * Return value: a newly allocated string.
+ */
+char *
+lw6sys_get_run_dir (int argc, char *argv[])
+{
+  char *run_dir = NULL;
+
+  if (argc >= 1)
+    {
+      run_dir = lw6sys_path_parent (argv[0]);
+    }
+  else
+    {
+      run_dir = lw6sys_str_copy (".");
+    }
+
+  return run_dir;
+}
+
+/**
+ * lw6sys_get_user_dir
+ *
+ * @argc: argc, number of arguments, as given to @main
+ * @argv: argv, pointer to arguments, as given to @main
+ *
+ * Returns the user dir, taking in account command-line and
+ * environment variables. However config file content has no impact
+ * on the result.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_user_dir (int argc, char *argv[])
 {
@@ -541,7 +849,7 @@ lw6sys_get_user_dir (int argc, char *argv[])
 	  lw6sys_create_dir_silent (user_dir);
 	  if (!lw6sys_dir_exists (user_dir))
 	    {
-	      lw6sys_log_sos (_("can't open user dir \"%s\""), user_dir);
+	      lw6sys_log_critical (_("can't open user dir \"%s\""), user_dir);
 	    }
 	}
     }
@@ -549,6 +857,18 @@ lw6sys_get_user_dir (int argc, char *argv[])
   return user_dir;
 }
 
+/**
+ * lw6sys_get_config_file
+ *
+ * @argc: argc, number of arguments, as given to @main
+ * @argv: argv, pointer to arguments, as given to @main
+ *
+ * Returns the config file, taking in account command-line and
+ * environment variables. However config file content has no impact
+ * on the result.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_config_file (int argc, char *argv[])
 {
@@ -569,6 +889,18 @@ lw6sys_get_config_file (int argc, char *argv[])
   return config_file;
 }
 
+/**
+ * lw6sys_get_log_file
+ *
+ * @argc: argc, number of arguments, as given to @main
+ * @argv: argv, pointer to arguments, as given to @main
+ *
+ * Returns the log file, taking in account command-line and
+ * environment variables. However config file content has no impact
+ * on the result.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_log_file (int argc, char *argv[])
 {
@@ -589,6 +921,18 @@ lw6sys_get_log_file (int argc, char *argv[])
   return log_file;
 }
 
+/**
+ * lw6sys_get_prefix
+ *
+ * @argc: argc, number of arguments, as given to @main
+ * @argv: argv, pointer to arguments, as given to @main
+ *
+ * Returns the prefix, taking in account command-line and
+ * environment variables. However config file content has no impact
+ * on the result.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_prefix (int argc, char *argv[])
 {
@@ -603,6 +947,19 @@ lw6sys_get_prefix (int argc, char *argv[])
   return prefix;
 }
 
+/**
+ * lw6sys_get_mod_dir
+ *
+ * @argc: argc, number of arguments, as given to @main
+ * @argv: argv, pointer to arguments, as given to @main
+ *
+ * Returns the mod dir (modules, shared .so), 
+ * taking in account command-line and
+ * environment variables. However config file content has no impact
+ * on the result.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_mod_dir (int argc, char *argv[])
 {
@@ -615,7 +972,7 @@ lw6sys_get_mod_dir (int argc, char *argv[])
       prefix = lw6sys_get_prefix (argc, argv);
       if (prefix)
 	{
-	  mod_dir = get_mod_dir_with_prefix (prefix);
+	  mod_dir = get_mod_dir_with_prefix_argc_argc (argc, argv, prefix);
 	  LW6SYS_FREE (prefix);
 	}
     }
@@ -623,6 +980,18 @@ lw6sys_get_mod_dir (int argc, char *argv[])
   return mod_dir;
 }
 
+/**
+ * lw6sys_get_data_dir
+ *
+ * @argc: argc, number of arguments, as given to @main
+ * @argv: argv, pointer to arguments, as given to @main
+ *
+ * Returns the data dir, taking in account command-line and
+ * environment variables. However config file content has no impact
+ * on the result.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_data_dir (int argc, char *argv[])
 {
@@ -635,7 +1004,9 @@ lw6sys_get_data_dir (int argc, char *argv[])
       prefix = lw6sys_get_prefix (argc, argv);
       if (prefix)
 	{
-	  data_dir = get_share_dir_with_prefix (prefix, DATA_DIR);
+	  data_dir =
+	    get_share_dir_with_prefix_argc_argv (argc, argv, prefix,
+						 DATA_DIR);
 	  LW6SYS_FREE (prefix);
 	}
     }
@@ -643,6 +1014,18 @@ lw6sys_get_data_dir (int argc, char *argv[])
   return data_dir;
 }
 
+/**
+ * lw6sys_get_map_dir
+ *
+ * @argc: argc, number of arguments, as given to @main
+ * @argv: argv, pointer to arguments, as given to @main
+ *
+ * Returns the map dir, taking in account command-line and
+ * environment variables. However config file content has no impact
+ * on the result.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_map_dir (int argc, char *argv[])
 {
@@ -655,7 +1038,8 @@ lw6sys_get_map_dir (int argc, char *argv[])
       prefix = lw6sys_get_prefix (argc, argv);
       if (prefix)
 	{
-	  map_dir = get_share_dir_with_prefix (prefix, MAP_DIR);
+	  map_dir =
+	    get_share_dir_with_prefix_argc_argv (argc, argv, prefix, MAP_DIR);
 	  LW6SYS_FREE (prefix);
 	}
     }
@@ -663,6 +1047,18 @@ lw6sys_get_map_dir (int argc, char *argv[])
   return map_dir;
 }
 
+/**
+ * lw6sys_get_map_path
+ *
+ * @argc: argc, number of arguments, as given to @main
+ * @argv: argv, pointer to arguments, as given to @main
+ *
+ * Returns the map path, taking in account command-line and
+ * environment variables. However config file content has no impact
+ * on the result. Map path can contain several directories.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_map_path (int argc, char *argv[])
 {
@@ -710,6 +1106,18 @@ lw6sys_get_map_path (int argc, char *argv[])
   return map_path;
 }
 
+/**
+ * lw6sys_get_script_file
+ *
+ * @argc: argc, number of arguments, as given to @main
+ * @argv: argv, pointer to arguments, as given to @main
+ *
+ * Returns the script file, taking in account command-line and
+ * environment variables. However config file content has no impact
+ * on the result.
+ *
+ * Return value: a newly allocated string.
+ */
 char *
 lw6sys_get_script_file (int argc, char *argv[])
 {
@@ -722,7 +1130,9 @@ lw6sys_get_script_file (int argc, char *argv[])
       prefix = lw6sys_get_prefix (argc, argv);
       if (prefix)
 	{
-	  script_file = get_share_file_with_prefix (prefix, SCRIPT_FILE);
+	  script_file =
+	    get_share_file_with_prefix_argc_argv (argc, argv, prefix,
+						  SCRIPT_FILE);
 	  LW6SYS_FREE (prefix);
 	}
     }
@@ -730,11 +1140,34 @@ lw6sys_get_script_file (int argc, char *argv[])
   return script_file;
 }
 
+/**
+ * lw6sys_options_log
+ *
+ * @argc: argc, number of arguments, as given to @main
+ * @argv: argv, pointer to arguments, as given to @main
+ *
+ * Logs all the main options values which are not config-file
+ * dependant but depend on built-in defaults, command-line arguments
+ * and environment variables. Usefull to debug and know where the
+ * program is searching for things.
+ */
 void
 lw6sys_options_log (int argc, char *argv[])
 {
   char *path = NULL;
 
+  path = lw6sys_get_cwd (argc, argv);
+  if (path)
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, _("cwd is \"%s\""), path);
+      LW6SYS_FREE (path);
+    }
+  path = lw6sys_get_run_dir (argc, argv);
+  if (path)
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, _("run dir is \"%s\""), path);
+      LW6SYS_FREE (path);
+    }
   path = lw6sys_get_user_dir (argc, argv);
   if (path)
     {
