@@ -20,35 +20,57 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <dirent.h>
 #include <sys/stat.h>
 
-#include "config.h"
 #include "sys.h"
 
 #define DIR_SEP_CHAR_UNIX '/'
 #define DIR_SEP_STR_UNIX "/"
-#define DIR_SEP_CHAR_WIN32 '\\'
-#define DIR_SEP_STR_WIN32 "\\"
+#define DIR_SEP_CHAR_MS_WINDOWS '\\'
+#define DIR_SEP_STR_MS_WINDOWS "\\"
 
-#ifdef SHOULD_CHECK_IF_CYGWIN_SUPPORTS_SLASH_IF_YES_NEVER_DEFINE_THIS
-#define DIR_SEP_CHAR DIR_SEP_CHAR_WIN32
-#define DIR_SEP_STR DIR_SEP_STR_WIN32
+#ifdef LW6_MS_WINDOWS
+#define DIR_SEP_CHAR DIR_SEP_CHAR_MS_WINDOWS
+#define DIR_SEP_STR DIR_SEP_STR_MS_WINDOWS
 #else
 #define DIR_SEP_CHAR DIR_SEP_CHAR_UNIX
-#define DIR_SEP_C DIR_SEP_CHAR_UNIX
+#define DIR_SEP_STR DIR_SEP_STR_UNIX
 #endif
 
 static int
 is_dir_sep (char c)
 {
-  return ((c == DIR_SEP_CHAR_UNIX) || (c == DIR_SEP_CHAR_WIN32));
+  return ((c == DIR_SEP_CHAR_UNIX) || (c == DIR_SEP_CHAR_MS_WINDOWS));
 }
 
-/*
- * Tests if a file exists and is readable.
+static void
+normalize (char *path)
+{
+  char *pos = NULL;
+
+  for (pos = path; (*pos); pos++)
+    {
+      if (is_dir_sep (*pos))
+	{
+	  (*pos) = DIR_SEP_CHAR;
+	}
+    }
+}
+
+/**
+ * lw6sys_file_exists
+ *
+ * @filename: the file to test
+ *
+ * Tests the existence of a file on the filesystem. File is considered
+ * to exists if it's at least readable.
+ *
+ * Return value: 1 if OK, 0 if file doesn't exist or can't be read.
  */
 int
 lw6sys_file_exists (char *filename)
@@ -66,21 +88,27 @@ lw6sys_file_exists (char *filename)
   return ret;
 }
 
-/*
- * Tests if a directory exists.
+/**
+ * lw6sys_dir_exists
+ *
+ * @dirname: the directory to test
+ *
+ * Tests the existence of a directory on the filesystem.
+ *
+ * Return value: 1 if OK, 0 if directory doesn't exist.
  */
 int
 lw6sys_dir_exists (char *dirname)
 {
-  struct dirent **namelist;
-  int n;
   int ret = 0;
+  DIR *dir = NULL;
 
-  n = scandir (dirname, &namelist, NULL, NULL);
-  if (n >= 0)
+  dir = opendir (dirname);
+  if (dir)
     {
+      closedir (dir);
+      dir = NULL;
       ret = 1;
-      free (namelist);
     }
 
   return ret;
@@ -91,13 +119,17 @@ create_dir (char *dirname, int verbose)
 {
   int ret = 0;
 
+#ifdef LW6_MS_WINDOWS
+  if (mkdir (dirname))
+#else
   if (mkdir (dirname, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP) == 0)
+#endif
     {
       if (verbose)
 	{
 	  lw6sys_log (LW6SYS_LOG_INFO, _("creating dir \"%s\""), dirname);
 	}
-      ret = 1;
+      ret = lw6sys_dir_exists (dirname);
     }
   else
     {
@@ -111,8 +143,15 @@ create_dir (char *dirname, int verbose)
   return ret;
 }
 
-/*
- * Wrapper on mkdir with all the options we like, + logs.
+/**
+ * lw6sys_create_dir
+ *
+ * @dirname: the directory to create
+ *
+ * Creates a directory, performing sanity checks such as verifying
+ * the directory really exists after being created.
+ *
+ * Return value: 1 if OK, 0 if error.
  */
 int
 lw6sys_create_dir (char *dirname)
@@ -120,12 +159,35 @@ lw6sys_create_dir (char *dirname)
   return create_dir (dirname, 1);
 }
 
+/**
+ * lw6sys_create_dir_silent
+ *
+ * @dirname: the directory to create
+ *
+ * Creates a directory like @lw6sys_create_dir but this function
+ * is silent in the sense that it won't log any error. Usefull
+ * to create the log directory itself, for instance, and avoid
+ * infinite loops on error.
+ *
+ * Return value: 1 if OK, 0 if error.
+ */
 int
 lw6sys_create_dir_silent (char *dirname)
 {
   return create_dir (dirname, 0);
 }
 
+/**
+ * lw6sys_path_add_slash
+ *
+ * @path: a path
+ *
+ * Adds a slash, or in a general manner, a directory separator,
+ * at the end of a path, if needed. So /foo/bar will become
+ * /foo/bar/ but /bar/foo/ will remain /bar/foo/.
+ *
+ * Return value: a newly allocated string, must be freed.
+ */
 char *
 lw6sys_path_add_slash (char *path)
 {
@@ -135,16 +197,32 @@ lw6sys_path_add_slash (char *path)
   len = strlen (path);
   if (len == 0 || (len > 0 && !is_dir_sep (path[len - 1])))
     {
-      ret = lw6sys_str_concat (path, "/");
+      ret = lw6sys_str_concat (path, DIR_SEP_STR);
     }
   else
     {
       ret = lw6sys_str_copy (path);
     }
 
+  if (ret)
+    {
+      normalize (ret);
+    }
+
   return ret;
 }
 
+/**
+ * lw6sys_path_strip_slash
+ *
+ * @path: a path
+ *
+ * Strips the slash, or in a general manner, the directory separator,
+ * at the end of a path, if needed. So /foo/bar/ will become
+ * /foo/bar but /bar/foo will remain /bar/foo.
+ *
+ * Return value: a newly allocated string, must be freed.
+ */
 char *
 lw6sys_path_strip_slash (char *path)
 {
@@ -161,9 +239,27 @@ lw6sys_path_strip_slash (char *path)
 	}
     }
 
+  if (ret)
+    {
+      normalize (ret);
+    }
+
   return ret;
 }
 
+/**
+ * lw6sys_path_concat
+ *
+ * @path1: left part of the path
+ * @path2: right part of the path
+ *
+ * Concatenates 2 parts of a path. Function will try to avoid
+ * stupid "double-slash" when concatenating /foo/ with /bar/
+ * and conversely insert a directory separator when concatenating
+ * /foo with bar/.
+ *
+ * Return value: a newly allocated string, must be freed.
+ */
 char *
 lw6sys_path_concat (char *path1, char *path2)
 {
@@ -185,7 +281,9 @@ lw6sys_path_concat (char *path1, char *path2)
 	    }
 	  if (strlen (path2_start) > 0 && strcmp (path2_start, ".") != 0)
 	    {
-	      ret = lw6sys_new_sprintf ("%s/%s", path1_stripped, path2_start);
+	      ret =
+		lw6sys_new_sprintf ("%s" DIR_SEP_STR "%s", path1_stripped,
+				    path2_start);
 	    }
 	  else
 	    {
@@ -196,9 +294,23 @@ lw6sys_path_concat (char *path1, char *path2)
       LW6SYS_FREE (path1_stripped);
     }
 
+  if (ret)
+    {
+      normalize (ret);
+    }
+
   return ret;
 }
 
+/**
+ * lw6sys_path_is_relative
+ *
+ * @path: a path
+ *
+ * Checks wether a path is relative or absolute.
+ *
+ * Return value: 1 if relative, 0 if absolute.
+ */
 int
 lw6sys_path_is_relative (char *path)
 {
@@ -206,9 +318,9 @@ lw6sys_path_is_relative (char *path)
 
   if (strcmp (".", path) == 0 ||
       strncmp ("." DIR_SEP_STR_UNIX, path, 2) == 0 ||
-      strncmp ("." DIR_SEP_STR_WIN32, path, 2) == 0 ||
+      strncmp ("." DIR_SEP_STR_MS_WINDOWS, path, 2) == 0 ||
       strncmp (".." DIR_SEP_STR_UNIX, path, 3) == 0 ||
-      strncmp (".." DIR_SEP_STR_WIN32, path, 3) == 0)
+      strncmp (".." DIR_SEP_STR_MS_WINDOWS, path, 3) == 0)
     {
       ret = 1;
     }
@@ -216,6 +328,16 @@ lw6sys_path_is_relative (char *path)
   return ret;
 }
 
+/**
+ * lw6sys_path_parent
+ *
+ * @path: a path
+ *
+ * Returns the parent path. That will return /foo when given
+ * /foo/bar in input. 
+ *
+ * Return value: a newly allocated string, must be freed.
+ */
 char *
 lw6sys_path_parent (char *path)
 {
@@ -254,9 +376,24 @@ lw6sys_path_parent (char *path)
       LW6SYS_FREE (stripped_path);
     }
 
+  if (parent)
+    {
+      normalize (parent);
+    }
+
   return parent;
 }
 
+/**
+ * lw6sys_path_unparent
+ *
+ * @path: a path
+ *
+ * Given the ../foo/bar path, will return foo/bar. Usefull to
+ * get rid of heading ../ when a path is known to start with it.
+ *
+ * Return value: a newly allocated string, must be freed.
+ */
 char *
 lw6sys_path_unparent (char *path)
 {
@@ -267,7 +404,7 @@ lw6sys_path_unparent (char *path)
   if (slashed_path)
     {
       if (strncmp (".." DIR_SEP_STR_UNIX, slashed_path, 3) == 0 ||
-	  strncmp (".." DIR_SEP_STR_WIN32, slashed_path, 3) == 0)
+	  strncmp (".." DIR_SEP_STR_MS_WINDOWS, slashed_path, 3) == 0)
 	{
 	  unparent = lw6sys_str_copy (path + 3);
 	}
@@ -278,16 +415,34 @@ lw6sys_path_unparent (char *path)
       LW6SYS_FREE (slashed_path);
     }
 
+  if (unparent)
+    {
+      normalize (unparent);
+    }
+
   return unparent;
 }
 
+/**
+ * lw6sys_path_unparent_no_malloc
+ *
+ * @path: a path
+ *
+ * Given the ../foo/bar path, will return foo/bar. Usefull to
+ * get rid of heading ../ when a path is known to start with it.
+ * This is different from @lw6sys_path_unparent just because
+ * the result is not dynamically allocated and copied from source.
+ *
+ * Return value: a pointer which points somewhere within the
+ *   string passed as an argument.
+ */
 char *
 lw6sys_path_unparent_no_malloc (char *path)
 {
   char *unparent = NULL;
 
   if (strncmp (".." DIR_SEP_STR_UNIX, path, 3) == 0 ||
-      strncmp (".." DIR_SEP_STR_WIN32, path, 3) == 0)
+      strncmp (".." DIR_SEP_STR_MS_WINDOWS, path, 3) == 0)
     {
       unparent = path + 3;
     }
