@@ -20,13 +20,13 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "sys.h"
 
-#define TEST_KEYWORD_AS "---this-is_a_TEST-KeYWord"
+#define TEST_KEYWORD_AS "--this-is_a_TEST-KeYWord"
 #define TEST_ARG_KEYWORD "my-option"
 #define TEST_ARG_ARGV_STRING "--my-option=my-value"
 #define CHECKSUM_INT32_DATA 1234
@@ -36,12 +36,21 @@
 #define COLOR_8_G 0x34
 #define COLOR_8_B 0x56
 #define COLOR_8_A 0x78
+#ifdef LW6_MS_WINDOWS
+#define PATH_WITH_SLASH "\\foo\\bar\\"
+#define PATH_WITHOUT_SLASH "\\foo\\bar"
+#define PATH_CONCAT "\\foo\\bar\\foo\\bar"
+#define PATH_CONCAT_PARENT "\\foo\\bar\\foo"
+#define PATH_RELATIVE "..\\..\\foo\\bar"
+#define PATH_RELATIVE_UNPARENT "..\\foo\\bar"
+#else
 #define PATH_WITH_SLASH "/foo/bar/"
 #define PATH_WITHOUT_SLASH "/foo/bar"
 #define PATH_CONCAT "/foo/bar/foo/bar"
 #define PATH_CONCAT_PARENT "/foo/bar/foo"
 #define PATH_RELATIVE "../../foo/bar"
 #define PATH_RELATIVE_UNPARENT "../foo/bar"
+#endif
 #define MALLOC_SIZE 1048576
 #define THREAD_N 5
 #define THREAD_SLEEP_MAIN 0.66f
@@ -52,11 +61,17 @@
 #define ASCII_STR "foo,bar"
 #define TEST_ARGC 4
 #define TEST_ARGV0 "test.out"
+#ifdef LW6_MS_WINDOWS
+#define TEST_ARGV1 "--prefix=C:\\toto"
+#define TEST_ARGV2 "-map-dir=C:\\home\\user\\my-maps\\"
+#else
 #define TEST_ARGV1 "--prefix=/toto"
 #define TEST_ARGV2 "-map-dir=/home/user/my-maps/"
+#endif
 #define TEST_ARGV3 "THISisAbug!==--foobar=123---?\\"
-#define TEST_FILENAME "/tmp/this-is-a-test.txt"
+#define TEST_FILENAME "test.txt"
 #define TEST_CONTENT "This is a test"
+#define TEST_DUMP "This...\n...is a dump\n"
 #define TEST_HEXA_INT64 1
 #define TEST_HEXA_INT32 123456789
 #define TEST_HEXA_INT16 12345
@@ -68,11 +83,21 @@
 #define TEST_HEXA_XY {3,4}
 #define TEST_HEXA_COLOR {25,50,75,100}
 #define TEST_KEYWORD "prefix"
+#ifdef LW6_MS_WINDOWS
+#define TEST_ENV_CONCAT1 "\\my\\path\\1"
+#define TEST_ENV_CONCAT2 "\\my\\path\\2"
+#else
 #define TEST_ENV_CONCAT1 "/my/path/1"
 #define TEST_ENV_CONCAT2 "/my/path/2"
-#define TEST_ENV_PUTENV "LW6_MY_KEY=my-value"
+#endif
+#define TEST_ENV_SETENV_KEYWORD "LW6_MY_KEY"
+#define TEST_ENV_SETENV_VALUE "my-value"
 #define TEST_ENV_KEYWORD "my-key"
+#ifdef LW6_MS_WINDOWS
+#define TEST_ENV_SPLIT "foo1\\foo2;foo3:bar1;bar2\\bar3"
+#else
 #define TEST_ENV_SPLIT "foo1/foo2;foo3:bar1;bar2/bar3"
+#endif
 #define TEST_REFORMAT_STR1 "this is a short string"
 #define TEST_REFORMAT_STR2 "this is a very long string it should be cut in some places but wherever there is a very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very long word it won't be cut.\n\nIt should even handle newlines in some places but well, this is not absolutely necessary"
 #define TEST_REFORMAT_PREFIX "# "
@@ -91,6 +116,9 @@
 #define TEST_CONVERT_INT 421
 #define TEST_CONVERT_BOOL 1
 #define TEST_CONVERT_FLOAT 3.14f
+#define TEST_RANDOM_RANGE 1000
+#define TEST_RANDOM_FLOAT_MIN 100.0f
+#define TEST_RANDOM_FLOAT_MAX 101.0f
 
 /*
  * Testing functions in arg.c
@@ -107,7 +135,7 @@ test_arg ()
     char *argv[TEST_ARGC] =
       { TEST_ARGV0, TEST_ARGV1, TEST_ARGV2, TEST_ARGV3 };
 
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("trying to match \"%s\""),
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("trying to match \"%s\""),
 		TEST_ARG_ARGV_STRING);
     if (lw6sys_arg_match (TEST_ARG_KEYWORD, TEST_ARG_ARGV_STRING))
       {
@@ -124,7 +152,7 @@ test_arg ()
 
     if (lw6sys_arg_exists (argc, argv, TEST_KEYWORD))
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("keyword \"%s\" is present"),
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("keyword \"%s\" is present"),
 		    TEST_KEYWORD);
       }
     else
@@ -137,7 +165,7 @@ test_arg ()
     value = lw6sys_arg_get_value (argc, argv, TEST_KEYWORD);
     if (value)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("value for \"%s\" is \"%s\""),
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("value for \"%s\" is \"%s\""),
 		    TEST_KEYWORD, value);
 	LW6SYS_FREE (value);
       }
@@ -162,7 +190,7 @@ assoc_map_func (void *func_data, char *key, void *value)
   int *ret = (int *) func_data;
   int *i = (int *) value;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG,
+  lw6sys_log (LW6SYS_LOG_NOTICE,
 	      _("assoc item ret=%d, key=\"%s\", value=%d"), *ret, key, *i);
 }
 
@@ -178,7 +206,7 @@ test_assoc ()
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("new/delete on assoc"));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("new/delete on assoc"));
     assoc = lw6sys_assoc_new (NULL);
     lw6sys_assoc_free (assoc);
   }
@@ -186,7 +214,7 @@ test_assoc ()
   {
     int a = 3, b = 5, c = 7;
 
-    lw6sys_log (LW6SYS_LOG_DEBUG,
+    lw6sys_log (LW6SYS_LOG_NOTICE,
 		_("set/unset/has_key/get/map on int assoc"));
     assoc = lw6sys_assoc_new (NULL);
     lw6sys_assoc_set (&assoc, "a", (void *) &a);
@@ -208,7 +236,7 @@ test_assoc ()
   {
     char *str1, *str2, *str3;
 
-    lw6sys_log (LW6SYS_LOG_DEBUG,
+    lw6sys_log (LW6SYS_LOG_NOTICE,
 		_("testing free_func callback and dup on string assoc"));
     assoc = lw6sys_assoc_new (&lw6sys_free_callback);
     str1 = LW6SYS_MALLOC (5);
@@ -236,7 +264,7 @@ test_assoc ()
     int a = 3, b = 5;
     lw6sys_list_t *keys;
 
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("testing keys on int assoc"));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("testing keys on int assoc"));
     assoc = lw6sys_assoc_new (NULL);
     lw6sys_assoc_set (&assoc, "a", (void *) &a);
     lw6sys_assoc_set (&assoc, "b", (void *) &b);
@@ -261,7 +289,7 @@ test_build ()
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("build version is \"%s\""),
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("build version is \"%s\""),
 		lw6sys_build_get_version ());
 
     lw6sys_build_log_pedigree ();
@@ -284,7 +312,7 @@ test_checksum ()
     u_int32_t checksum = 0;
 
     lw6sys_checksum_update_int32 (&checksum, CHECKSUM_INT32_DATA);
-    lw6sys_log (LW6SYS_LOG_DEBUG,
+    lw6sys_log (LW6SYS_LOG_NOTICE,
 		_("checksum for %d is %08x (should be %08x)"),
 		CHECKSUM_INT32_DATA, checksum, CHECKSUM_INT32_RESULT);
     if (checksum != CHECKSUM_INT32_RESULT)
@@ -303,13 +331,13 @@ rgb_to_hsv_to_rgb (char *label, lw6sys_color_8_t color_8)
   lw6sys_color_hsv_t color_hsv;
   lw6sys_color_8_t color_8_back;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("%s init r=%d,g=%d,b=%d"), label, color_8.r,
-	      color_8.g, color_8.b);
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("%s init r=%d,g=%d,b=%d"), label,
+	      color_8.r, color_8.g, color_8.b);
   lw6sys_color_rgb_to_hsv (&color_hsv, color_8);
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("%s HSV convert h=%.2f,s=%.2f,v=%.2f"),
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("%s HSV convert h=%.2f,s=%.2f,v=%.2f"),
 	      label, color_hsv.h, color_hsv.s, color_hsv.v);
   color_8_back = lw6sys_color_hsv_to_rgb (&color_hsv);
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("%s RGB convert r=%d,g=%d,b=%d"), label,
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("%s RGB convert r=%d,g=%d,b=%d"), label,
 	      color_8_back.r, color_8_back.g, color_8_back.b);
 }
 
@@ -328,7 +356,7 @@ test_color ()
     lw6sys_color_8_t color_8_average[3];
     float distance;
 
-    lw6sys_log (LW6SYS_LOG_DEBUG,
+    lw6sys_log (LW6SYS_LOG_NOTICE,
 		_("interpreting color \"%s\""), COLOR_ASCII);
     color_8 = lw6sys_color_a_to_8 (COLOR_ASCII);
     if (color_8.r != COLOR_8_R || color_8.g != COLOR_8_G
@@ -349,7 +377,7 @@ test_color ()
 
     color_8 =
       lw6sys_color_ponderate (LW6SYS_COLOR_8_RED, LW6SYS_COLOR_8_BLUE, 0.5f);
-    lw6sys_log (LW6SYS_LOG_DEBUG,
+    lw6sys_log (LW6SYS_LOG_NOTICE,
 		_("color between red & blue is r=%d,g=%d,b=%d"), color_8.r,
 		color_8.g, color_8.b);
 
@@ -357,12 +385,12 @@ test_color ()
     color_8_average[1] = LW6SYS_COLOR_8_RED;
     color_8_average[2] = LW6SYS_COLOR_8_GREEN;
     color_8 = lw6sys_color_average (3, color_8_average);
-    lw6sys_log (LW6SYS_LOG_DEBUG,
+    lw6sys_log (LW6SYS_LOG_NOTICE,
 		_("color average of red+red+green is r=%d,g=%d,b=%d"),
 		color_8.r, color_8.g, color_8.b);
     distance =
       lw6sys_color_distance (LW6SYS_COLOR_8_GREEN, LW6SYS_COLOR_8_BLUE);
-    lw6sys_log (LW6SYS_LOG_DEBUG,
+    lw6sys_log (LW6SYS_LOG_NOTICE,
 		_("distance between green and blue is %.2f"), distance);
   }
 
@@ -388,7 +416,7 @@ test_convert ()
     if (str)
       {
 	i = lw6sys_atoi (str);
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("int=%d -> str=\"%s\" -> int=%d"),
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("int=%d -> str=\"%s\" -> int=%d"),
 		    TEST_CONVERT_INT, str, i);
 	if (i != TEST_CONVERT_INT)
 	  {
@@ -405,7 +433,7 @@ test_convert ()
     if (str)
       {
 	i = lw6sys_atob (str);
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("bool=%d -> str=\"%s\" -> bool=%d"),
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("bool=%d -> str=\"%s\" -> bool=%d"),
 		    TEST_CONVERT_BOOL, str, i);
 	if (i != TEST_CONVERT_BOOL)
 	  {
@@ -422,7 +450,8 @@ test_convert ()
     if (str)
       {
 	f = lw6sys_atof (str);
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("float=%f -> str=\"%s\" -> float=%f"),
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("float=%f -> str=\"%s\" -> float=%f"),
 		    TEST_CONVERT_FLOAT, str, f);
 	if (f != TEST_CONVERT_FLOAT)
 	  {
@@ -458,9 +487,12 @@ test_dump ()
     user_dir = lw6sys_get_default_user_dir ();
     if (user_dir)
       {
-	lw6sys_create_dir (user_dir);
+	if (!lw6sys_dir_exists (user_dir))
+	  {
+	    lw6sys_create_dir (user_dir);
+	  }
 	lw6sys_dump_clear (user_dir);
-	if (!lw6sys_dump (user_dir, TEST_CONTENT))
+	if (!lw6sys_dump (user_dir, TEST_DUMP))
 	  {
 	    ret = 0;
 	  }
@@ -492,14 +524,19 @@ test_env ()
     concat = lw6sys_env_concat (TEST_ENV_CONCAT1, TEST_ENV_CONCAT2);
     if (concat)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("ENV concat is \"%s\""), concat);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("ENV concat is \"%s\""), concat);
 	LW6SYS_FREE (concat);
       }
     else
       {
 	ret = 0;
       }
-    putenv (TEST_ENV_PUTENV);
+    if (!lw6sys_setenv (TEST_ENV_SETENV_KEYWORD, TEST_ENV_SETENV_VALUE))
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING, _("unable to set ENV \"%s\""),
+		    TEST_ENV_SETENV_KEYWORD);
+	ret = 0;
+      }
     if (!lw6sys_env_exists (TEST_ENV_KEYWORD))
       {
 	lw6sys_log (LW6SYS_LOG_WARNING, _("ENV \"%s\" doesn't exist"),
@@ -509,7 +546,7 @@ test_env ()
     value = lw6sys_getenv (TEST_ENV_KEYWORD);
     if (value)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("ENV value for \"%s\" is \"%s\""),
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("ENV value for \"%s\" is \"%s\""),
 		    TEST_ENV_KEYWORD, value);
 	LW6SYS_FREE (value);
       }
@@ -520,7 +557,7 @@ test_env ()
     value = lw6sys_get_username ();
     if (value)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("username=\"%s\""), value);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("username=\"%s\""), value);
 	LW6SYS_FREE (value);
       }
     else
@@ -530,7 +567,7 @@ test_env ()
     value = lw6sys_get_hostname ();
     if (value)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("hostname=\"%s\""), value);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("hostname=\"%s\""), value);
 	LW6SYS_FREE (value);
       }
     else
@@ -559,7 +596,7 @@ test_env ()
 	while (splitted
 	       && (data = (char *) lw6sys_lifo_pop (&splitted)) != NULL)
 	  {
-	    lw6sys_log (LW6SYS_LOG_DEBUG,
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
 			_("splitted env \"%s\" contains \"%s\""),
 			TEST_ENV_SPLIT, data);
 	    LW6SYS_FREE (data);
@@ -587,25 +624,45 @@ test_file ()
 
   {
     char *content = NULL;
+    char *user_dir = NULL;
+    char *filename = NULL;
+    int argc = TEST_ARGC;
+    char *argv[TEST_ARGC] =
+      { TEST_ARGV0, TEST_ARGV1, TEST_ARGV2, TEST_ARGV3 };
 
-    if (lw6sys_write_file_content (TEST_FILENAME, TEST_CONTENT))
+    user_dir = lw6sys_get_user_dir (argc, argv);
+    if (user_dir)
       {
-	content = lw6sys_read_file_content (TEST_FILENAME);
+	if (!lw6sys_dir_exists (user_dir))
+	  {
+	    lw6sys_create_dir (user_dir);
+	  }
+	filename = lw6sys_path_concat (user_dir, TEST_FILENAME);
+	if (filename)
+	  {
+	    if (lw6sys_write_file_content (filename, TEST_CONTENT))
+	      {
+		content = lw6sys_read_file_content (filename);
 
-	if (content && !strcmp (TEST_CONTENT, content))
-	  {
-	    lw6sys_log (LW6SYS_LOG_DEBUG, _("file \"%s\" contains \"%s\""),
-			TEST_FILENAME, content);
-	    LW6SYS_FREE (content);
+		if (content && !strcmp (TEST_CONTENT, content))
+		  {
+		    lw6sys_log (LW6SYS_LOG_NOTICE,
+				_("file \"%s\" contains \"%s\""),
+				filename, content);
+		    LW6SYS_FREE (content);
+		  }
+		else
+		  {
+		    ret = 0;
+		  }
+	      }
+	    else
+	      {
+		ret = 0;
+	      }
+	    LW6SYS_FREE (filename);
 	  }
-	else
-	  {
-	    ret = 0;
-	  }
-      }
-    else
-      {
-	ret = 0;
+	LW6SYS_FREE (user_dir);
       }
   }
 
@@ -668,7 +725,7 @@ test_hexa ()
 	    hexa_string = lw6sys_hexa_serializer_as_string (hexa_serializer);
 	    if (hexa_string)
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("hexa string is \"%s\""),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("hexa string is \"%s\""),
 			    hexa_string);
 		LW6SYS_FREE (hexa_string);
 	      }
@@ -684,7 +741,7 @@ test_hexa ()
 
 	    if (lw6sys_hexa_serializer_pop_int64 (hexa_serializer, &test_64))
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("int64 loaded, value=%d"),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("int64 loaded, value=%d"),
 			    (int) test_64);
 	      }
 	    else
@@ -693,7 +750,7 @@ test_hexa ()
 	      }
 	    if (lw6sys_hexa_serializer_pop_int32 (hexa_serializer, &test_32))
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("int32 loaded, value=%d"),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("int32 loaded, value=%d"),
 			    (int) test_32);
 	      }
 	    else
@@ -702,7 +759,7 @@ test_hexa ()
 	      }
 	    if (lw6sys_hexa_serializer_pop_int16 (hexa_serializer, &test_16))
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("int16 loaded, value=%d"),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("int16 loaded, value=%d"),
 			    (int) test_16);
 	      }
 	    else
@@ -711,7 +768,7 @@ test_hexa ()
 	      }
 	    if (lw6sys_hexa_serializer_pop_int8 (hexa_serializer, &test_8))
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("int8 loaded, value=%d"),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("int8 loaded, value=%d"),
 			    (int) test_8);
 	      }
 	    else
@@ -721,7 +778,7 @@ test_hexa ()
 	    if (lw6sys_hexa_serializer_pop_float
 		(hexa_serializer, &test_float))
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("float loaded, value=%f"),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("float loaded, value=%f"),
 			    test_float);
 	      }
 	    else
@@ -730,7 +787,7 @@ test_hexa ()
 	      }
 	    if (lw6sys_hexa_serializer_pop_str (hexa_serializer, &test_str))
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("str loaded, value=\"%s\""),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("str loaded, value=\"%s\""),
 			    test_str);
 		LW6SYS_FREE (test_str);
 	      }
@@ -740,7 +797,7 @@ test_hexa ()
 	      }
 	    if (lw6sys_hexa_serializer_pop_str (hexa_serializer, &test_str))
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("str loaded, value=\"%s\""),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("str loaded, value=\"%s\""),
 			    test_str);
 		LW6SYS_FREE (test_str);
 	      }
@@ -750,7 +807,7 @@ test_hexa ()
 	      }
 	    if (lw6sys_hexa_serializer_pop_wh (hexa_serializer, &test_wh))
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("wh loaded, value=%dx%d"),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("wh loaded, value=%dx%d"),
 			    (int) test_wh.w, (int) test_wh.h);
 	      }
 	    else
@@ -759,7 +816,7 @@ test_hexa ()
 	      }
 	    if (lw6sys_hexa_serializer_pop_xy (hexa_serializer, &test_xy))
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("xy loaded, value=%d,%d"),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("xy loaded, value=%d,%d"),
 			    (int) test_xy.x, (int) test_xy.y);
 	      }
 	    else
@@ -769,7 +826,7 @@ test_hexa ()
 	    if (lw6sys_hexa_serializer_pop_color
 		(hexa_serializer, &test_color))
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG,
+		lw6sys_log (LW6SYS_LOG_NOTICE,
 			    _("color loaded, value=#%02x%02x%02x%02x"),
 			    (int) test_color.r, (int) test_color.g,
 			    (int) test_color.b, (int) test_color.a);
@@ -780,7 +837,7 @@ test_hexa ()
 	      }
 	    if (lw6sys_hexa_serializer_eof (hexa_serializer))
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("serializer EOF"));
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("serializer EOF"));
 	      }
 	    else
 	      {
@@ -846,25 +903,25 @@ test_keyword ()
     str = lw6sys_keyword_as_key (TEST_KEYWORD_AS);
     if (str)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("keyword as key is \"%s\""), str);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("keyword as key is \"%s\""), str);
 	LW6SYS_FREE (str);
       }
     str = lw6sys_keyword_as_arg (TEST_KEYWORD_AS);
     if (str)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("keyword as arg is \"%s\""), str);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("keyword as arg is \"%s\""), str);
 	LW6SYS_FREE (str);
       }
     str = lw6sys_keyword_as_env (TEST_KEYWORD_AS);
     if (str)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("keyword as env is \"%s\""), str);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("keyword as env is \"%s\""), str);
 	LW6SYS_FREE (str);
       }
     str = lw6sys_keyword_as_xml (TEST_KEYWORD_AS);
     if (str)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("keyword as xml is \"%s\""), str);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("keyword as xml is \"%s\""), str);
 	LW6SYS_FREE (str);
       }
   }
@@ -882,7 +939,7 @@ list_map_func (void *func_data, void *data)
   int *ret = (int *) func_data;
   int *i = (int *) data;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("list item ret=%d, data=%d"), *ret, *i);
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("list item ret=%d, data=%d"), *ret, *i);
 }
 
 /*
@@ -897,7 +954,7 @@ test_list ()
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("new/delete/is_empty on list"));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("new/delete/is_empty on list"));
     list = lw6sys_list_new (NULL);
     ret = ret && lw6sys_list_is_empty (list);
     lw6sys_list_free (list);
@@ -906,7 +963,7 @@ test_list ()
   {
     int a = 3, b = 5, c = 7;
 
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("lifo push/pop on int list"));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("lifo push/pop on int list"));
     list = lw6sys_list_new (NULL);
     lw6sys_lifo_push (&list, (void *) &a);
     lw6sys_lifo_push (&list, (void *) &b);
@@ -922,7 +979,7 @@ test_list ()
   {
     int a = 2, b = 4, c = 6, d = 8;
 
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("fifo push/pop on int list"));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("fifo push/pop on int list"));
     list = lw6sys_list_new (NULL);
     lw6sys_fifo_push (&list, (void *) &a);
     lw6sys_fifo_push (&list, (void *) &b);
@@ -940,7 +997,7 @@ test_list ()
   {
     int a = 32, b = 64, c = 128, d = 256, e = 512;
 
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("front/back push/pop on int list"));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("front/back push/pop on int list"));
     list = lw6sys_list_new (NULL);
     lw6sys_list_push_front (&list, (void *) &a);
     lw6sys_list_push_front (&list, (void *) &b);
@@ -960,7 +1017,7 @@ test_list ()
   {
     char *str1, *str2, *str3, *str4;
 
-    lw6sys_log (LW6SYS_LOG_DEBUG,
+    lw6sys_log (LW6SYS_LOG_NOTICE,
 		_("testing free_func callback and dup on string list"));
     list = lw6sys_list_new (&lw6sys_free_callback);
     str1 = lw6sys_str_copy ("str1");
@@ -978,7 +1035,7 @@ test_list ()
   }
 
   {
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("testing final pop behavior"));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("testing final pop behavior"));
 
     list = lw6sys_list_new (NULL);
     if (list)
@@ -1020,11 +1077,22 @@ test_log ()
   int ret = 1;
   LW6SYS_TEST_FUNCTION_BEGIN;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("testing log_debug %s=%d"), "toto", 0);
-  lw6sys_log (LW6SYS_LOG_INFO, _("testing log_info %s=%d"), "toto", 0);
-  /*
-   * We do not test WARNING & ERROR to avoid confusion...
-   */
+  {
+    int log_level;
+
+    log_level = lw6sys_log_get_level ();
+    lw6sys_log_set_level (log_level);
+    /*
+     * We do not test WARNING & ERROR to avoid confusion...
+     */
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("testing log_notice %s=%d"),
+		"log_level=%d", log_level);
+    lw6sys_log (LW6SYS_LOG_INFO, _("testing log_info %s=%d"), "log_level=%d",
+		log_level);
+    // normally, this one does now show with defaults settings...
+    lw6sys_log (LW6SYS_LOG_DEBUG, _("testing log_debug %s=%d"),
+		"log_level=%d", log_level);
+  }
 
   LW6SYS_TEST_FUNCTION_END;
   return ret;
@@ -1040,19 +1108,19 @@ test_mem ()
   char *ptr = NULL;
   LW6SYS_TEST_FUNCTION_BEGIN;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG,
+  lw6sys_log (LW6SYS_LOG_NOTICE,
 	      _("testing MALLOC/FREE (%d bytes)"), MALLOC_SIZE);
   ptr = (char *) LW6SYS_MALLOC (MALLOC_SIZE * sizeof (char));
   ret = ret && (ptr != NULL);
   LW6SYS_FREE (ptr);
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("%d megs"), lw6sys_megabytes_available ());
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("%d megs"), lw6sys_megabytes_available ());
   if (lw6sys_is_big_endian ())
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("big endian"));
+      lw6sys_log (LW6SYS_LOG_NOTICE, _("big endian"));
     }
   if (lw6sys_is_little_endian ())
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("little endian"));
+      lw6sys_log (LW6SYS_LOG_NOTICE, _("little endian"));
     }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -1070,7 +1138,7 @@ test_mutex ()
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("testing mutex functions"));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("testing mutex functions"));
     mutex = lw6sys_mutex_create ();
     if (mutex)
       {
@@ -1113,7 +1181,7 @@ test_options ()
     path = lw6sys_get_default_user_dir ();
     if (path)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("default user dir is \"%s\""), path);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("default user dir is \"%s\""), path);
 	LW6SYS_FREE (path);
       }
     else
@@ -1124,7 +1192,7 @@ test_options ()
     path = lw6sys_get_default_prefix ();
     if (path)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("default prefix is \"%s\""), path);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("default prefix is \"%s\""), path);
 	LW6SYS_FREE (path);
       }
     else
@@ -1144,7 +1212,7 @@ test_options ()
     path = lw6sys_get_user_dir (argc, argv);
     if (path)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("user dir is \"%s\""), path);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("user dir is \"%s\""), path);
 	LW6SYS_FREE (path);
       }
     else
@@ -1155,7 +1223,7 @@ test_options ()
     path = lw6sys_get_prefix (argc, argv);
     if (path)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("prefix is \"%s\""), path);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("prefix is \"%s\""), path);
 	LW6SYS_FREE (path);
       }
     else
@@ -1199,7 +1267,7 @@ test_path ()
     char *path;
     int relative;
 
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("add/strip slash"));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("add/strip slash"));
     path = lw6sys_path_add_slash (PATH_WITHOUT_SLASH);
     if (path)
       {
@@ -1212,11 +1280,11 @@ test_path ()
 	ret = ret && (strcmp (path, PATH_WITHOUT_SLASH) == 0);
 	LW6SYS_FREE (path);
       }
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("concat path"));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("concat path"));
     path = lw6sys_path_concat (PATH_WITH_SLASH, PATH_WITH_SLASH);
     if (path)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("concatenated path = \"%s\""), path);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("concatenated path = \"%s\""), path);
 	ret = ret && (strcmp (path, PATH_CONCAT) == 0);
 	LW6SYS_FREE (path);
       }
@@ -1230,19 +1298,19 @@ test_path ()
     path = lw6sys_path_parent (PATH_CONCAT);
     if (path)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("parent path = \"%s\""), path);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("parent path = \"%s\""), path);
 	ret = ret && (strcmp (path, PATH_CONCAT_PARENT) == 0);
 	LW6SYS_FREE (path);
       }
     path = lw6sys_path_unparent (PATH_RELATIVE);
     if (path)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("unparent path = \"%s\""), path);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("unparent path = \"%s\""), path);
 	ret = ret && (strcmp (path, PATH_RELATIVE_UNPARENT) == 0);
 	LW6SYS_FREE (path);
       }
     path = lw6sys_path_unparent_no_malloc (PATH_RELATIVE);
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("unparent path = \"%s\""), path);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("unparent path = \"%s\""), path);
     ret = ret && (strcmp (path, PATH_RELATIVE_UNPARENT) == 0);
   }
 
@@ -1250,6 +1318,33 @@ test_path ()
   return ret;
 }
 
+/*
+ * Testing functions in random.c
+ */
+static int
+test_random ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    int i;
+    float f;
+
+    i = lw6sys_random (TEST_RANDOM_RANGE);
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_("here's a random number between 0 and %d: %d"),
+		TEST_RANDOM_RANGE, i);
+    f = lw6sys_random_float (TEST_RANDOM_FLOAT_MIN, TEST_RANDOM_FLOAT_MAX);
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_("here's a random float number between %f and %f: %f"),
+		TEST_RANDOM_FLOAT_MIN, TEST_RANDOM_FLOAT_MAX, f);
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /*
  * Testing functions in sort.c
  */
@@ -1276,7 +1371,7 @@ test_sort ()
 	  {
 	    if ((*((int *) (list->data))) == TEST_SORT_INT_MIN)
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("min sorted value is %d"),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("min sorted value is %d"),
 			    TEST_SORT_INT_MIN);
 	      }
 	    else
@@ -1292,7 +1387,7 @@ test_sort ()
 	  {
 	    if ((*((int *) (list->data))) == TEST_SORT_INT_MAX)
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("max sorted value is %d"),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("max sorted value is %d"),
 			    TEST_SORT_INT_MAX);
 	      }
 	    else
@@ -1335,7 +1430,7 @@ test_sort ()
 	  {
 	    if ((*((float *) (list->data))) == TEST_SORT_FLOAT_MIN)
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("min sorted value is %f"),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("min sorted value is %f"),
 			    TEST_SORT_FLOAT_MIN);
 	      }
 	    else
@@ -1351,7 +1446,7 @@ test_sort ()
 	  {
 	    if ((*((float *) (list->data))) == TEST_SORT_FLOAT_MAX)
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("max sorted value is %f"),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("max sorted value is %f"),
 			    TEST_SORT_FLOAT_MAX);
 	      }
 	    else
@@ -1394,7 +1489,8 @@ test_sort ()
 	  {
 	    if (!strcmp ((char *) (list->data), TEST_SORT_STR_MIN))
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("min sorted value is \"%s\""),
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _("min sorted value is \"%s\""),
 			    TEST_SORT_STR_MIN);
 	      }
 	    else
@@ -1411,7 +1507,8 @@ test_sort ()
 	  {
 	    if (!strcmp ((char *) (list->data), TEST_SORT_STR_MAX))
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG, _("max sorted value is \"%s\""),
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _("max sorted value is \"%s\""),
 			    TEST_SORT_STR_MAX);
 	      }
 	    else
@@ -1454,14 +1551,16 @@ test_str ()
   {
     char *str;
 
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("testing is_blank on \"%s\""), BLANK_STR);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("testing is_blank on \"%s\""),
+		BLANK_STR);
     ret = ret && lw6sys_str_is_blank (BLANK_STR);
     str =
       lw6sys_str_reformat (TEST_REFORMAT_STR1, TEST_REFORMAT_PREFIX,
 			   TEST_REFORMAT_COLUMNS);
     if (str)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("reformatted string is \"%s\""), str);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("reformatted string is \"%s\""),
+		    str);
 	LW6SYS_FREE (str);
       }
     else
@@ -1474,7 +1573,8 @@ test_str ()
 			   TEST_REFORMAT_COLUMNS);
     if (str)
       {
-	lw6sys_log (LW6SYS_LOG_DEBUG, _("reformatted string is \"%s\""), str);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("reformatted string is \"%s\""),
+		    str);
 	LW6SYS_FREE (str);
       }
     else
@@ -1497,7 +1597,7 @@ test_sdl ()
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
-    lw6sys_log (LW6SYS_LOG_DEBUG, _("register/unregister SDL"));
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("register/unregister SDL"));
     ret = ret && lw6sys_sdl_register () && lw6sys_sdl_unregister ();
   }
 
@@ -1562,10 +1662,10 @@ thread_func (void *callback_data)
   char *text = NULL;
 
   text = (char *) callback_data;
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("thread_callback text=\"%s\""), text);
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("thread_callback text=\"%s\""), text);
   for (i = 0; i < THREAD_N; ++i)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("thread_callback step %d"), i + 1);
+      lw6sys_log (LW6SYS_LOG_NOTICE, _("thread_callback step %d"), i + 1);
       lw6sys_sleep (THREAD_SLEEP_CALLBACK);
     }
 }
@@ -1603,7 +1703,7 @@ test_thread ()
 	  {
 	    for (i = 0; i < THREAD_N; ++i)
 	      {
-		lw6sys_log (LW6SYS_LOG_DEBUG,
+		lw6sys_log (LW6SYS_LOG_NOTICE,
 			    _("thread_main step %d, callback_done=%d"), i + 1,
 			    lw6sys_thread_is_callback_done (thread_handler));
 		lw6sys_sleep (THREAD_SLEEP_MAIN);
@@ -1628,16 +1728,25 @@ test_time ()
   int ret = 1;
   LW6SYS_TEST_FUNCTION_BEGIN;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("timestamp %lld"), lw6sys_timestamp ());
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("sleep %d seconds"), SLEEP_TIME);
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("timestamp %lld"), lw6sys_timestamp ());
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("uptime %lld"), lw6sys_uptime ());
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("sleep %d seconds"), SLEEP_TIME);
   lw6sys_sleep (SLEEP_TIME);
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("uptime %lld"), lw6sys_uptime ());
 
   LW6SYS_TEST_FUNCTION_END;
   return ret;
 }
 
-/*
- * Launch tests
+/**
+ * lw6sys_test
+ *
+ * Runs the @sys module test suite, testing most (if not all...)
+ * functions. Note that some tests perform file system operations
+ * and might therefore fail on a read-only filesystem, or if
+ * user permissions are not sufficient.
+ *
+ * Return value: 1 if test is successfull, 0 on error.
  */
 int
 lw6sys_test ()
@@ -1648,9 +1757,9 @@ lw6sys_test ()
     && test_color () && test_convert () && test_dump () && test_env ()
     && test_file () && test_hexa () && test_i18n () && test_keyword ()
     && test_list () && test_log () && test_mem () && test_mutex ()
-    && test_options () && test_nop () && test_path () && test_sdl ()
-    && test_serial () && test_sort () && test_str () && test_thread ()
-    && test_time ();
+    && test_options () && test_nop () && test_path () && test_random ()
+    && test_sdl () && test_serial () && test_sort () && test_str ()
+    && test_thread () && test_time ();
 
   return ret;
 }
