@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,10 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <string.h>
-#include <stdio.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "sys.h"
 #include "sys-internal.h"
 
