@@ -40,15 +40,60 @@
 #include <locale.h>
 #endif
 
+/*
+ * Those are so common it saves time to always include them
+ */
 #include <stdlib.h>
 #include <stdio.h>
+#include <string.h>
 #include <sys/types.h>
+#ifdef LW6_MS_WINDOWS
+#ifndef LW6_SKIP_WINDOWS_H
+#include <windows.h>
+#endif
+#endif
 
-#define LW6SYS_MAIN_BEGIN { setlocale (LC_ALL, ""); bindtextdomain (lw6sys_build_get_package_tarname (), lw6sys_build_get_localedir ()); textdomain (lw6sys_build_get_package_tarname ()); lw6sys_default_memory_bazooka(); }
+/*
+ * Redefining basic types mostly for platforms like MinGW which do
+ * not have a complete nice GNU libc 8-(
+ */
+#ifdef LW6_MS_WINDOWS
+#ifndef int8_t
+typedef signed char int8_t;
+#endif
+#ifndef int16_t
+typedef signed short int16_t;
+#endif
+#ifndef int32_t
+typedef signed int int32_t;
+#endif
+#ifndef int64_t
+typedef signed long long int64_t;
+#endif
+#ifndef u_int8_t
+typedef unsigned char u_int8_t;
+#endif
+#ifndef u_int16_t
+typedef unsigned short u_int16_t;
+#endif
+#ifndef u_int32_t
+typedef unsigned int u_int32_t;
+#endif
+#ifndef u_int64_t
+typedef unsigned long long u_int64_t;
+#endif
+#endif // MS_WINDOWS
+
+#define LW6SYS_MAIN_BEGIN { setlocale (LC_ALL, ""); bindtextdomain (lw6sys_build_get_package_tarname (), lw6sys_build_get_localedir ()); textdomain (lw6sys_build_get_package_tarname ()); lw6sys_time_init(); lw6sys_default_memory_bazooka(); }
 #define LW6SYS_MAIN_END { ret = lw6sys_check_thread_count () && ret; ret = lw6sys_memory_bazooka_report() && ret; lw6sys_clear_memory_bazooka(); }
 
-#define LW6SYS_TEST_FUNCTION_BEGIN { lw6sys_log(LW6SYS_LOG_DEBUG,_("running tests in function \"%s\""),__FUNCTION__); }
-#define LW6SYS_TEST_FUNCTION_END   if (ret) { lw6sys_log(LW6SYS_LOG_DEBUG,_("tests in \"%s\" OK"),__FUNCTION__); } else { lw6sys_log(LW6SYS_LOG_WARNING,_("tests in \"%s\" failed"),__FUNCTION__); }
+#define LW6SYS_TEST_FUNCTION_BEGIN { lw6sys_log(LW6SYS_LOG_NOTICE,_("running tests in function \"%s\""),__FUNCTION__); }
+#define LW6SYS_TEST_FUNCTION_END   if (ret) { lw6sys_log(LW6SYS_LOG_NOTICE,_("tests in \"%s\" OK"),__FUNCTION__); } else { lw6sys_log(LW6SYS_LOG_WARNING,_("tests in \"%s\" failed"),__FUNCTION__); }
+#define LW6SYS_BACKEND_FUNCION_BEGIN { lw6sys_log(LW6SYS_LOG_DEBUG,_("begin backend function \"%s\""),__FUNCTION__); }
+#define LW6SYS_BACKEND_FUNCION_END { lw6sys_log(LW6SYS_LOG_DEBUG,_("end backend function \"%s\""),__FUNCTION__); }
+
+#define LW6SYS_SCRIPT_FUNCTION_BEGIN { lw6sys_log(LW6SYS_LOG_DEBUG,_("begin script function \"%s\""),__FUNCTION__); }
+#define LW6SYS_SCRIPT_FUNCTION_END { lw6sys_log(LW6SYS_LOG_DEBUG,_("end script function \"%s\""),__FUNCTION__); }
 
 typedef struct lw6sys_xy_s
 {
@@ -188,20 +233,26 @@ extern lw6sys_color_hsv_t LW6SYS_COLOR_HSV_BLUE;
  * lw6sys_log directly, but use constructs like
  * lw6sys_log(LW6SYS_LOG_<LEVEL>,"%s%d",str,num);
  */
-#define LW6SYS_LOG_DEBUG_ID -1
-#define LW6SYS_LOG_INFO_ID 0
-#define LW6SYS_LOG_NOTICE_ID 1
-#define LW6SYS_LOG_WARNING_ID 2
-#define LW6SYS_LOG_ERROR_ID 3
-#define LW6SYS_LOG_DEBUG LW6SYS_LOG_DEBUG_ID, __FILE__, __LINE__
-#define LW6SYS_LOG_INFO LW6SYS_LOG_INFO_ID, __FILE__, __LINE__
-#define LW6SYS_LOG_NOTICE LW6SYS_LOG_NOTICE_ID, __FILE__, __LINE__
-#define LW6SYS_LOG_WARNING LW6SYS_LOG_WARNING_ID, __FILE__, __LINE__
+#define LW6SYS_LOG_ERROR_ID 0
+#define LW6SYS_LOG_WARNING_ID 1
+#define LW6SYS_LOG_NOTICE_ID 2
+#define LW6SYS_LOG_INFO_ID 3
+#define LW6SYS_LOG_DEBUG_ID 4
 #define LW6SYS_LOG_ERROR LW6SYS_LOG_ERROR_ID, __FILE__, __LINE__
+#define LW6SYS_LOG_WARNING LW6SYS_LOG_WARNING_ID, __FILE__, __LINE__
+#define LW6SYS_LOG_NOTICE LW6SYS_LOG_NOTICE_ID, __FILE__, __LINE__
+#define LW6SYS_LOG_INFO LW6SYS_LOG_INFO_ID, __FILE__, __LINE__
+#define LW6SYS_LOG_DEBUG LW6SYS_LOG_DEBUG_ID, __FILE__, __LINE__
+
 /*
  * macro D defined for quick-debugging / trace
  */
-#define D(message) lw6sys_log(LW6SYS_LOG_DEBUG, message)
+#define D(message) {int log_level=0; log_level=lw6sys_debug_get(); lw6sys_debug_set(1); lw6sys_log(LW6SYS_LOG_DEBUG, message); lw6sys_debug_set(log_level);}
+#define D1(message,arg1) {int log_level=0; log_level=lw6sys_debug_get(); lw6sys_debug_set(1); lw6sys_log(LW6SYS_LOG_DEBUG, message, arg1); lw6sys_debug_set(log_level);}
+#define D2(message,arg1,arg2) {int log_level=0; log_level=lw6sys_debug_get(); lw6sys_debug_set(1); lw6sys_log(LW6SYS_LOG_DEBUG, message, arg1, arg2); lw6sys_debug_set(log_level);}
+#define D3(message,arg1,arg2,arg3) {int log_level=0; log_level=lw6sys_debug_get(); lw6sys_debug_set(1); lw6sys_log(LW6SYS_LOG_DEBUG, message, arg1, arg2, arg3); lw6sys_debug_set(log_level);}
+#define D4(message,arg1,arg2,arg3,arg4) {int log_level=0; log_level=lw6sys_debug_get(); lw6sys_debug_set(1); lw6sys_log(LW6SYS_LOG_DEBUG, message, arg1, arg2, arg3, arg4); lw6sys_debug_set(log_level);}
+#define D5(message,arg1,arg2,arg3,arg4,arg5) {int log_level=0; log_level=lw6sys_debug_get(); lw6sys_debug_set(1); lw6sys_log(LW6SYS_LOG_DEBUG, message, arg1, arg2, arg3, arg4, arg5); lw6sys_debug_set(log_level);}
 
 /*
  * Common indenting parameters
@@ -260,6 +311,7 @@ extern char *lw6sys_build_get_md5sum ();
 extern char *lw6sys_build_get_copyright ();
 extern char *lw6sys_build_get_license ();
 extern char *lw6sys_build_get_configure_args ();
+extern char *lw6sys_build_get_gcc_version ();
 extern char *lw6sys_build_get_cflags ();
 extern char *lw6sys_build_get_ldflags ();
 extern char *lw6sys_build_get_hostname ();
@@ -267,6 +319,7 @@ extern char *lw6sys_build_get_date ();
 extern char *lw6sys_build_get_time ();
 extern char *lw6sys_build_get_target_cpu ();
 extern char *lw6sys_build_get_target_os ();
+extern int lw6sys_build_is_ms_windows ();
 extern char *lw6sys_build_get_top_srcdir ();
 extern char *lw6sys_build_get_prefix ();
 extern char *lw6sys_build_get_datadir ();
@@ -274,6 +327,15 @@ extern char *lw6sys_build_get_libdir ();
 extern char *lw6sys_build_get_includedir ();
 extern char *lw6sys_build_get_localedir ();
 extern char *lw6sys_build_get_docdir ();
+extern char *lw6sys_build_get_enable_console ();
+extern char *lw6sys_build_get_enable_mod_gl ();
+extern char *lw6sys_build_get_enable_mod_csound ();
+extern char *lw6sys_build_get_enable_mod_ogg ();
+extern char *lw6sys_build_get_enable_mod_http ();
+extern char *lw6sys_build_get_enable_allinone ();
+extern char *lw6sys_build_get_enable_fullstatic ();
+extern char *lw6sys_build_get_enable_gprof ();
+extern char *lw6sys_build_get_enable_valgrind ();
 extern void lw6sys_build_log_pedigree ();
 
 /* sys-checksum.c */
@@ -290,11 +352,9 @@ extern void lw6sys_checksum_update_wh (u_int32_t * checksum,
 extern void lw6sys_checksum_update_xy (u_int32_t * checksum,
 				       lw6sys_xy_t * xy);
 
-/*
- * In color.c
- */
-extern u_int8_t lw6sys_color_float2char (float comp);
-extern float lw6sys_color_char2float (u_int8_t comp);
+/* sys-color.c */
+extern u_int8_t lw6sys_color_float2char (float f);
+extern float lw6sys_color_char2float (u_int8_t i);
 extern lw6sys_color_8_t lw6sys_color_f_to_8 (lw6sys_color_f_t * color_f);
 extern void lw6sys_color_8_to_f (lw6sys_color_f_t *
 				 color_f, lw6sys_color_8_t color_8);
@@ -326,9 +386,11 @@ extern char *lw6sys_itoa (int value);
 extern char *lw6sys_btoa (int value);
 extern char *lw6sys_ftoa (float value);
 
-/*
- * Functions in dump.c
- */
+/* sys-debug.c */
+extern int lw6sys_debug_get ();
+extern void lw6sys_debug_set (int mode);
+
+/* sys-dump.c */
 extern void lw6sys_dump_clear (char *user_dir);
 extern int lw6sys_dump (char *user_dir, char *content);
 
@@ -338,14 +400,13 @@ extern char *lw6sys_env_separator_str ();
 extern char *lw6sys_env_concat (char *value1, char *value2);
 extern int lw6sys_env_exists (char *keyword);
 extern char *lw6sys_getenv (char *keyword);
+extern int lw6sys_setenv (char *keyword, char *value);
 extern lw6sys_list_t *lw6sys_env_split (char *value);
 extern char *lw6sys_get_home ();
 extern char *lw6sys_get_username ();
 extern char *lw6sys_get_hostname ();
 
-/*
- * Functions in file.c
- */
+/* sys-file.c */
 extern int lw6sys_clear_file (char *filename);
 extern char *lw6sys_read_file_content (char *filename);
 extern int lw6sys_write_file_content (char *filename, char *content);
@@ -407,9 +468,7 @@ extern int lw6sys_hexa_serializer_pop_color (lw6sys_hexa_serializer_t *
 					     hexa_serializer,
 					     lw6sys_color_8_t * value);
 
-/*
- * Functions in i18n.c
- */
+/* sys-i18n.c */
 extern char *lw6sys_locale_to_utf8 (char *string);
 
 /* sys-keyword.c */
@@ -438,13 +497,13 @@ extern void *lw6sys_fifo_pop (lw6sys_list_t ** list);
 extern lw6sys_list_t *lw6sys_list_dup (lw6sys_list_t * list,
 				       LW6SYS_DUP_FUNC dup_func);
 
-/*
- * Functions in log.c
- */
+/* sys-log.c */
 extern void lw6sys_log_set_file (char *filename);
 extern void lw6sys_log_clear (char *filename);
 extern void lw6sys_log (int level_id, char *file, int line, char *fmt, ...);
-extern void lw6sys_log_sos (char *fmt, ...);
+extern void lw6sys_log_critical (char *fmt, ...);
+extern int lw6sys_log_get_level ();
+extern void lw6sys_log_set_level (int level);
 
 /* sys-mem.c */
 #define LW6SYS_MALLOC(SIZE) lw6sys_malloc((SIZE),__FILE__,__LINE__);
@@ -461,9 +520,7 @@ extern int lw6sys_megabytes_available ();
 extern int lw6sys_is_big_endian ();
 extern int lw6sys_is_little_endian ();
 
-/*
- * Functions in mutex.c
- */
+/* sys-mutex.c */
 extern void *lw6sys_mutex_create ();
 extern void lw6sys_mutex_destroy (void *mutex);
 extern int lw6sys_mutex_lock (void *mutex);
@@ -473,15 +530,12 @@ extern int lw6sys_get_mutex_lock_count ();
 extern int lw6sys_get_mutex_unlock_count ();
 extern int lw6sys_check_mutex_count ();
 
-/*
- * Functions in nop.c
- */
+/* sys-nop.c */
 extern int lw6sys_true ();
 extern int lw6sys_false ();
 
-/*
- * Functions in options.c
- */
+/* sys-options.c */
+extern char *lw6sys_get_cwd ();
 extern char *lw6sys_get_default_user_dir ();
 extern char *lw6sys_get_default_config_file ();
 extern char *lw6sys_get_default_log_file ();
@@ -492,6 +546,7 @@ extern char *lw6sys_get_default_map_dir ();
 extern char *lw6sys_get_default_map_path ();
 extern char *lw6sys_get_default_script_file ();
 extern void lw6sys_options_log_defaults ();
+extern char *lw6sys_get_run_dir (int argc, char *argv[]);
 extern char *lw6sys_get_user_dir (int argc, char *argv[]);
 extern char *lw6sys_get_config_file (int argc, char *argv[]);
 extern char *lw6sys_get_log_file (int argc, char *argv[]);
@@ -503,9 +558,7 @@ extern char *lw6sys_get_map_path (int argc, char *argv[]);
 extern char *lw6sys_get_script_file (int argc, char *argv[]);
 extern void lw6sys_options_log (int argc, char *argv[]);
 
-/*
- * Functions in path.c
- */
+/* sys-path.c */
 extern int lw6sys_file_exists (char *filename);
 extern int lw6sys_dir_exists (char *dirname);
 extern int lw6sys_create_dir (char *dirname);
@@ -521,9 +574,12 @@ char *lw6sys_path_unparent_no_malloc (char *path);
 /* sys-print.c */
 extern void lw6sys_print_xml_header (FILE * f, char *comment);
 extern void lw6sys_print_xml_footer (FILE * f);
-/*
- * Functions in sdl.c
- */
+
+/* sys-random.c */
+extern u_int32_t lw6sys_random (u_int32_t range);
+extern float lw6sys_random_float (float min, float max);
+
+/* sys-sdl.c */
 extern int lw6sys_sdl_register ();
 extern int lw6sys_sdl_unregister ();
 
@@ -535,9 +591,7 @@ extern int32_t lw6sys_unserialize_int32 (unsigned char *data);
 extern void lw6sys_serialize_int16 (unsigned char *data, int16_t value);
 extern int16_t lw6sys_unserialize_int16 (unsigned char *data);
 
-/*
- * Functions in sort.c
- */
+/* sys-sort.c */
 int lw6sys_sort_int_callback (lw6sys_list_t ** list_a,
 			      lw6sys_list_t ** list_b);
 int lw6sys_sort_int_desc_callback (lw6sys_list_t ** list_a,
@@ -562,9 +616,7 @@ extern void lw6sys_str_cleanup (char *str);
 extern char *lw6sys_str_reformat (char *str, char *prefix, int nb_columns);
 extern char *lw6sys_eol ();
 
-/*
- * Functions in test.c
- */
+/* sys-test.c */
 extern int lw6sys_test ();
 
 /* sys-thread.c */
@@ -581,20 +633,19 @@ extern int lw6sys_get_thread_create_count ();
 extern int lw6sys_get_thread_join_count ();
 extern int lw6sys_check_thread_count ();
 
-/*
- * Functions in time.c
- */
+/* sys-time.c */
 extern int64_t lw6sys_timestamp ();
+extern int64_t lw6sys_uptime ();
 extern void lw6sys_sleep (float seconds);
+extern void lw6sys_time_init ();
 
-/*
- * Various inline utils
- */
+/* inline utils */
 static inline int
 lw6sys_min (int a, int b)
 {
   return (a < b) ? a : b;
 }
+
 static inline int
 lw6sys_max (int a, int b)
 {
