@@ -1,21 +1,21 @@
 #!/bin/sh
 
 # Liquid War 6 is a unique multiplayer wargame.
-# Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
-# 
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
-# 
+# Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
 # 
 # Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
 # Contact author        : ufoot@ufoot.org
@@ -23,7 +23,7 @@
 # Quick hack to generate a dummy .c file which will then be processed
 # by GNU gettext to extract strings for po files and i18n.
 
-SCRIPT_DIR=../src/script
+SCRIPT_DIR=../script
 C_FILE=../src/scriptpo.c
 
 find $SCRIPT_DIR -type f -a -name "*.scm" \
@@ -35,6 +35,8 @@ find $SCRIPT_DIR -type f -a -name "*.scm" \
 cd ..
 find src -type f -a -name "*.c" \
     > po/POTFILES.in
+find src -type f -a -name "*.c.inc" \
+    >> po/POTFILES.in
 cd src
 
 indent $C_FILE
